@@ -18,8 +18,10 @@ use PDO;
 use function array_keys;
 use function array_map;
 use function array_merge;
+use function assert;
 use function class_implements;
 use function in_array;
+use function is_string;
 use function is_subclass_of;
 use function parse_str;
 use function parse_url;
@@ -86,20 +88,7 @@ final class DriverManager
      *
      * $params must contain at least one of the following.
      *
-     * Either 'driver' with one of the following values:
-     *
-     *     pdo_mysql
-     *     pdo_sqlite
-     *     pdo_pgsql
-     *     pdo_oci (unstable)
-     *     pdo_sqlsrv
-     *     pdo_sqlsrv
-     *     mysqli
-     *     sqlanywhere
-     *     sqlsrv
-     *     ibm_db2 (unstable)
-     *     drizzle_pdo_mysql
-     *
+     * Either 'driver' with one of the array keys of {@link $_driverMap},
      * OR 'driverClass' that contains the full class name (with namespace) of the
      * driver class to instantiate.
      *
@@ -172,7 +161,9 @@ final class DriverManager
         // check for existing pdo object
         if (isset($params['pdo']) && ! $params['pdo'] instanceof PDO) {
             throw DBALException::invalidPdoInstance();
-        } elseif (isset($params['pdo'])) {
+        }
+
+        if (isset($params['pdo'])) {
             $params['pdo']->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
             $params['driver'] = 'pdo_' . $params['pdo']->getAttribute(PDO::ATTR_DRIVER_NAME);
         } else {
@@ -263,6 +254,8 @@ final class DriverManager
 
         // (pdo_)?sqlite3?:///... => (pdo_)?sqlite3?://localhost/... or else the URL will be invalid
         $url = preg_replace('#^((?:pdo_)?sqlite3?):///#', '$1://localhost/', $params['url']);
+        assert(is_string($url));
+
         $url = parse_url($url);
 
         if ($url === false) {
@@ -414,6 +407,7 @@ final class DriverManager
 
             // URL schemes must not contain underscores, but dashes are ok
             $driver = str_replace('-', '_', $url['scheme']);
+            assert(is_string($driver));
 
             // The requested driver from the URL scheme takes precedence over the
             // default driver from the connection parameters. If the driver is
