@@ -2,20 +2,19 @@ OC.L10N.register(
     "accessibility",
     {
     "Dark theme" : "Tamna tema",
+    "Enable dark theme" : "Omogući tamnu temu",
     "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Tamna tema ublažava naprezanje očiju smanjujući ukupnu luminoznost i svjetlinu. Tema je i dalje u izradi pa nam prijavite bilo kakve probleme s korištenjem.",
     "High contrast mode" : "Način jakog kontrasta",
+    "Enable high contrast mode" : "Omogući način jakog kontrasta",
     "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Način jakog kontrasta olakšava navigaciju. Smanjuje vizualnu kvalitetu, ali povećava jasnoću prikaza.",
     "Dyslexia font" : "Font za osobe s disleksijom",
+    "Enable dyslexia font" : "Omogući font za osobe s disleksijom",
     "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic je besplatan font/izgled slova posebno osmišljen za ublažavanje nekih uobičajenih pogrešaka pri čitanju uzrokovanih disleksijom.",
     "Accessibility" : "Pristupačnost",
     "Accessibility options for nextcloud" : "Mogućnosti pristupačnosti za Nextcloud",
     "Provides multiple accessibilities options to ease your use of Nextcloud" : "Pruža višestruke mogućnosti pristupačnosti za jednostavniju upotrebu Nextclouda",
-    "Web Content Accessibility Guidelines" : "Smjernice pristupačnosti web-sadržaja",
-    "our issue tracker" : "naš alat za praćenje problema",
-    "our design team" : "naš dizajnerski tim",
-    "Enable" : "Omogući",
-    "High contrast theme" : "Tema jakog kontrasta",
-    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Tema jakog kontrasta olakšava navigaciju. Smanjuje vizualnu kvalitetu, ali povećava jasnoću prikaza.",
-    "Dark theme (beta)" : "Tamna tema (beta)"
+    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Nama je vrlo važno osigurati univerzalan pristup. Pratimo sve internetske i mrežne standarde i provjeravamo je li sustav upotrebljiv bez miša i pomoćnog softvera, kao što je čitač zaslona. Naš je cilj postići sukladnost sa {guidelines}Smjernicama pristupačnosti web-sadržaja{linkend} 2.1 na razini AA s temom jakog kontrasta na razini AAA.",
+    "If you find any issues, don’t hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Prijavite sve pronađene poteškoće putem {issuetracker}alata za praćenje poteškoća{linkend}. Ako želite sudjelovati, pridružite se {designteam}našem dizajnerskom timu{linkend}!",
+    "Enable" : "Omogući"
 },
 "nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
