@@ -15,13 +15,6 @@ OC.L10N.register(
     "Provides multiple accessibilities options to ease your use of Nextcloud" : "あなたのNextcloudの利用を簡単にするための複数のユーザー補助のオプションを提供します。",
     "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "ユニバーサルアクセスは私たちにとって非常に重要なことです。そのためウェブ標準に従い、マウスやスクリーンリーダーなどの支援ソフトウェアが無くても全ての機能をご利用いただけるようにチェックしています。AAAレベルのハイコントラストのテーマを採用することで、{guidelines} Webコンテンツアクセシビリティガイドライン2.1  {linkend} のAAAレベルに準拠することを目指しています。",
     "If you find any issues, don’t hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "問題がある場合は、お気軽に{issuetracker}issue tracker {linkend}に報告してください。 手伝って頂ける方は、{designteam}デザインチーム{linkend}にご参加ください。",
-    "High contrast theme" : "ハイコントラストテーマ",
-    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "ハイコントラストテーマは表示の質は下がりますが、見やすさは上がります。",
-    "Web Content Accessibility Guidelines" : "Webコンテンツ アクセシビリティガイドライン",
-    "our issue tracker" : "問題追跡",
-    "our design team" : "デザインチーム",
-    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines} 2.1 on AA level, with the high contrast theme even on AAA level." : "ユニバーサルアクセスは私たちにとって非常に重要なことです。そのためウェブ標準に従い、マウスやスクリーンリーダーなどの支援ソフトウェアが無くても全ての機能をご利用いただけるようにチェックしています。AAAレベルのハイコントラストのテーマを採用することで、{guidelines} 2.1 のAAAレベルに準拠することを目指しています。",
-    "If you find any issues, don’t hesitate to report them on {issuetracker}. And if you want to get involved, come join {designteam}!" : "問題がある場合は、お気軽に{issuetracker}に報告してください。 手伝って頂ける方は、{designteam}にご参加ください。",
     "Enable" : "有効にする"
 },
 "nplurals=1; plural=0;");
