@@ -1,21 +1,20 @@
 OC.L10N.register(
     "accessibility",
     {
-    "Dark theme" : "Tmavý motív",
+    "Dark theme" : "Tmavý motív vzhľadu",
+    "Enable dark theme" : "Zapnúť tmavý motív vzhľadu",
     "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Tmavý motív vzhľadu pre úľavu vašim očiam znížením celkovej svietivosti a jasu. Je ešte stále vo vývoji, ak náhodou narazíte na nejaký problém, tak nám ho prosím nahláste.",
     "High contrast mode" : "Režim vysokého kontrastu",
+    "Enable high contrast mode" : "Zapnúť režim vysokého kontrastu",
     "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Mód s vysokým kontrastom pre uľahčenie navigácie. Zníži sa síce vizuálna kvalita, ale zvýši sa čitateľnosť.",
     "Dyslexia font" : "Písmo pre dyslektikov",
+    "Enable dyslexia font" : "Povoliť písmo pre dyslektikov",
     "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic je slobodný typ písma navrhnutý priamo pre obmedzenie vplyvu niektorých bežných porúch čítania spôsobených dyslexiou.",
     "Accessibility" : "Prístupnosť",
     "Accessibility options for nextcloud" : "Možnosti prístupnosti pre Nextcloud",
     "Provides multiple accessibilities options to ease your use of Nextcloud" : "Poskytuje viac možností prístupnosti pre uľahčenie používania Nextcloud",
-    "Web Content Accessibility Guidelines" : "Usmernenia o prístupnosti webového obsahu",
-    "our issue tracker" : "náš systém evidencie hlásenia chýb",
-    "our design team" : "náš tím dizajnérov",
-    "Enable" : "Zapnúť",
-    "High contrast theme" : "Motív vzhľadu s vysokým kontrastom",
-    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Motív vzhľadu s vysokým kontrastom pre uľahčenie navigácie. Zníži sa síce vizuálna kvalita, ale zvýši sa čitateľnosť.",
-    "Dark theme (beta)" : "Tmavý motív vzhľadu (beta)"
+    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Univerzálny prístup je pre nás veľmi dôležitý. Dodržiavame webové štandardy a kontrolujeme, aby bolo všetko použiteľné aj bez myši a pomocného softvéru, ako sú čítačky obrazovky. Naším cieľom je byť v súlade s {guidelines}pokynmi pre prístup k webovému obsahu {linkend} 2.1 na úrovni AA,  v režime vysokého kontrastu dokonca na úrovni AAA.",
+    "If you find any issues, don’t hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Ak nájdete nejaký problém, neváhajte a nahláste ho na {issuetracker}nástroj na sledovanie problémov{linkend}. A ak sa chcete zapojiť, pripojte sa k {designteam}nášmu dizajnérskemu tímu{linkend}!",
+    "Enable" : "Zapnúť"
 },
 "nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
