@@ -22,8 +22,6 @@
 
 namespace OCA\Activity;
 
-use OCA\Activity\Extension\LegacyParser;
-use OCA\Activity\Parameter\IParameter;
 use OCP\Activity\IEvent;
 use OCP\Activity\IManager;
 use OCP\IL10N;
@@ -46,39 +44,22 @@ class GroupHelper {
 	/** @var \OCP\Activity\IManager */
 	protected $activityManager;
 
-	/** @var \OCA\Activity\DataHelper */
-	protected $dataHelper;
-
 	/** @var IValidator */
 	protected $richObjectValidator;
 
 	/** @var ILogger */
 	protected $logger;
 
-	/** @var LegacyParser */
-	protected $legacyParser;
-
 	public function __construct(IL10N $l,
 								IManager $activityManager,
-								DataHelper $dataHelper,
 								IValidator $richObjectValidator,
-								ILogger $logger,
-								LegacyParser $legacyParser) {
+								ILogger $logger) {
 		$this->allowGrouping = true;
 
 		$this->l = $l;
 		$this->activityManager = $activityManager;
-		$this->dataHelper = $dataHelper;
 		$this->richObjectValidator = $richObjectValidator;
 		$this->logger = $logger;
-		$this->legacyParser = $legacyParser;
-	}
-
-	/**
-	 * @param string $user
-	 */
-	public function setUser($user) {
-		$this->dataHelper->setUser($user);
 	}
 
 	/**
@@ -86,7 +67,6 @@ class GroupHelper {
 	 */
 	public function setL10n(IL10N $l) {
 		$this->l = $l;
-		$this->dataHelper->setL10n($l);
 	}
 
 	/**
@@ -136,14 +116,8 @@ class GroupHelper {
 		}
 
 		if (!$event->getParsedSubject()) {
-			try {
-				$this->activityManager->setFormattingObject($event->getObjectType(), $event->getObjectId());
-				$event = $this->legacyParser->parse($language, $event);
-				$this->activityManager->setFormattingObject('', 0);
-			} catch (\InvalidArgumentException $e) {
-				\OC::$server->getLogger()->debug('Failed to parse activity');
-				return;
-			}
+			$this->logger->debug('Activity "' . $event->getRichSubject() . '" was not parsed by any provider');
+			return;
 		}
 
 		$this->event[$id] = $event;
@@ -165,6 +139,13 @@ class GroupHelper {
 		return $return;
 	}
 
+	/**
+	 * @return IEvent[]
+	 */
+	public function getEvents(): array {
+		return $this->event;
+	}
+
 	/**
 	 * @param array $row
 	 * @return IEvent
@@ -176,8 +157,8 @@ class GroupHelper {
 			->setAffectedUser((string) $row['affecteduser'])
 			->setAuthor((string) $row['user'])
 			->setTimestamp((int) $row['timestamp'])
-			->setSubject((string) $row['subject'], json_decode($row['subjectparams'], true))
-			->setMessage((string) $row['message'], json_decode($row['messageparams'], true))
+			->setSubject((string) $row['subject'], (array) json_decode($row['subjectparams'], true))
+			->setMessage((string) $row['message'], (array) json_decode($row['messageparams'], true))
 			->setObject((string) $row['object_type'], (int) $row['object_id'], (string) $row['file'])
 			->setLink((string) $row['link']);
 
@@ -219,14 +200,15 @@ class GroupHelper {
 	 * @param IEvent $event
 	 * @return array
 	 */
-	protected function getObjectsFromChildren(IEvent $event) {
+	protected function getObjectsFromChildren(IEvent $event): array {
 		$child = $event->getChildEvent();
+		$objects = [];
 		if ($child instanceof IEvent) {
 			$objects = $this->getObjectsFromChildren($child);
-			$objects[$event->getObjectId()] = $event->getObjectName();
-			return $objects;
-		} else {
-			return [$event->getObjectId() => $event->getObjectName()];
 		}
+		if ($event->getObjectId() !== 0 || $event->getObjectName() !== '') {
+			$objects[$event->getObjectId()] = $event->getObjectName();
+		}
+		return $objects;
 	}
 }
