@@ -22,6 +22,7 @@
 
 namespace OCA\Activity;
 
+use OCP\Activity\ActivitySettings;
 use OCP\Activity\IManager;
 use OCP\IConfig;
 
@@ -135,30 +136,27 @@ class UserSettings {
 
 		try {
 			$setting = $this->manager->getSettingById($type);
-			return ($method === 'stream') ? $setting->isDefaultEnabledStream() : $setting->isDefaultEnabledMail();
+			switch ($method) {
+				case 'email':
+					return $setting->isDefaultEnabledMail();
+				case 'notification':
+					return $setting->isDefaultEnabledNotification();
+				default:
+					return false;
+			}
 		} catch (\InvalidArgumentException $e) {
 			return false;
 		}
 	}
 
 	/**
-	 * Get a list with enabled notification types for a user
-	 *
-	 * @param string	$user	Name of the user
-	 * @param string	$method	Should be one of 'stream' or 'email'
-	 * @return array
+	 * Get a list with all notification types
 	 */
-	public function getNotificationTypes($user, $method) {
-		$notificationTypes = array();
-
+	public function getNotificationTypes() {
 		$settings = $this->manager->getSettings();
-		foreach ($settings as $setting) {
-			if ($this->getUserSetting($user, $method, $setting->getIdentifier())) {
-				$notificationTypes[] = $setting->getIdentifier();
-			}
-		}
-
-		return $notificationTypes;
+		return array_map(function(ActivitySettings $setting) {
+			return $setting->getIdentifier();
+		}, $settings);
 	}
 
 	/**
@@ -167,7 +165,7 @@ class UserSettings {
 	 * @param array $users
 	 * @param string $method
 	 * @param string $type
-	 * @return array Returns a "username => b:true" Map for method = stream
+	 * @return array Returns a "username => b:true" Map for method = notification
 	 *               Returns a "username => i:batchtime" Map for method = email
 	 */
 	public function filterUsersBySetting($users, $method, $type) {
@@ -204,7 +202,7 @@ class UserSettings {
 		// we add all users that didn't set the preference yet.
 		if ($this->getDefaultFromSetting($method, $type)) {
 			foreach ($users as $user) {
-				if ($method === 'stream') {
+				if ($method === 'notification') {
 					$filteredUsers[$user] = true;
 				} else {
 					$filteredUsers[$user] = $this->getDefaultFromSetting('setting', 'batchtime');
