@@ -1,21 +1,7 @@
 OC.L10N.register(
     "comments",
     {
-    "Edit comment" : "Editar comentariu",
-    "Delete comment" : "Desaniciar comentariu",
-    "New comment …" : "Comentariu nuevu...",
-    "Post" : "Espublizar",
-    "Cancel" : "Encaboxar",
-    "[Deleted user]" : "[Usuariu desaniciáu]",
     "Comments" : "Comentarios",
-    "No comments yet, start the conversation!" : "Entá nun hai comentarios. ¡Entama una conversación!",
-    "More comments …" : "Más comentarios...",
-    "Save" : "Guardar",
-    "Allowed characters {count} of {max}" : "{count} caráuteres almitíos de {max}",
-    "Error occurred while updating comment with id {id}" : "Asocedió un fallu entrín s'anovaba'l comentariu cola ID {id}",
-    "Error occurred while posting comment" : "Asocedieron fallos entrín s'espublizaba'l comentariu",
-    "_%n unread comment_::_%n unread comments_" : ["%n comentariu ensin lleer","%n comentarios ensin lleer"],
-    "Comment" : "Comentariu",
     "You commented" : "Comentesti",
     "%1$s commented" : "%1$s comentó",
     "{author} commented" : "{author} comentó",
@@ -25,9 +11,20 @@ OC.L10N.register(
     "{author} commented on {file}" : "{autor} comentó en {ficheru}",
     "<strong>Comments</strong> for files" : "<strong>Comentarios</strong> pa ficheros",
     "{user} mentioned you in a comment on “{file}”" : "{user} mentóte nun comentariu de «{file}»",
-    "Unknown user" : "Usuariu desconocíu",
-    "A (now) deleted user mentioned you in a comment on “%s”" : "Un usuariu (agora) desaniciáu mentóte nun comentariu de «%s»",
-    "A (now) deleted user mentioned you in a comment on “{file}”" : "Un usuariu (agora) desaniciáu mentóte nun comentariu de «{file}»",
-    "%1$s mentioned you in a comment on “%2$s”" : "%1$s mentóte nun comentariu de «%2$s»"
+    "Edit comment" : "Editar comentariu",
+    "Delete comment" : "Desaniciar comentariu",
+    "No comments yet, start the conversation!" : "Entá nun hai comentarios. ¡Entama una conversación!",
+    "Retry" : "Retentar",
+    "_%n unread comment_::_%n unread comments_" : ["%n comentariu ensin lleer","%n comentarios ensin lleer"],
+    "Comment" : "Comentariu",
+    "New comment …" : "Comentariu nuevu...",
+    "Post" : "Espublizar",
+    "Cancel" : "Encaboxar",
+    "[Deleted user]" : "[Usuariu desaniciáu]",
+    "More comments …" : "Más comentarios...",
+    "Save" : "Guardar",
+    "Allowed characters {count} of {max}" : "{count} caráuteres almitíos de {max}",
+    "Error occurred while updating comment with id {id}" : "Asocedió un fallu entrín s'anovaba'l comentariu cola ID {id}",
+    "Error occurred while posting comment" : "Asocedieron fallos entrín s'espublizaba'l comentariu"
 },
 "nplurals=2; plural=(n != 1);");
