@@ -15,19 +15,19 @@ OC.L10N.register(
     "Files app plugin to add comments to files" : "Complemento de aplicación de archivos para agregar comentarios a los archivos.",
     "Edit comment" : "Editar comentario",
     "Delete comment" : "Borrar comentario",
+    "No comments yet, start the conversation!" : "No hay comentarios aún, iniciar la conversación!",
+    "Retry" : "Reintentar",
+    "_%n unread comment_::_%n unread comments_" : ["%n comentarios sin leer","%n comentarios sin leer"],
+    "Comment" : "Comentar",
     "New comment …" : "Nuevo comentario ...",
     "Post" : "Post",
     "Cancel" : "Cancelar",
     "[Deleted user]" : "[Usuario borrado]",
-    "No comments yet, start the conversation!" : "No hay comentarios aún, iniciar la conversación!",
     "More comments …" : "Más comentarios ...",
     "Save" : "Guardar",
     "Allowed characters {count} of {max}" : "Caracteres permitidos {count} of {max}",
     "Error occurred while retrieving comment with ID {id}" : "Se produjo un error al recuperar el comentario con ID {id}",
     "Error occurred while updating comment with id {id}" : "Se ha producido un error al actualizar el comentario con id {id}",
-    "Error occurred while posting comment" : "Se ha producido un error al publicar un comentario",
-    "_%n unread comment_::_%n unread comments_" : ["%n comentarios sin leer","%n comentarios sin leer"],
-    "Comment" : "Comentar",
-    "%1$s mentioned you in a comment on “%2$s”" : "%1$s te ha mencionado en un comentario en “%2$s”"
+    "Error occurred while posting comment" : "Se ha producido un error al publicar un comentario"
 },
 "nplurals=2; plural=(n != 1);");
