@@ -20,10 +20,14 @@ OC.L10N.register(
     "No comments yet, start the conversation!" : "Il n'y a aucun commentaire, démarrez la conversation !",
     "No more messages" : "Aucun autre message",
     "Retry" : "Réessayer",
+    "Unable to load the comments list" : "Impossible de charger la liste des commentaires",
     "_%n unread comment_::_%n unread comments_" : ["%n commentaire non lu","%n commentaires non lus"],
     "_1 new comment_::_{unread} new comments_" : ["1 nouveau commentaire","{unread} nouveaux commentaires"],
     "Comment" : "Commenter",
+    "An error occurred while trying to edit the comment" : "Une erreur s'est produite lors de la tentative de modification du commentaire",
     "Comment deleted" : "Commentaire supprimé",
+    "An error occurred while trying to delete the comment" : "Une erreur s'est produite lors de la tentative de suppression du commentaire",
+    "An error occurred while trying to create the comment" : "Une erreur s'est produite lors de la tentative de création du commentaire",
     "New comment …" : "Nouveau commentaire...",
     "Post" : "Poster",
     "Cancel" : "Annuler",
