@@ -1,24 +1,9 @@
 OC.L10N.register(
     "comments",
     {
-    "Edit comment" : "編輯留言",
-    "Delete comment" : "刪除留言",
-    "New comment …" : "新留言…",
-    "Post" : "送出",
-    "Cancel" : "取消",
-    "[Deleted user]" : "[已刪除的使用者]",
     "Comments" : "留言",
-    "No comments yet, start the conversation!" : "尚無留言，開始討論 !",
-    "More comments …" : "其他留言…",
-    "Save" : "儲存",
-    "Allowed characters {count} of {max}" : "已輸入 {count} / 長度限制 {max}",
-    "Error occurred while retrieving comment with ID {id}" : "在擷取 ID {id} 的註解時發生錯誤",
-    "Error occurred while updating comment with id {id}" : "編輯留言 {id} 發生錯誤",
-    "Error occurred while posting comment" : "張貼留言出錯",
-    "_%n unread comment_::_%n unread comments_" : ["%n 未讀留言"],
-    "Comment" : "留言",
-    "You commented" : "你已留言",
-    "%1$s commented" : "%1$s 留言",
+    "You commented" : "您已留言",
+    "%1$s commented" : "%1$s 個留言",
     "{author} commented" : "{author} 已留言",
     "You commented on %1$s" : "你對 %1$s 留言",
     "You commented on {file}" : "你對 {file} 留言",
@@ -28,7 +13,23 @@ OC.L10N.register(
     "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "一個已被刪除的用戶在 “{file}” 的留言中提到你",
     "{user} mentioned you in a comment on “{file}”" : "{user} 在 “{file}” 的留言中提到你",
     "Files app plugin to add comments to files" : "檔案插件程式插件，用於為檔案增加註釋",
-    "You were mentioned on “%s”, in a comment by a user that has since been deleted" : "一個已被刪除的用戶在 “%s” 的留言中提到你",
-    "%1$s mentioned you in a comment on “%2$s”" : "%1$s 在 “%2$s” 的留言中提到你"
+    "Edit comment" : "編輯留言",
+    "Delete comment" : "刪除留言",
+    "No comments yet, start the conversation!" : "尚無留言，開始討論 !",
+    "Retry" : "重試",
+    "_%n unread comment_::_%n unread comments_" : ["%n 未讀留言"],
+    "_1 new comment_::_{unread} new comments_" : ["{unread} 個新留言"],
+    "Comment" : "留言",
+    "Comment deleted" : "意見刪除",
+    "New comment …" : "新增留言",
+    "Post" : "送出",
+    "Cancel" : "取消",
+    "[Deleted user]" : "[已刪除的使用者]",
+    "More comments …" : "其他留言…",
+    "Save" : "儲存",
+    "Allowed characters {count} of {max}" : "已輸入 {count} / 長度限制 {max}",
+    "Error occurred while retrieving comment with ID {id}" : "在擷取 ID {id} 的註解時發生錯誤",
+    "Error occurred while updating comment with id {id}" : "編輯留言 {id} 發生錯誤",
+    "Error occurred while posting comment" : "張貼留言出錯"
 },
 "nplurals=1; plural=0;");
