@@ -40,6 +40,7 @@ OC.L10N.register(
     "You solved todo {todo} in list {calendar}" : "Usted completó la tarea {todo} en la lista {calendar}",
     "{actor} reopened todo {todo} in list {calendar}" : "{actor} reabrió la tarea {todo} en la lista {calendar}",
     "You reopened todo {todo} in list {calendar}" : "Usted reabrió la tarea {todo} en la lista {calendar}",
+    "Calendar and tasks" : "Calendario y tareas",
     "A <strong>calendar</strong> was modified" : "Un <strong>calendario</strong> fue modificado.",
     "A calendar <strong>event</strong> was modified" : "Un <strong>evento</strong> del calendario fue modificado.",
     "A calendar <strong>todo</strong> was modified" : "Una <strong>lista de tareas</strong> fue modificada",
@@ -63,21 +64,30 @@ OC.L10N.register(
     "Where: %s" : "Lugar: %s",
     "%1$s via %2$s" : "%1$s vía %2$s",
     "Invitation canceled" : "Invitación cancelada",
-    "Hello %s," : "Hola, %s:",
-    "The meeting »%1$s« with %2$s was canceled." : "La reunión »%1$s« con %2$s se ha cancelado.",
     "Invitation updated" : "Invitación actualizada",
-    "The meeting »%1$s« with %2$s was updated." : "La reunión »%1$s« con %2$s se ha actualizado.",
-    "%1$s invited you to »%2$s«" : "%1$s te ha invitado a »%2$s«",
-    "When:" : "Cuándo:",
+    "Invitation" : "Invitación",
+    "Title:" : "Título:",
+    "Time:" : "Hora:",
+    "Location:" : "Ubicación:",
     "Link:" : "Enlace:",
+    "Organizer:" : "Organizador:",
+    "Attendees:" : "Asistentes:",
     "Accept" : "Aceptar",
     "Decline" : "Rechazar",
     "More options …" : "Más opciones...",
     "More options at %s" : "Más opciones en %s",
     "Contacts" : "Contactos",
+    "System in maintenance mode." : "Sistema en modo de mantenimiento.",
+    "Upgrade needed" : "Se necesita actualizar",
     "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Tu %s necesita configurarse para usar HTTPS en caso de usar CalDAV y CardDAV con iOS/macOS.",
     "Configures a CalDAV account" : "Configura una cuenta CalDAV",
     "Configures a CardDAV account" : "Configura una cuenta CardDAV",
+    "Events" : "Eventos",
+    "Tasks" : "Tareas",
+    "Untitled task" : "Tarea sin título",
+    "Completed on %s" : "Completado el %s",
+    "Due on %s by %s" : "Finaliza el %s por %s",
+    "Due on %s" : "Finaliza el %s",
     "WebDAV" : "WebDAV",
     "WebDAV endpoint" : "Extremo de WebDAV",
     "There was an error updating your attendance status." : "Ha habido un error al actualizar tu estado de asistencia.",
@@ -96,9 +106,10 @@ OC.L10N.register(
     "Send notifications for events" : "Enviar notificaciones de los eventos",
     "Notifications are sent via background jobs, so these must occur often enough." : "Las notificaciones son enviadas a través de trabajos en segundo plano, por lo que estos deben ocurrir con la suficiente frecuencia.",
     "Enable notifications for events via push" : "Activar notificaciones push para eventos",
-    "Technical details" : "Detalles técnicos",
-    "Remote Address: %s" : "Dirección remota: %s",
-    "Request ID: %s" : "ID de solicitud: %s",
-    "Notifications will be send through background jobs, so these need to happen often enough." : "Las notificaciones se enviarán a través de trabajos en segundo plano, por lo que estos deben llevarse a cabo con cierta frecuencia."
+    "Hello %s," : "Hola, %s:",
+    "The meeting »%1$s« with %2$s was canceled." : "La reunión »%1$s« con %2$s se ha cancelado.",
+    "The meeting »%1$s« with %2$s was updated." : "La reunión »%1$s« con %2$s se ha actualizado.",
+    "%1$s invited you to »%2$s«" : "%1$s te ha invitado a »%2$s«",
+    "When:" : "Cuándo:"
 },
 "nplurals=2; plural=(n != 1);");
