@@ -63,21 +63,21 @@ OC.L10N.register(
     "Where: %s" : "איפה: %s",
     "%1$s via %2$s" : "%1$s דרך %2$s",
     "Invitation canceled" : "ההזמנה בוטלה",
-    "Hello %s," : "שלום %s,",
-    "The meeting »%1$s« with %2$s was canceled." : "הפגישה »%1$s« עם %2$s בוטלה.",
     "Invitation updated" : "ההזמנה עודכנה",
-    "The meeting »%1$s« with %2$s was updated." : "הפגישה »%1$s« עם %2$s עודכנה.",
-    "%1$s invited you to »%2$s«" : "הוזמנת על ידי %1$s אל „%2$s”",
-    "When:" : "מתי:",
+    "Location:" : "מיקום:",
     "Link:" : "קישור:",
     "Accept" : "קבלה",
     "Decline" : "דחייה",
     "More options …" : "אפשרויות נוספות…",
     "More options at %s" : "אפשרויות נוספים ב־%s",
     "Contacts" : "אנשי קשר",
+    "System in maintenance mode." : "המערכת במצב עבודות תחזוקה.",
+    "Upgrade needed" : "נדרש עדכון",
     "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "עליך להגדיר את ה־%s שלך להשתמש ב־HTTPS כדי להשתמש ב־CalDAV וב־CardDAV עם iOS/macOS.",
     "Configures a CalDAV account" : "מגדיר חשבון CalDAV",
     "Configures a CardDAV account" : "מגדיר חשבון CardDAV",
+    "Tasks" : "משימות",
+    "Untitled task" : "משימה ללא כותרת",
     "WebDAV" : "WebDAV",
     "WebDAV endpoint" : "נקודת קצה WebDAV",
     "There was an error updating your attendance status." : "אירעה שגיאה בעת עדכון מצב ההשתתפות שלך.",
@@ -96,9 +96,10 @@ OC.L10N.register(
     "Send notifications for events" : "שליחת התראות לאירועים",
     "Notifications are sent via background jobs, so these must occur often enough." : "התראות נשלחות באמצעות משימות רקע, לכן הבדיקה תתבצע יחסית לעתים קרובות.",
     "Enable notifications for events via push" : "הפעלת התראות לאירועים בדחיפה",
-    "Technical details" : "פרטים טכניים",
-    "Remote Address: %s" : "כתובת מרוחקת: %s",
-    "Request ID: %s" : "מזהה בקשה: %s",
-    "Notifications will be send through background jobs, so these need to happen often enough." : "התראות נשלחות באמצעות משימות רקע, לכן הבדיקה תתבצע יחסית באופן סדיר מספיק."
+    "Hello %s," : "שלום %s,",
+    "The meeting »%1$s« with %2$s was canceled." : "הפגישה »%1$s« עם %2$s בוטלה.",
+    "The meeting »%1$s« with %2$s was updated." : "הפגישה »%1$s« עם %2$s עודכנה.",
+    "%1$s invited you to »%2$s«" : "הוזמנת על ידי %1$s אל „%2$s”",
+    "When:" : "מתי:"
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
