@@ -48,12 +48,8 @@ OC.L10N.register(
     "Description:" : "설명:",
     "%1$s via %2$s" : "%1$s(%2$s 경유)",
     "Invitation canceled" : "초대장 취소됨",
-    "Hello %s," : "%s 님 안녕하세요,",
-    "The meeting »%1$s« with %2$s was canceled." : "\"%1$s\" 행사(%2$s 님이 진행함)가 취소되었습니다.",
     "Invitation updated" : "초대장 업데이트됨",
-    "The meeting »%1$s« with %2$s was updated." : "\"%1$s\" 행사(%2$s 님이 진행함)가 업데이트되었습니다.",
-    "%1$s invited you to »%2$s«" : "%1$s 님이 \"%2$s\"에 초대함",
-    "When:" : "일시:",
+    "Location:" : "위치:",
     "Link:" : "링크:",
     "Accept" : "수락",
     "Decline" : "거절",
@@ -63,6 +59,7 @@ OC.L10N.register(
     "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "iOS/macOS에서 CalDAV 및 CardDAV를 사용하려면 %s에서 HTTPS를 사용하도록 설정해야 합니다.",
     "Configures a CalDAV account" : "CalDAV 계정 설정",
     "Configures a CardDAV account" : "CardDAV 계정 설정",
+    "Tasks" : "작업",
     "WebDAV" : "WebDAV",
     "WebDAV endpoint" : "WebDAV 종단점",
     "There was an error updating your attendance status." : "참석 상태를 업데이트하는 중 오류가 발생했습니다.",
@@ -78,8 +75,10 @@ OC.L10N.register(
     "Automatically generate a birthday calendar" : "자동으로 생일 달력 생성",
     "Birthday calendars will be generated by a background job." : "배경 작업으로 생일 달력을 생성합니다.",
     "Hence they will not be available immediately after enabling but will show up after some time." : "생일 달력이 생성되는 데 시간이 걸릴 수도 있습니다.",
-    "Technical details" : "기술 정보",
-    "Remote Address: %s" : "원격 주소: %s",
-    "Request ID: %s" : "요청 ID: %s"
+    "Hello %s," : "%s 님 안녕하세요,",
+    "The meeting »%1$s« with %2$s was canceled." : "\"%1$s\" 행사(%2$s 님이 진행함)가 취소되었습니다.",
+    "The meeting »%1$s« with %2$s was updated." : "\"%1$s\" 행사(%2$s 님이 진행함)가 업데이트되었습니다.",
+    "%1$s invited you to »%2$s«" : "%1$s 님이 \"%2$s\"에 초대함",
+    "When:" : "일시:"
 },
 "nplurals=1; plural=0;");
