@@ -33,12 +33,8 @@ OC.L10N.register(
     "Description:" : "描述",
     "%1$s via %2$s" : "%1$s 由 %2$s",
     "Invitation canceled" : "邀請被取消了",
-    "Hello %s," : "%s您好，",
-    "The meeting »%1$s« with %2$s was canceled." : "與 %2$s 的會議 %1$s 取消了",
     "Invitation updated" : "邀請更新",
-    "The meeting »%1$s« with %2$s was updated." : "與 %2$s 的會議 %1$s 有變動",
-    "%1$s invited you to »%2$s«" : "%1$s邀請您到%2$s",
-    "When:" : "時間",
+    "Location:" : "地點：",
     "Link:" : "連結",
     "Accept" : "接受",
     "Decline" : "拒絕",
@@ -61,8 +57,10 @@ OC.L10N.register(
     "Send invitations to attendees" : "發送邀請函給參加者",
     "Automatically generate a birthday calendar" : "自動建立 生日 日曆",
     "Birthday calendars will be generated by a background job." : "生日日曆 將會在 後台 建立",
-    "Technical details" : "技術細節",
-    "Remote Address: %s" : "遠端位置：%s",
-    "Request ID: %s" : "請求編號：%s"
+    "Hello %s," : "%s您好，",
+    "The meeting »%1$s« with %2$s was canceled." : "與 %2$s 的會議 %1$s 取消了",
+    "The meeting »%1$s« with %2$s was updated." : "與 %2$s 的會議 %1$s 有變動",
+    "%1$s invited you to »%2$s«" : "%1$s邀請您到%2$s",
+    "When:" : "時間"
 },
 "nplurals=1; plural=0;");
