@@ -38,6 +38,7 @@ OC.L10N.register(
     "Federated Cloud Sharing" : "Compartido en Cloud Federado",
     "Open documentation" : "Abrir documentación",
     "Adjust how people can share between servers." : "Ajusta cómo la gente puede compartir entre servidores.",
+    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Permitir a los usuarios de este servidor compartir con usuarios de otros servidores (esta opción también permite acceso de WebDAV a los elementos públicos compartidos)",
     "Allow users on this server to receive shares from other servers" : "Permitir a los usuarios de este servidor recibir de usuarios de otros servidores",
     "Allow users on this server to send shares to groups on other servers" : "Permitir a los usuarios de este servidor enviar a grupos de otros servidores",
     "Allow users on this server to receive group shares from other servers" : "Permitir a los usuarios de este servidor recibir de grupos de otros servidores",
@@ -50,8 +51,6 @@ OC.L10N.register(
     "Add to your website" : "Añadir a su sitio web",
     "Share with me via Nextcloud" : "Compartirlo conmigo vía Nextcloud",
     "HTML Code:" : "Código HTML:",
-    "You received \"%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Has recibido \"%3$s\" como un recurso compartido remoto desde %1$s (en nombre de %2$s)",
-    "You received \"%3$s\" as a remote share from %1$s" : "Has recibido \"%3$s\" como un compartido remoto de %1$s",
     "Allow users on this server to send shares to other servers" : "Permitir a los usuarios de este servidor compartir con usuarios de otros servidores"
 },
 "nplurals=2; plural=(n != 1);");
