@@ -5,11 +5,11 @@ OC.L10N.register(
     "Server is already in the list of trusted servers." : "сервер нь аль хэдийн найдвартай серверийн жагсаалтанд  байна",
     "No server to federate with found" : "Ямар ч холбооны сервер олдсонгүй ",
     "Could not add server" : " сервер нэмж чадаагүй ",
-    "Trusted servers" : "найдвартай сервер",
+    "Federation" : "холбоо",
     "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing." : "Холбоо нь хэрэглэгчийн санг солилцох бусад найдвартай серверүүд уруу холбогдох боломжийг олгоно. Жишээ нь үүнийг холбооны хуваарилалт авто бүрэн гадны хэрэглэгчдэд ашиглаж болно",
+    "Trusted servers" : "найдвартай сервер",
     "+ Add trusted server" : "+ найдвартай сервер нэмэх",
     "Trusted server" : "найдвартай сервер",
-    "Add" : "нэмэх",
-    "Federation" : "холбоо"
+    "Add" : "нэмэх"
 },
 "nplurals=2; plural=(n != 1);");
