@@ -192,11 +192,9 @@ OC.L10N.register(
     "Text file" : "Archivo de texto",
     "New text file.txt" : "Nuevo archivo.txt",
     "Unshare" : "Dejar de compartir",
-    "This group folder is full, files can not be updated or synced anymore!" : "Esta carpeta de grupo está llena, los archivos no pueden ser actualizados o sincronizados más.",
-    "This external storage is full, files can not be updated or synced anymore!" : "Este almacenamiento externo está lleno, los archivos no pueden ser subidos o sincronizados más.",
     "Storage of {owner} is almost full ({usedSpacePercent}%)" : "El espacio de {owner} está casi lleno en un ({usedSpacePercent}%)",
-    "This group folder is almost full ({usedSpacePercent}%)" : "Esta carpeta de grupo está casi llena ({usedSpacePercent}%)",
-    "This external storage is almost full ({usedSpacePercent}%)" : "Este almacenamiento externo está casi lleno ({usedSpacePercent}%)",
+    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)" : "La carpeta de grupo \"{mountPoint}\" está casi llena ({usedSpacePercent}%)",
+    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)" : "El almacenamiento externo \"{mountPoint}\" está casi lleno ({usedSpacePercent}%)",
     "Your storage is almost full ({usedSpacePercent}%)" : "Tu espacio está casi lleno, ({usedSpacePercent}%)",
     "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Un archivo o carpeta ha sido <strong>cambiado</strong> o <strong>renombrado</strong>",
     "A new file or folder has been <strong>created</strong>" : "Se ha <strong>creado</strong> un nuevo archivo o carpeta",
