@@ -1,19 +1,19 @@
 OC.L10N.register(
     "files",
     {
-    "Storage is temporarily not available" : "Biltegia ez dago erabilgarri aldi baterako",
+    "Storage is temporarily not available" : "Biltegia ez dago erabilgarri momentu honetan",
     "Storage invalid" : "Biltegi baliogabea",
     "Unknown error" : "Errore ezezaguna",
     "File could not be found" : "Ezin izan da fitxategia aurkitu",
-    "Move or copy" : "Lekuz aldatu edo kopiatu",
+    "Move or copy" : "Mugitu edo kopiatu",
     "Download" : "Deskargatu",
     "Delete" : "Ezabatu",
     "Home" : "Etxea",
     "Close" : "Itxi",
     "Favorites" : "Gogokoak",
     "Could not create folder \"{dir}\"" : "Ezin izan da \"{dir}\" karpeta sortu",
-    "This will stop your current uploads." : "Honek zure uneko kargatzeak geldituko ditu.",
-    "Upload cancelled." : "Kargatzea bertan behera utzi da.",
+    "This will stop your current uploads." : "Honek martxan dauzkazun igoerak geldituko ditu.",
+    "Upload cancelled." : "Igoera bertan behera utzi da.",
     "Processing files …" : "Fitxategiak prozesatzen...",
     "…" : "…",
     "Unable to upload {filename} as it is a directory or has 0 bytes" : "Ezin da {filename} kargatu karpeta bat delako edo 0 byte dituelako",
@@ -25,6 +25,7 @@ OC.L10N.register(
     "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} / {totalSize} ({bitrate})",
     "Uploading that item is not supported" : "Ez da onartzen elementu hori kargatzea",
     "Target folder does not exist any more" : "Helburuko karpeta ez da existitzen jadanik",
+    "Operation is blocked by access control" : "Sarbide kontrolak eragiketa blokeatu du",
     "Error when assembling chunks, status code {status}" : "Errorea zatiak elkartzean, egoera kodea {status}",
     "Actions" : "Ekintzak",
     "Rename" : "Berrizendatu",
@@ -34,6 +35,7 @@ OC.L10N.register(
     "Delete file" : "Ezabatu fitxategia",
     "Delete folder" : "Ezabatu karpeta",
     "Disconnect storage" : "Deskonektatu biltegia",
+    "Leave this share" : "Utzi partekatze hau",
     "Could not load info for file \"{file}\"" : "Ezin izan da \"{file}\" fitxategiaren informazioa kargatu",
     "Files" : "Fitxategiak",
     "Details" : "Xehetasunak",
@@ -59,6 +61,7 @@ OC.L10N.register(
     "Could not fetch file details \"{file}\"" : "Ezin izan dira \"{file}\" fitxategiaren xehetasunak eskuratu",
     "Error deleting file \"{fileName}\"." : "Errorea \"{fileName}\" fitxategia ezabatzerakoan.",
     "No search results in other folders for {tag}{filter}{endtag}" : "Ez da '{tag}{filter}{endtag}' bilaketarako emaitzarik aurkitu beste karpetetan",
+    "Enter more than two characters to search in other folders" : "Sartu bi karaktere baino gehiago beste karpetetan bilatu ahal izateko",
     "Name" : "Izena",
     "Size" : "Tamaina",
     "Modified" : "Aldatuta",
@@ -77,7 +80,13 @@ OC.L10N.register(
     "\"/\" is not allowed inside a file name." : "\"/\" ez da onartzen fitxategi-izenen barnean.",
     "\"{name}\" is not an allowed filetype" : "\"{name}\" fitxategi-mota ez da onartzen",
     "Storage of {owner} is full, files can not be updated or synced anymore!" : "{owner} erabiltzailearen biltegia beteta dago, fitxategiak ezin dira eguneratu edo sinkronizatu jada!",
+    "Group folder \"{mountPoint}\" is full, files can not be updated or synced anymore!" : "\"{mountPoint}\" talde karpeta beteta dago, ezin da fitxategirik eguneratu edo sinkronizatu gehiago!",
+    "External storage \"{mountPoint}\" is full, files can not be updated or synced anymore!" : "\"{mountPoint}\" kanpoko biltegia beteta dago, ezin da fitxategirik eguneratu edo sinkronizatu gehiago!",
     "Your storage is full, files can not be updated or synced anymore!" : "Zure biltegia beteta dago, ezin duzu fitxategirik igo edo sinkronizatu jada!",
+    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "{owner}-(r)en biltegia betetzear dago ({usedSpacePercent}%).",
+    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "\"{mountPoint}\" talde karpeta betetzear dago ({usedSpacePercent}%).",
+    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "\"{mountPoint}\" kanpoko biltegia betetzear dago ({usedSpacePercent}%).",
+    "Your storage is almost full ({usedSpacePercent}%)." : "Zure biltegia betetzear dago ({usedSpacePercent}%).",
     "_matches '{filter}'_::_match '{filter}'_" : ["bat dator '{filter}' iragazkiarekin","bat datoz '{filter}' iragazkiarekin"],
     "View in folder" : "Ikusi karpetan",
     "Copied!" : "Kopiatua!",
@@ -127,6 +136,7 @@ OC.L10N.register(
     "{user} moved {oldfile} to {newfile}" : "{user} erabiltzaileak {oldfile} lekuz aldatu du {newfile}(e)ra",
     "A file has been added to or removed from your <strong>favorites</strong>" : "Fitxategi bat gehitu edo kendu da zure <strong>gogokoetatik</strong>",
     "A file or folder has been <strong>changed</strong>" : "Fitxategi edo karpeta bat <strong>aldatu da</strong>",
+    "A favorite file or folder has been <strong>changed</strong>" : "Gogoko fitxategi edo karpeta bat <strong>aldatu</strong> egin da.",
     "All files" : "Fitxategi guztiak",
     "Unlimited" : "Mugarik gabe",
     "Upload (max. %s)" : "Kargatu (%s gehienez)",
@@ -183,6 +193,8 @@ OC.L10N.register(
     "New text file.txt" : "Testu-fitxategi berria.txt",
     "Unshare" : "Ez partekatu",
     "Storage of {owner} is almost full ({usedSpacePercent}%)" : "{owner} erabiltzailearen biltegia ia beteta dago ({usedSpacePercent}%)",
+    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)" : "\"{mountPoint}\" talde karpeta betetzear dago ({usedSpacePercent}%)",
+    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)" : "\"{mountPoint}\" kanpoko biltegia betetzear dago ({usedSpacePercent}%)",
     "Your storage is almost full ({usedSpacePercent}%)" : "Zure biltegia ia beteta dago (%{usedSpacePercent})",
     "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Fitxategi edo karpeta bat <strong>aldatu</strong> edo <strong>berrizendatu</strong> da",
     "A new file or folder has been <strong>created</strong>" : "Fitxategi edo karpeta berri bat <strong>sortu</strong> da",
