@@ -4,15 +4,13 @@ OC.L10N.register(
     "Storage is temporarily not available" : "Gagnageymsla ekki tiltæk í augnablikinu",
     "Storage invalid" : "Ógild geymsla",
     "Unknown error" : "Óþekkt villa",
-    "All files" : "Allar skrár",
-    "Recent" : "Nýlegt",
-    "Favorites" : "Eftirlæti",
     "File could not be found" : "Skrá finnst ekki",
     "Move or copy" : "Færa eða afrita",
     "Download" : "Niðurhal",
     "Delete" : "Eyða",
     "Home" : "Heim",
     "Close" : "Loka",
+    "Favorites" : "Eftirlæti",
     "Could not create folder \"{dir}\"" : "Gat ekki búið til möppuna \"{dir}\"",
     "This will stop your current uploads." : "Þetta mun stöðva núverandi innsendingar þínar.",
     "Upload cancelled." : "Hætt við innsendingu.",
@@ -36,7 +34,6 @@ OC.L10N.register(
     "Delete file" : "Eyða skrá",
     "Delete folder" : "Eyða möppu",
     "Disconnect storage" : "Aftengja geymslu",
-    "Unshare" : "Hætta deilingu",
     "Could not load info for file \"{file}\"" : "Gat ekki lesið upplýsingar um skrána \"{file}\"",
     "Files" : "Skrár",
     "Details" : "Nánar",
@@ -80,8 +77,6 @@ OC.L10N.register(
     "\"{name}\" is not an allowed filetype" : "\"{name}\" er ógild skráartegund",
     "Storage of {owner} is full, files can not be updated or synced anymore!" : "Geymslupláss {owner} er fullt, ekki er lengur hægt að uppfæra eða samstilla skrár!",
     "Your storage is full, files can not be updated or synced anymore!" : "Geymsluplássið þitt er fullt, ekki er lengur hægt að uppfæra eða samstilla skrár!",
-    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Geymslupláss {owner} er næstum fullt ({usedSpacePercent}%)",
-    "Your storage is almost full ({usedSpacePercent}%)" : "Geymsluplássið þitt er næstum fullt ({usedSpacePercent}%)",
     "_matches '{filter}'_::_match '{filter}'_" : ["samsvarar '{filter}'","samsvara '{filter}'"],
     "View in folder" : "Skoða í möppu",
     "Copied!" : "Afritað!",
@@ -93,6 +88,7 @@ OC.L10N.register(
     "You can only favorite a single file or folder at a time" : "Þú getur aðeins bætt einni skrá eða möppu í einu í eftilæti",
     "New folder" : "Ný mappa",
     "Upload file" : "Senda inn skrá",
+    "Recent" : "Nýlegt",
     "Not favorited" : "Ekki í eftirlætum",
     "Remove from favorites" : "Fjarlægja úr eftirlætum",
     "Add to favorites" : "Bæta í eftirlæti",
@@ -129,25 +125,36 @@ OC.L10N.register(
     "You moved {oldfile} to {newfile}" : "Þú færðir {oldfile} í {newfile}",
     "{user} moved {oldfile} to {newfile}" : "{user} færði {oldfile} í {newfile}",
     "A file has been added to or removed from your <strong>favorites</strong>" : "Skrá var bætt við eða hún fjarlægð úr <strong>eftirlætum</strong>",
-    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Skrá eða möppu hefur verið <strong>breytt</strong> eða verið <strong>endurnefnt</strong>",
-    "A new file or folder has been <strong>created</strong>" : "Skjal eða mappa hefur verið <strong>búin til</strong>",
-    "A file or folder has been <strong>deleted</strong>" : "Skjali eða möppu hefur verið  <strong>eytt</strong>",
-    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Takmarka tilkynningar um gerð og breytingar á <strong>eftirlætisskrám</strong> <em>(einungis streymi)</em>",
-    "A file or folder has been <strong>restored</strong>" : "Skjal eða mappa hefur verið <strong>endurheimt</strong>",
+    "A file or folder has been <strong>changed</strong>" : "Skjali eða möppu hefur verið <strong>breytt</strong>",
+    "All files" : "Allar skrár",
     "Unlimited" : "Ótakmarkað",
     "Upload (max. %s)" : "Senda inn (hám. %s)",
     "Accept" : "Samþykkja",
     "Reject" : "Hafna",
+    "Ownership transfer failed" : "Millifærsla eignarhalds mistókst",
+    "Ownership transfer done" : "Millifærslu eignarhalds er lokið",
+    "in %s" : "í %s",
     "File Management" : "Skráastjórnun",
+    "Transfer ownership of a file or folder" : "Millifæra eignarhald skráar eða möppu",
+    "Choose file or folder to transfer" : "Veldu skrá eða möppu til að millifæra",
     "Change" : "Breyta",
+    "New owner" : "Nýr eigandi",
+    "Search users" : "Leita að notendum",
+    "Choose a file or folder to transfer" : "Veldu skrá eða möppu til að millifæra",
+    "Transfer" : "Færa",
+    "Transfer {path} to {userid}" : "Færa {path} til {userid}",
+    "Invalid path selected" : "Ógild slóð valin",
+    "Ownership transfer request sent" : "Beiðni um millifærslu eignarhalds send",
+    "Cannot transfer ownership of a file or folder you don't own" : "Ekki er hægt að millifæra eignarhald á skrá eða möppu sem þú átt ekki",
     "Tags" : "Merki",
+    "Error while loading the file data" : "Villa við að hlaða inn skráagögnum",
     "%s used" : "%s notað",
     "%s%% of %s used" : "%s%% af %s notað",
     "%1$s of %2$s used" : "%1$s af %2$s notað",
     "Settings" : "Stillingar",
     "Show hidden files" : "Sýna faldar skrár",
     "WebDAV" : "WebDAV",
-    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Notaðu þetta vistfang til að <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">nálgast skrárnar þínar með WebDAV</a>",
+    "Use this address to access your Files via WebDAV" : "Notaðu þetta vistfang til að nálgast skrárnar þínar með WebDAV",
     "Toggle grid view" : "Víxla reitasýn af/á",
     "No files in here" : "Engar skrár hér",
     "Upload some content or sync with your devices!" : "Sendu inn eitthvað efni eða samstilltu við tækin þín!",
@@ -163,9 +170,18 @@ OC.L10N.register(
     "Shared with you" : "Deilt með þér",
     "Shared by link" : "Deilt með tengli",
     "Deleted shares" : "Eyddar sameignir",
+    "Pending shares" : "Sameignir í bið",
     "Text file" : "Textaskrá",
     "New text file.txt" : "Ný textaskrá.txt",
-    "%s of %s used" : "%s af %s notað",
-    "%1$s%% of %2$s used" : "%1$s%% af %2$s notað"
+    "Unshare" : "Hætta deilingu",
+    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Geymslupláss {owner} er næstum fullt ({usedSpacePercent}%)",
+    "Your storage is almost full ({usedSpacePercent}%)" : "Geymsluplássið þitt er næstum fullt ({usedSpacePercent}%)",
+    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Skrá eða möppu hefur verið <strong>breytt</strong> eða verið <strong>endurnefnt</strong>",
+    "A new file or folder has been <strong>created</strong>" : "Skjal eða mappa hefur verið <strong>búin til</strong>",
+    "A file or folder has been <strong>deleted</strong>" : "Skjali eða möppu hefur verið  <strong>eytt</strong>",
+    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Takmarka tilkynningar um gerð og breytingar á <strong>eftirlætisskrám</strong> <em>(einungis streymi)</em>",
+    "A file or folder has been <strong>restored</strong>" : "Skjal eða mappa hefur verið <strong>endurheimt</strong>",
+    "Cannot transfter ownership of a file or folder you don't own" : "Ekki er hægt að millifæra eignarhald á skrá eða möppu sem þú átt ekki",
+    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Notaðu þetta vistfang til að <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">nálgast skrárnar þínar með WebDAV</a>"
 },
 "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
