@@ -4,15 +4,13 @@ OC.L10N.register(
     "Storage is temporarily not available" : "Glabātuve īslaicīgi nav pieejama",
     "Storage invalid" : "Nepareiza glabātuve",
     "Unknown error" : "Nezināma kļūda",
-    "All files" : "Visas datnes",
-    "Recent" : "Nesenās",
-    "Favorites" : "Iecienītie",
     "File could not be found" : "Datni nevar atrast",
     "Move or copy" : "Pārvietot vai kopēt",
     "Download" : "Lejupielādēt",
     "Delete" : "Dzēst",
     "Home" : "Mājas",
     "Close" : "Aizvērt",
+    "Favorites" : "Iecienītie",
     "Could not create folder \"{dir}\"" : "Nevarēja izveidot mapi \"{dir}\"",
     "This will stop your current uploads." : "Tādējādi tiks pārtraukta jūsu pašreizējā augšupielāde.",
     "Upload cancelled." : "Augšupielāde ir atcelta.",
@@ -32,7 +30,6 @@ OC.L10N.register(
     "Delete file" : "Dzēst datni",
     "Delete folder" : "Dzēst mapi",
     "Disconnect storage" : "Atvienot glabātuvi",
-    "Unshare" : "Pārtraukt koplietošanu",
     "Could not load info for file \"{file}\"" : "Nevar ielādēt informāciju par datni \"{file}\"",
     "Files" : "Datnes",
     "Details" : "Detaļas",
@@ -65,10 +62,10 @@ OC.L10N.register(
     "New" : "Jauna",
     "\"{name}\" is an invalid file name." : "\"{name}\" ir nepareizs datnes nosaukums.",
     "File name cannot be empty." : "Datnes nosaukums nevar būt tukšs.",
+    "\"/\" is not allowed inside a file name." : "\"/\" nav atļauts faila nosaukumā.",
+    "\"{name}\" is not an allowed filetype" : "\"{name}\" nav atļauts faila tips",
     "Storage of {owner} is full, files can not be updated or synced anymore!" : "{owner} glabātuve ir pilna, datnes vairs nevar augšupielādēt vai sinhronizēt!",
     "Your storage is full, files can not be updated or synced anymore!" : "Jūsu glabātuve ir pilna, datnes vairs nevar augšupielādēt vai sinhronizēt!",
-    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "{owner} glabātuve ir gandrīz pilna ({usedSpacePercent}%)",
-    "Your storage is almost full ({usedSpacePercent}%)" : "Jūsu glabātuve ir gandrīz pilna ({usedSpacePercent}%)",
     "_matches '{filter}'_::_match '{filter}'_" : ["atrasts pēc '{filter}'","atrasts pēc '{filter}'","atrasti pēc '{filter}'"],
     "View in folder" : "Skatīt mapē",
     "Copied!" : "Nokopēts!",
@@ -78,6 +75,7 @@ OC.L10N.register(
     "Favorite" : "Iecienītais",
     "New folder" : "Jauna mape",
     "Upload file" : "Augšupielādēt datni",
+    "Recent" : "Nesenās",
     "Remove from favorites" : "Noņemt no favorītiem",
     "Add to favorites" : "Pievienot izlasei",
     "An error occurred while trying to update the tags" : "Notika kļūda mēģinot atjaunot birkas",
@@ -107,14 +105,12 @@ OC.L10N.register(
     "You moved {oldfile} to {newfile}" : "Pārvietoji {oldfile} uz {newfile}",
     "{user} moved {oldfile} to {newfile}" : "{user} pārvietoja {oldfile} uz {newfile}",
     "A file has been added to or removed from your <strong>favorites</strong>" : "Datne ir pievienota vai noņemta no jūsu <strong>favorītiem</strong>",
-    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Datne vai mape tika <strong>mainīta</strong> vai <strong>pārsaukta</strong>",
-    "A new file or folder has been <strong>created</strong>" : "<strong>Izveidota</strong> jauna datne vai mape",
-    "A file or folder has been <strong>deleted</strong>" : "<strong>Dzēsta</strong> datne vai mape",
-    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limitēt ziņojumus par jūsu <strong>iecienīto datņu</strong> izveidošanu un izmaiņām <em>(tikai datu straumei)</em>",
-    "A file or folder has been <strong>restored</strong>" : "<strong>Atjaunota</strong> datne vai mape",
+    "A file or folder has been <strong>changed</strong>" : "<strong>Izmainīta</strong> datne vai mape",
+    "All files" : "Visas datnes",
     "Unlimited" : "Neierobežota",
     "Upload (max. %s)" : "Augšupielādēt (maks. %s)",
     "Accept" : "Akceptēt",
+    "in %s" : "iekš %s",
     "Change" : "Mainīt",
     "Tags" : "Birkas",
     "%s used" : "%s izmantoti",
@@ -136,6 +132,14 @@ OC.L10N.register(
     "Shared by link" : "Koplietots ar saiti",
     "Deleted shares" : "Dzēstās koplietotnes",
     "Text file" : "Teksta datne",
-    "New text file.txt" : "Jauna teksta datne.txt"
+    "New text file.txt" : "Jauna teksta datne.txt",
+    "Unshare" : "Pārtraukt koplietošanu",
+    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "{owner} glabātuve ir gandrīz pilna ({usedSpacePercent}%)",
+    "Your storage is almost full ({usedSpacePercent}%)" : "Jūsu glabātuve ir gandrīz pilna ({usedSpacePercent}%)",
+    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Datne vai mape tika <strong>mainīta</strong> vai <strong>pārsaukta</strong>",
+    "A new file or folder has been <strong>created</strong>" : "<strong>Izveidota</strong> jauna datne vai mape",
+    "A file or folder has been <strong>deleted</strong>" : "<strong>Dzēsta</strong> datne vai mape",
+    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limitēt ziņojumus par jūsu <strong>iecienīto datņu</strong> izveidošanu un izmaiņām <em>(tikai datu straumei)</em>",
+    "A file or folder has been <strong>restored</strong>" : "<strong>Atjaunota</strong> datne vai mape"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
