@@ -30,7 +30,6 @@ OC.L10N.register(
     "Copy" : "کاپي کول",
     "Choose target folder" : "د ورانتقالېدو فولډر ټاکل",
     "Open" : "پرانيستل",
-    "Unshare" : "له شرېکوالي ويستل",
     "Could not load info for file \"{file}\"" : "د \"{file}\" فایل معلومات نشي پرانيستل کېدای",
     "Files" : "فایلونه",
     "Details" : "معلومات",
@@ -69,7 +68,6 @@ OC.L10N.register(
     "File name cannot be empty." : "فایل نوم تش نشي کېدای",
     "\"/\" is not allowed inside a file name." : "د فایل په نوم کې \"/\" نشئ کارولای",
     "\"{name}\" is not an allowed filetype" : "\"{name}\" ډول فایلونو اجازه نشته",
-    "Your storage is almost full ({usedSpacePercent}%)" : "({usedSpacePercent}%) ستاسې ذخیره تقریبا ډکه ده ",
     "_matches '{filter}'_::_match '{filter}'_" : ["'{filter}' په څېر","'{filter}' په څېر"],
     "View in folder" : "په فولډر کې کتل",
     "Copied!" : "کاپي شو!",
@@ -136,6 +134,8 @@ OC.L10N.register(
     "Shared by link" : "په لېنک شريک شوي",
     "Deleted shares" : "ړنګ شوي لېنکونه",
     "Text file" : "متن فایل",
-    "New text file.txt" : "New text file.txt"
+    "New text file.txt" : "New text file.txt",
+    "Unshare" : "له شرېکوالي ويستل",
+    "Your storage is almost full ({usedSpacePercent}%)" : "({usedSpacePercent}%) ستاسې ذخیره تقریبا ډکه ده "
 },
 "nplurals=2; plural=(n != 1);");
