@@ -192,11 +192,7 @@ OC.L10N.register(
     "Text file" : "Arquivo texto",
     "New text file.txt" : "Novo texto file.txt",
     "Unshare" : "Descompartilhar",
-    "This group folder is full, files can not be updated or synced anymore!" : "Esta pasta do grupo está cheia, os arquivos não podem mais ser atualizados ou sincronizados!",
-    "This external storage is full, files can not be updated or synced anymore!" : "Este armazenamento externo está cheio, os arquivos não podem mais ser atualizados ou sincronizados!",
     "Storage of {owner} is almost full ({usedSpacePercent}%)" : "O armazenamento do {owner} está quase cheio ({usedSpacePercent}%)",
-    "This group folder is almost full ({usedSpacePercent}%)" : "Esta pasta de grupo está quase cheia ({usedSpacePercent}%)",
-    "This external storage is almost full ({usedSpacePercent}%)" : "Este armazenamento externo está quase cheio ({usedSpacePercent}%)",
     "Your storage is almost full ({usedSpacePercent}%)" : "Seu armazenamento está quase cheio ({usedSpacePercent}%)",
     "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Um arquivo ou pasta foi <strong>alterado</strong> ou <strong>renomeado</strong>",
     "A new file or folder has been <strong>created</strong>" : "Um novo arquivo ou pasta foi <strong>criado</strong>",
