@@ -4,17 +4,16 @@ OC.L10N.register(
     "Storage is temporarily not available" : "Armazenamento temporariamente indisponível",
     "Storage invalid" : "Armazenamento inválido",
     "Unknown error" : "Erro desconhecido",
-    "All files" : "Todos os ficheiros",
-    "Recent" : "Recentes",
-    "Favorites" : "Favoritos",
     "File could not be found" : "O ficheiro não foi encontrado",
     "Move or copy" : "Mover ou copiar",
     "Download" : "Transferir",
     "Delete" : "Eliminar",
     "Home" : "Início",
     "Close" : "Fechar",
+    "Favorites" : "Favoritos",
     "Could not create folder \"{dir}\"" : "Não foi possível criar a pasta \"{dir}\"",
     "Upload cancelled." : "Envio cancelado.",
+    "Processing files …" : "A processar os ficheiros ...",
     "…" : "...",
     "Unable to upload {filename} as it is a directory or has 0 bytes" : "Não é possível enviar {filename}, porque este é uma diretoria ou tem 0 bytes",
     "Not enough free space, you are uploading {size1} but only {size2} is left" : "Não existe espaço suficiente, está a enviar {size1} mas resta apenas {size2}",
@@ -30,7 +29,6 @@ OC.L10N.register(
     "Delete file" : "Eliminar ficheiro",
     "Delete folder" : "Eliminar pasta",
     "Disconnect storage" : "Desligue o armazenamento",
-    "Unshare" : "Cancelar partilha",
     "Could not load info for file \"{file}\"" : "Não foi possível carregar informações do ficheiro \"{file}\"",
     "Files" : "Ficheiros",
     "Details" : "Detalhes",
@@ -73,18 +71,18 @@ OC.L10N.register(
     "\"{name}\" is not an allowed filetype" : "\"{name}\" não é um tipo de ficheiro permitido",
     "Storage of {owner} is full, files can not be updated or synced anymore!" : "O armazenamento de {owner} está cheio. Os ficheiros já não podem ser atualizados ou sincronizados!",
     "Your storage is full, files can not be updated or synced anymore!" : "O seu armazenamento está cheio, os ficheiros já não podem ser atualizados ou sincronizados.",
-    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "O armazenamento de {owner} está quase cheio ({usedSpacePercent}%)",
-    "Your storage is almost full ({usedSpacePercent}%)" : "O seu armazenamento está quase cheio ({usedSpacePercent}%)",
     "_matches '{filter}'_::_match '{filter}'_" : ["corresponde a '{filter}'","correspondem a '{filter}'"],
     "View in folder" : "Ver na pasta",
     "Copied!" : "Copiado!",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Copiar hiperligação directa (apenas funciona para utilizadores que tenham acesso a este ficheiro/pasta)",
+    "Copy direct link (only works for users who have access to this file/folder)" : "Copiar hiperligação direta (apenas funciona para os utilizadores que tenham acesso a este ficheiro/pasta)",
     "Path" : "Caminho",
     "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
     "Favorited" : "Nos Favoritos",
     "Favorite" : "Favorito",
+    "You can only favorite a single file or folder at a time" : "Apenas pode definir como favorito um ficheiro ou uma pasta de cada vez",
     "New folder" : "Nova pasta",
     "Upload file" : "Enviar ficheiro",
+    "Recent" : "Recentes",
     "Not favorited" : "Não favorito",
     "Remove from favorites" : "Remover dos favoritos",
     "Add to favorites" : "Adicionar aos favoritos",
@@ -103,6 +101,7 @@ OC.L10N.register(
     "\"remote user\"" : "\"utilizador remoto\"",
     "You created {file}" : "Criou {file}",
     "{user} created {file}" : "{user} criou {file}",
+    "{user} created an encrypted file in {file}" : "{user} criou um ficheiro encriptado em {file}",
     "{file} was created in a public folder" : "{file} foi criado numa pasta pública",
     "You changed {file}" : "Modificou {file}",
     "{user} changed {file}" : "{user} modificou {file}",
@@ -115,20 +114,18 @@ OC.L10N.register(
     "You moved {oldfile} to {newfile}" : "Moveu {oldfile} para {newfile}",
     "{user} moved {oldfile} to {newfile}" : "{user} moveu {oldfile} para {newfile}",
     "A file has been added to or removed from your <strong>favorites</strong>" : "Um ficheiro foi adicionado ou removido dos seus <strong>favoritos</strong>",
-    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Um ficheiro ou pasta foram <strong>modificados</strong> ou <strong>renomeados</strong>",
-    "A new file or folder has been <strong>created</strong>" : "Foi <strong>criado</strong> um novo ficheiro ou pasta",
-    "A file or folder has been <strong>deleted</strong>" : "Um ficheiro ou pasta foram <strong>apagados</strong>",
-    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limite as notificações sobre a criação e alterações para os seus <strong>ficheiros favoritos</strong> <em>(apenas Emissão)</em>",
-    "A file or folder has been <strong>restored</strong>" : "Um ficheiro ou pasta foram <strong>restaurados</strong>",
+    "A file or folder has been <strong>changed</strong>" : "Foi <strong>alterado</strong> um ficheiro ou pasta",
+    "All files" : "Todos os ficheiros",
     "Unlimited" : "Ilimitado",
     "Upload (max. %s)" : "Envio (máx. %s)",
     "Accept" : "Aceitar",
+    "in %s" : "em %s",
+    "Tags" : "Etiquetas",
     "%s used" : "%s utilizado",
     "%1$s of %2$s used" : "Usado %1$s de %2$s",
     "Settings" : "Configurações",
     "Show hidden files" : "Mostrar ficheiros ocultos",
     "WebDAV" : "WebDAV",
-    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Utilize este endereço para <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">aceder aos seus ficheiros por WebDAV</a>",
     "No files in here" : "Nenhuns ficheiros aqui",
     "Upload some content or sync with your devices!" : "Envie algum conteúdo ou sincronize com os seus dispositivos!",
     "No entries found in this folder" : "Não foram encontradas entradas nesta pasta",
@@ -137,7 +134,6 @@ OC.L10N.register(
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Os ficheiros que está a tentar enviar excedem o tamanho máximo para os envios de ficheiro neste servidor.",
     "No favorites yet" : "Sem favoritos",
     "Files and folders you mark as favorite will show up here" : "Os ficheiros e pastas que marcou como favoritos serão mostrados aqui",
-    "Tags" : "Etiquetas",
     "Deleted files" : "Ficheiros eliminados",
     "Shares" : "Partilhas",
     "Shared with others" : "Partilhado com terceiros",
@@ -145,13 +141,14 @@ OC.L10N.register(
     "Shared by link" : "Partilhado por hiperligação",
     "Text file" : "Ficheiro de Texto",
     "New text file.txt" : "Novo texto ficheiro.txt",
-    "File handling" : "Utilização do ficheiro",
-    "Maximum upload size" : "Tamanho máximo de envio",
-    "max. possible: " : "Máx. possível: ",
-    "Save" : "Guardar",
-    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Com o PHP-FPM poderá demorar 5 minutos até que as alterações sejam aplicadas.",
-    "Missing permissions to edit from here." : "Faltam permissões para editar a partir daqui.",
-    "Cancel upload" : "Cancelar envio",
-    "%s of %s used" : "%s de %s utilizado"
+    "Unshare" : "Cancelar partilha",
+    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "O armazenamento de {owner} está quase cheio ({usedSpacePercent}%)",
+    "Your storage is almost full ({usedSpacePercent}%)" : "O seu armazenamento está quase cheio ({usedSpacePercent}%)",
+    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Um ficheiro ou pasta foram <strong>modificados</strong> ou <strong>renomeados</strong>",
+    "A new file or folder has been <strong>created</strong>" : "Foi <strong>criado</strong> um novo ficheiro ou pasta",
+    "A file or folder has been <strong>deleted</strong>" : "Um ficheiro ou pasta foram <strong>apagados</strong>",
+    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limite as notificações sobre a criação e alterações para os seus <strong>ficheiros favoritos</strong> <em>(apenas Emissão)</em>",
+    "A file or folder has been <strong>restored</strong>" : "Um ficheiro ou pasta foram <strong>restaurados</strong>",
+    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Utilize este endereço para <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">aceder aos seus ficheiros por WebDAV</a>"
 },
 "nplurals=2; plural=(n != 1);");
