@@ -25,6 +25,7 @@ OC.L10N.register(
     "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} / {totalSize} ({bitrate})",
     "Uploading that item is not supported" : "不支持上传此项目",
     "Target folder does not exist any more" : "目标文件夹不存在",
+    "Operation is blocked by access control" : "操作被访问控制阻止",
     "Error when assembling chunks, status code {status}" : "组装块时发生错误，状态码 {status}",
     "Actions" : "操作",
     "Rename" : "重命名",
@@ -34,6 +35,7 @@ OC.L10N.register(
     "Delete file" : "删除文件",
     "Delete folder" : "删除文件夹",
     "Disconnect storage" : "断开与存储空间的连接",
+    "Leave this share" : "离开这个共享",
     "Could not load info for file \"{file}\"" : "无法加载文件 \"{file}\" 的信息",
     "Files" : "文件",
     "Details" : "详细信息",
@@ -78,7 +80,13 @@ OC.L10N.register(
     "\"/\" is not allowed inside a file name." : "文件名不能包含“/”",
     "\"{name}\" is not an allowed filetype" : "\"{name}\" 不是允许的文件类型",
     "Storage of {owner} is full, files can not be updated or synced anymore!" : "{owner} 的存储空间已满，文件将无法更新或同步！",
+    "Group folder \"{mountPoint}\" is full, files can not be updated or synced anymore!" : "组文件夹 \"{mountPoint}\" 已满，无法再更新或同步文件！",
+    "External storage \"{mountPoint}\" is full, files can not be updated or synced anymore!" : "外部存储 \"{mountPoint}\" 已满，无法再更新或同步文件！",
     "Your storage is full, files can not be updated or synced anymore!" : "您的存储空间已满，文件将无法更新或同步！",
+    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "{owner} 的存储空间几乎已满 ({usedSpacePercent}%)。",
+    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "组文件夹 \"{mountPoint}\" 的存储空间几乎已满 ({usedSpacePercent}%)。",
+    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "外部存储 \"{mountPoint}\" 的存储空间几乎已满 ({usedSpacePercent}%)。",
+    "Your storage is almost full ({usedSpacePercent}%)." : "您的存储空间几乎已满（{usedSpacePercent}%）",
     "_matches '{filter}'_::_match '{filter}'_" : ["匹配 '{filter}'"],
     "View in folder" : "在文件夹中查看",
     "Copied!" : "已复制",
@@ -128,6 +136,7 @@ OC.L10N.register(
     "{user} moved {oldfile} to {newfile}" : "{user} 将 {oldfile} 移动到了 {newfile}",
     "A file has been added to or removed from your <strong>favorites</strong>" : "文件已经添加或删除到您的 <strong>收藏夹</strong> 中",
     "A file or folder has been <strong>changed</strong>" : "文件/文件夹已经 <strong>修改</strong>",
+    "A favorite file or folder has been <strong>changed</strong>" : "一个文件或文件夹已<strong>修改</strong>。",
     "All files" : "全部文件",
     "Unlimited" : "无限制",
     "Upload (max. %s)" : "上传 （最大 %s）",
@@ -184,6 +193,8 @@ OC.L10N.register(
     "New text file.txt" : "新建文本文档.txt",
     "Unshare" : "取消共享",
     "Storage of {owner} is almost full ({usedSpacePercent}%)" : "{owner} 的存储空间即将用完（{usedSpacePercent}%）",
+    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)" : "组文件夹 \"{mountPoint}\" 的存储空间几乎已满 ({usedSpacePercent}%)",
+    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)" : "外部存储 \"{mountPoint}\" 的存储空间几乎已满 ({usedSpacePercent}%)",
     "Your storage is almost full ({usedSpacePercent}%)" : "您的存储空间即将用完（{usedSpacePercent}%）",
     "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "文件/文件夹已经 <strong>更改</strong> 或者 <strong>重命名</strong>",
     "A new file or folder has been <strong>created</strong>" : "新的文件或文件夹已被 <strong>创建</strong>",
