@@ -45,9 +45,7 @@ OC.L10N.register(
     "Invalid backend or authentication mechanism class" : "Netinkama programinio kodo klasė realizuoja prisijungimo mechanizmą",
     "Invalid mount point" : "Neteisingas prijungimo taškas",
     "Objectstore forbidden" : "Objektų saugykla yra neprieinama",
-    "Invalid storage backend \"%s\"" : "Netinkama saugyklos posistemė \"%s\"",
-    "Not permitted to use backend \"%s\"" : "Neleidžiama naudoti posistemės \"%s\"",
-    "Not permitted to use authentication mechanism \"%s\"" : "Neleidžiama naudoti prisijungimo mechanizmo \"%s\"",
+    "Not permitted to use authentication mechanism \"%s\"" : "Neleidžiama naudoti tapatybės nustatymo mechanizmo „%s“",
     "Unsatisfied backend parameters" : " Netinkami posistemės parametrai",
     "Unsatisfied authentication mechanism parameters" : "Netinkami parametrai perduoti į prisijungimo mechanizmą",
     "Insufficient data: %s" : "Trūksta duomenų: %s",
@@ -105,7 +103,6 @@ OC.L10N.register(
     "Timeout" : "Pasibaigė laikas",
     "SMB / CIFS using OC login" : "SMB / CIFS, naudojant OC prisijungimą",
     "Username as share" : "Dalinimosi vardas kaip ir vartotojo vardas",
-    "OpenStack Object Storage" : "Objektų saugykla \"OpenStack\"",
     "Service name" : "Paslaugos vardas",
     "Request timeout (seconds)" : "Prisijungimo laikas (sekundėmis)",
     "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "cURL palaikymas yra neįjungtas arba neįdiegtas į PHP. %s prijungimas neįmanomas. Paprašykite sistemos administratoriaus pagalbos.",
