@@ -1,23 +1,27 @@
 OC.L10N.register(
     "files_sharing",
     {
-    "Shared with others" : "Compartido con otros",
     "Shared with you" : "Compartido contigo",
-    "Shared by link" : "Compartido por liga",
     "Nothing shared with you yet" : "Nada ha sido compartido contigo aún",
     "Files and folders others share with you will show up here" : "Los archivos y carpetas que sean compartidos contigo se mostrarán aquí",
+    "Shared with others" : "Compartido con otros",
     "Nothing shared yet" : "Nada compartido aún",
     "Files and folders you share will show up here" : "Los archivos y carpetas que compartas se mostrarán aquí",
+    "Shared by link" : "Compartido por liga",
     "No shared links" : "No hay ligas compartidas",
     "Files and folders you share by link will show up here" : "Los archivos y carpetas que compartas por ligas se mostrarán aquí",
+    "Shares" : "Elementos compartidos",
+    "Restore" : "Restaurar",
+    "error" : "error",
+    "Move or copy" : "Mover o copiar",
+    "Download" : "Descargar",
+    "Delete" : "Borrar",
     "You can upload into this folder" : "Puedes cargar archivos dentro de esta carpeta",
     "No compatible server found at {remote}" : "No se encontró un servidor compatible en {remote}",
     "Invalid server URL" : "URL del servidor inválido",
     "Failed to add the public link to your Nextcloud" : "Se presentó una falla al agregar la liga pública a tu Nextcloud",
-    "Share" : "Compartir",
     "No expiration date set" : "No se ha establecido la fecha de expiración",
     "Shared by" : "Compartido por",
-    "Sharing" : "Compartiendo",
     "File shares" : "Archivos compartidos",
     "Downloaded via public link" : "Descargado mediante una liga pública",
     "Downloaded by {email}" : "Descargado por {email}",
@@ -62,9 +66,9 @@ OC.L10N.register(
     "{actor} shared {file} with you" : "{actor} ha compartido {file} contigo",
     "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Un archivo o carpeta comparitdo por correo o por liga pública ha sido <strong>descargado</strong>",
     "A file or folder was shared from <strong>another server</strong>" : "Un archivo o carpeta fue compartido desde <strong>otro servidor</strong>",
+    "Files" : "Archivos",
     "A file or folder has been <strong>shared</strong>" : "Un archivo o carpeta ha sido <strong>compartido</strong>",
     "Wrong share ID, share doesn't exist" : "ID del elemento compartido equivocado, el elemento compartido no existe",
-    "could not delete share" : "no fue posible borrar el elemento compartido",
     "Could not delete share" : "No fue posible borrar el elemento compartido",
     "Please specify a file or folder path" : "Por favor especifica un archivo o ruta de carpeta",
     "Wrong path, file/folder doesn't exist" : "La ruta es incorrecta, el correo / carpeta no existe ",
@@ -77,7 +81,6 @@ OC.L10N.register(
     "Public upload disabled by the administrator" : "Cargas públicas deshabilitadas por el administrador",
     "Public upload is only possible for publicly shared folders" : "Las cargas públicas son posibles sólo para carpetas compartidas públicamente",
     "Invalid date, date format must be YYYY-MM-DD" : "La fecha es inválida, por favor sigue el formato AAAA-MM-DD",
-    "Sharing %s failed because the back end does not allow shares from type %s" : "Se presentó  una falla al compartir %s, porque el backend no permite elementos compartidos de tipo %s",
     "You cannot share to a Circle if the app is not enabled" : "No puedes compartir al Círculo si la aplicación no está habilitada",
     "Please specify a valid circle" : "Por favor especifica un círculo válido",
     "Unknown share type" : "Tipo de elemento compartido desconocido",
@@ -85,13 +88,35 @@ OC.L10N.register(
     "Could not lock path" : "No fue posible bloquear la ruta",
     "Wrong or no update parameter given" : "El parametro de actualización está erróneo o falta",
     "Can't change permissions for public share links" : "No es posible cambiar los permisos para ligas públicas compartidas",
-    "Cannot increase permissions" : "No es posible incrementar los permisos",
     "shared by %s" : "compartido por %s",
-    "Download" : "Descargar",
     "Direct link" : "Liga directa",
     "Add to your Nextcloud" : "Agregar a tu Nextcloud",
     "Share API is disabled" : "El API para compartir está deshabilitado",
     "File sharing" : "Compartir archivos",
+    "Accept" : "Aceptar",
+    "Sharing" : "Compartiendo",
+    "Allow editing" : "Permitir edición",
+    "Allow resharing" : "Permitir volver a compartir",
+    "Set expiration date" : "Establecer fecha de expiración",
+    "Unshare" : "Dejar de compartir",
+    "group" : "grupo",
+    "remote" : "remoto",
+    "Link copied" : "Enlace copiado",
+    "Copy to clipboard" : "Copiar al portapapeles",
+    "Password protection" : "Protección con contraseña",
+    "Enter a password" : "Ingresa una contraseña",
+    "Cancel" : "Cancelar",
+    "Read only" : "Sólo lectura",
+    "Allow upload and editing" : "Permitir carga y edición",
+    "File drop (upload only)" : "Permitir carga",
+    "Password protect" : "Proteger con contraseña",
+    "Share link" : "Compartir liga",
+    "Resharing is not allowed" : "No se permite volver a compartir",
+    "Shared" : "Compartido",
+    "Share" : "Compartir",
+    "Shared with" : "Compartido con",
+    "Shared with you and the group {group} by {owner}" : "Compartido contigo y con el grupo {group} por {owner}",
+    "Shared with you by {owner}" : "Compartido contigo por {owner}",
     "No entries found in this folder" : "No se encontraron elementos en esta carpeta",
     "Name" : "Nombre",
     "Share time" : "Compartido desde",
@@ -102,15 +127,11 @@ OC.L10N.register(
     "the link expired" : "la liga expiró",
     "sharing is disabled" : "compartir está deshabilitado",
     "For more info, please ask the person who sent this link." : "Para mayores informes, contacta a la persona que le envió esta liga.",
+    "Share note" : "Compartir nota",
     "Download %s" : "Descargar %s",
     "Upload files to %s" : "Cargar archivos a %s",
     "Select or drop files" : "Selecciona o suelta los archivos",
-    "Uploading files…" : "Cargando archivos...",
     "Uploaded files:" : "Archivos cargados:",
-    "{actor} removed you from {file}" : "{actor} lo eliminó de {file}",
-    "%s is publicly shared" : "%s está compartido públicamente",
-    "This share is password-protected" : "Este elemento compartido está protegido con contraseña",
-    "The password is wrong. Try again." : "La contraseña es incorrecta. Por favor inténtalo de nuevo.",
-    "Password" : "Contraseña"
+    "Uploading files…" : "Cargando archivos..."
 },
 "nplurals=2; plural=(n != 1);");
