@@ -14,11 +14,17 @@ OC.L10N.register(
     "No deleted shares" : "Ingen slettede delinger",
     "Shares you deleted will show up here" : "Delinger du har slettet vil vises her",
     "Pending shares" : "Ventende delinger",
+    "No pending shares" : "Ingen ventende delinger",
+    "Shares you have received but not confirmed will show up here" : "Delinger du har mottatt men ikke bekreftet vil vises her",
     "Shares" : "Delinger",
     "No shares" : "Ingen delinger",
     "Shares will show up here" : "Delinger vil vises her",
     "Restore" : "Gjenopprett",
     "Restore share" : "Gjenopprett deling",
+    "Something happened. Unable to restore the share." : "Noe skjedde. Ikke mulig å gjenopprette delingen.",
+    "Accept share" : "Aksepter deling",
+    "Reject share" : "Avvis deling",
+    "Something happened. Unable to reject the share." : "Noe skjedde. Ikke mulig å avvise delingen.",
     "Waiting…" : "Venter...",
     "error" : "feil",
     "finished" : "fullført",
@@ -42,6 +48,7 @@ OC.L10N.register(
     "Removed share for group {group}" : "Fjernet deling for gruppen {group}",
     "{actor} shared with group {group}" : "{actor} delt med gruppen {group}",
     "{actor} removed share for group {group}" : "{actor} fjernet deling for gruppen {group}",
+    "Share for group {group} expired" : "Deling for gruppen {group} utløpt",
     "You shared {file} with group {group}" : "Du delte {file} med gruppen {group}",
     "You removed group {group} from {file}" : "Du fjernet gruppen {group} fra {file}",
     "{actor} shared {file} with group {group}" : "{actor} delte {file} med gruppen {group}",
