@@ -2,7 +2,9 @@
 /**
  * @copyright Copyright (c) 2016 Joas Schilling <coding@schilljs.com>
  *
+ * @author Christoph Wurst <christoph@winzerhof-wurst.at>
  * @author Joas Schilling <coding@schilljs.com>
+ * @author John Molakvoæ (skjnldsv) <skjnldsv@protonmail.com>
  *
  * @license GNU AGPL version 3 or any later version
  *
@@ -17,7 +19,7 @@
  * GNU Affero General Public License for more details.
  *
  * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -25,6 +27,8 @@ namespace OCA\Files_Sharing\Activity\Providers;
 
 use OCP\Activity\IEvent;
 use OCP\Activity\IManager;
+use OCP\Contacts\IManager as IContactsManager;
+use OCP\Federation\ICloudIdManager;
 use OCP\IGroup;
 use OCP\IGroupManager;
 use OCP\IURLGenerator;
@@ -32,14 +36,13 @@ use OCP\IUserManager;
 use OCP\L10N\IFactory;
 
 class Groups extends Base {
+	public const SUBJECT_SHARED_GROUP_SELF = 'shared_group_self';
+	public const SUBJECT_RESHARED_GROUP_BY = 'reshared_group_by';
 
-	const SUBJECT_SHARED_GROUP_SELF = 'shared_group_self';
-	const SUBJECT_RESHARED_GROUP_BY = 'reshared_group_by';
+	public const SUBJECT_UNSHARED_GROUP_SELF = 'unshared_group_self';
+	public const SUBJECT_UNSHARED_GROUP_BY = 'unshared_group_by';
 
-	const SUBJECT_UNSHARED_GROUP_SELF = 'unshared_group_self';
-	const SUBJECT_UNSHARED_GROUP_BY = 'unshared_group_by';
-
-	const SUBJECT_EXPIRED_GROUP = 'expired_group';
+	public const SUBJECT_EXPIRED_GROUP = 'expired_group';
 
 	/** @var IGroupManager */
 	protected $groupManager;
@@ -47,15 +50,14 @@ class Groups extends Base {
 	/** @var string[] */
 	protected $groupDisplayNames = [];
 
-	/**
-	 * @param IFactory $languageFactory
-	 * @param IURLGenerator $url
-	 * @param IManager $activityManager
-	 * @param IUserManager $userManager
-	 * @param IGroupManager $groupManager
-	 */
-	public function __construct(IFactory $languageFactory, IURLGenerator $url, IManager $activityManager, IUserManager $userManager, IGroupManager $groupManager) {
-		parent::__construct($languageFactory, $url, $activityManager, $userManager);
+	public function __construct(IFactory $languageFactory,
+								IURLGenerator $url,
+								IManager $activityManager,
+								IUserManager $userManager,
+								ICloudIdManager $cloudIdManager,
+								IContactsManager $contactsManager,
+								IGroupManager $groupManager) {
+		parent::__construct($languageFactory, $url, $activityManager, $userManager, $cloudIdManager, $contactsManager);
 		$this->groupManager = $groupManager;
 	}
 
@@ -70,13 +72,13 @@ class Groups extends Base {
 
 		if ($event->getSubject() === self::SUBJECT_SHARED_GROUP_SELF) {
 			$subject = $this->l->t('Shared with group {group}');
-		} else if ($event->getSubject() === self::SUBJECT_UNSHARED_GROUP_SELF) {
+		} elseif ($event->getSubject() === self::SUBJECT_UNSHARED_GROUP_SELF) {
 			$subject = $this->l->t('Removed share for group {group}');
-		} else if ($event->getSubject() === self::SUBJECT_RESHARED_GROUP_BY) {
+		} elseif ($event->getSubject() === self::SUBJECT_RESHARED_GROUP_BY) {
 			$subject = $this->l->t('{actor} shared with group {group}');
-		} else if ($event->getSubject() === self::SUBJECT_UNSHARED_GROUP_BY) {
+		} elseif ($event->getSubject() === self::SUBJECT_UNSHARED_GROUP_BY) {
 			$subject = $this->l->t('{actor} removed share for group {group}');
-		} else if ($event->getSubject() === self::SUBJECT_EXPIRED_GROUP) {
+		} elseif ($event->getSubject() === self::SUBJECT_EXPIRED_GROUP) {
 			$subject = $this->l->t('Share for group {group} expired');
 		} else {
 			throw new \InvalidArgumentException();
@@ -103,13 +105,13 @@ class Groups extends Base {
 
 		if ($event->getSubject() === self::SUBJECT_SHARED_GROUP_SELF) {
 			$subject = $this->l->t('You shared {file} with group {group}');
-		} else if ($event->getSubject() === self::SUBJECT_UNSHARED_GROUP_SELF) {
+		} elseif ($event->getSubject() === self::SUBJECT_UNSHARED_GROUP_SELF) {
 			$subject = $this->l->t('You removed group {group} from {file}');
-		} else if ($event->getSubject() === self::SUBJECT_RESHARED_GROUP_BY) {
+		} elseif ($event->getSubject() === self::SUBJECT_RESHARED_GROUP_BY) {
 			$subject = $this->l->t('{actor} shared {file} with group {group}');
-		} else if ($event->getSubject() === self::SUBJECT_UNSHARED_GROUP_BY) {
+		} elseif ($event->getSubject() === self::SUBJECT_UNSHARED_GROUP_BY) {
 			$subject = $this->l->t('{actor} removed group {group} from {file}');
-		} else if ($event->getSubject() === self::SUBJECT_EXPIRED_GROUP) {
+		} elseif ($event->getSubject() === self::SUBJECT_EXPIRED_GROUP) {
 			$subject = $this->l->t('Share for file {file} with group {group} expired');
 		} else {
 			throw new \InvalidArgumentException();
