@@ -12,8 +12,20 @@ OC.L10N.register(
     "Add your profile information! Set a full name for easier recognition across all features." : "Lisää profiilitietosi! Lisää koko nimesi, jotta sinut on helpompi tunnistaa.",
     "Add your profile information! Set a profile picture for easier recognition across all features." : "Lisää profiilitietosi! Lisää profiilikuva, jotta sinut on helpompi tunnistaa.",
     "App recommendation: Nextcloud Calendar" : "Sovellussuositus: Nextcloud-kalenteri",
+    "Schedule work & meetings, synced with all your devices." : "Aikatauluta työsi ja tapaamisesi synkronoidusti kaikkien laitteitesi välillä.",
     "App recommendation: Nextcloud Contacts" : "Sovellussuositus: Nextcloud-yhteystiedot",
+    "Keep your colleagues and friends in one place without leaking their private info." : "Pidä työkaverisi ja kaverisi samassa paikassa vuotamatta heidän yksityisiä tietojaan.",
     "App recommendation: Nextcloud Mail" : "Sovellussuositus: Nextcloud-sähköposti",
+    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Yksinkertainen sähköpostisovellus, joka toimii yhdessä Tiedostojen, Kontaktien ja Kalenterin kanssa.",
+    "App recommendation: Tasks" : "Sovellussuositus: Tehtävät",
+    "Sync tasks from various devices with your Nextcloud and edit them online." : "Synkronoit tehtäviä eri laitteista Nextcloudiisi ja muokkaa niitä netissä.",
+    "App recommendation: Deck" : "Sovellussuositus: Pakka",
+    "Kanban style organization for personal planning and team projects." : "Kanban-tyylistä organisointia henkilökohtaiseen suunnitteluun ja ryhmäprojekteihin.",
+    "App recommendation: Notes" : "Sovellussuositus: Muistiinpanot",
+    "Distraction-free notes and writing." : "Häiriötöntä muistiinpanojen ottamista ja kirjoittamista",
+    "App recommendation: Social" : "Sovellussuositus: Sosiaalinen",
+    "App recommendation: Group folders" : "Sovellussuositus: Ryhmäkansiot",
+    "Admin-configured folders shared by everyone in a group." : "Ylläpitäjän määrittämät kansiot jaettuina kaikille ryhmän jäsenille.",
     "About" : "Tietoja",
     "A welcome and introduction wizard for Nextcloud" : "Nextcloudin ensimmäisen käyttökerran avustaja",
     "Start using Nextcloud" : "Aloita Nextcloudin käyttäminen",
@@ -23,6 +35,7 @@ OC.L10N.register(
     "Communication with Nextcloud Talk" : "Yhteydenpito Nextcloud Talkilla",
     "Collaboration apps for document editing" : "Yhteistyösovellukset asiakirjojen muokkaukseen",
     "Security and authentication features like two-factor authentication, SSO and ransomware protection" : "Tietoturva- ja tunnistautumisominaisuuksia kuten kaksivaiheinen tunnistautuminen, kertakirjautuminen ja suoja kiristysohjelmia vastaan",
+    "Many others like a music player, a password manager, a kanban app, a download manager or a Markdown editor" : "Paljon muuta kuten musiikkisoitin, salasanahallinta, kanban-sovellus, lataushallinta ja markdown-muokkain",
     "Browse the app store" : "Selaa sovelluskauppaa",
     "Stay in sync" : "Pysy synkronoituna",
     "Nextcloud gives you access to your files wherever you are." : "Nextcloud mahdollistaa pääsyn tiedostoihisi sijainnistasi riippumatta.",
@@ -58,7 +71,9 @@ OC.L10N.register(
     "100%% Open Source & community-focused" : "100%% avointa lähdekoodia ja yhteisökeskeisyyttä",
     "Learn more about %s" : "Lisätietoja - %s",
     "%s gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost." : "%s mahdollistaa pääsyn tiedostoihisi missä hyvänsä oletkin. Hellpokäyttöiset työpöytä- ja mobiilisovellukset ovat saatavilla kaikille suurimmille alustoille veloituksetta.",
+    "Set up sync clients using an <a href=\"%s\">app password</a>. That way you can make sure you are able to revoke access in case you lose that device." : "Määritä synkronointi käyttäen <a href=\"%s\">sovelluskohtaisia salasanoja</a>. Näin voit kumota käyttöoikeuden, jos satut esimerkiksi kadottamaan tietyn laitteesi",
     "Connect other apps to %s" : "Yhdistä muita sovelluksia %siin",
+    "Besides the mobile apps and desktop client you can connect any other software that supports the WebDAV/CalDAV/CardDAV protocols to %s." : "Synkronointisovellusten lisäksi voit yhdistää minkä tahansa WebDAV-, CalDAV- ja CardDAV-yhteyskäytäntöjä tukevan ohjelmiston %siin",
     "Server address" : "Palvelimen osoite",
     "Use this link to connect your apps and desktop client to this server:" : "Käytä tätä linkkiä yhdistääksesi sovellukset ja työpöytäsovelluksen tähän palvelimeen:",
     "Copy link" : "Kopioi linkki",
