@@ -1,6 +1,10 @@
 OC.L10N.register(
     "logreader",
     {
+    "Log levels" : "Niveles de registro",
+    "Log content" : "Contenido del registro",
+    "Live update" : "Actualización en vivo",
+    "Download logs" : "Descargar registros",
     "Error parsing log" : "Error al analizar el registro",
     "Copy" : "Copiar",
     "Copy raw" : "Copia cruda",
@@ -8,14 +12,12 @@ OC.L10N.register(
     "No server logs" : "No hay registros del servidor",
     "One or more entries are hidden by the log level filter" : "Una o más entradas están ocultas por el filtro de nivel de registro",
     "Everything is working fine" : "Todo esta funcionando bien",
-    "Log levels" : "Niveles de registro",
-    "Log content" : "Contenido del registro",
-    "Live update" : "Actualización en vivo",
-    "Download logs" : "Descargar registros",
+    "Level" : "Nivel",
+    "App" : "Aplicación",
+    "Time" : "Hora",
     "Logging" : "Explotación forestal",
     "Log Reader" : "Lector de registro",
     "A log reader for Nextcloud" : "Un lector de registro para Nextcloud",
-    "Log reader for Nextcloud" : "Lector de registro para Nextcloud",
-    "Cased by " : "Encajonada por"
+    "Log reader for Nextcloud" : "Lector de registro para Nextcloud"
 },
 "nplurals=2; plural=(n != 1);");
