@@ -36,19 +36,29 @@ use OCP\Files\IRootFolder;
 use OCP\FIles\Node;
 use OCP\Files\NotFoundException;
 use OCP\Files\StorageNotAvailableException;
+use OCP\IPreview;
 use OCP\IRequest;
 
 class AlbumsController extends Controller {
 
 	/** @var string */
 	private $userId;
+	
 	/** @var IRootFolder */
 	private $rootFolder;
+	
+	/** @var IPreview */
+	private $previewManager;
+
+	public function __construct(string $userId,
+								IRequest $request,
+								IRootFolder $rootFolder,
+								IPreview $previewManager) {
+		parent::__construct(Application::APP_ID, $request);
 
-	public function __construct($appName, IRequest $request, string $userId, IRootFolder $rootFolder) {
-		parent::__construct($appName, $request);
 		$this->userId = $userId;
 		$this->rootFolder = $rootFolder;
+		$this->previewManager = $previewManager;
 	}
 
 	/**
@@ -102,7 +112,8 @@ class AlbumsController extends Controller {
 				'lastmod' => $node->getMTime(),
 				'mime' => $node->getMimetype(),
 				'size' => $node->getSize(),
-				'type' => $node->getType()
+				'type' => $node->getType(),
+				'hasPreview' => $this->previewManager->isAvailable($node),
 			];
 		}
 
@@ -127,7 +138,8 @@ class AlbumsController extends Controller {
 	}
 
 	private function validFile(File $file, bool $shared): bool {
-		if (in_array($file->getMimeType(), Application::MIMES) && $this->isShared($file) === $shared) {
+		$allowed_mimes = array_merge(Application::IMAGE_MIMES, Application::VIDEO_MIMES);
+		if (in_array($file->getMimeType(), $allowed_mimes) && $this->isShared($file) === $shared) {
 			return true;
 		}
 
