@@ -6,6 +6,7 @@ OC.L10N.register(
     "Recently shared" : "For nyligt delt",
     "Recommendations" : "Anbefalinger",
     "Shows recommended files" : "Vis anbefalede filer",
-    "Shows recommended files for quick access of files and folders with recent activity" : "Vis anbefalede filer for hurtig adgang til filer og mapper med nylig aktivitet"
+    "Shows recommended files for quick access of files and folders with recent activity" : "Vis anbefalede filer for hurtig adgang til filer og mapper med nylig aktivitet",
+    "Show recommendations" : "Vis anbefalinger"
 },
 "nplurals=2; plural=(n != 1);");
