@@ -11,19 +11,23 @@ OC.L10N.register(
     "Links" : "ბმულები",
     "Federated sent" : "ფედერალური გაიგზავნა",
     "Federated received" : "ფედერალური შემოვიდა",
-    "Last 24 hours" : "ბოლო 24 საათი",
-    "Last 1 hour" : "ბოლო 1 საათი",
-    "Last 5 mins" : "ბოლო 5 წუთი",
+    "24 hours" : "24 საათი",
+    "1 hour" : "1 საათი",
+    "Copy" : "კოპირება",
+    "Copied!" : "კოპირებულია!",
+    "Not supported!" : "არაა მხარდაჭერილი",
+    "Press ⌘-C to copy." : "კოპირებისთვის დააჭირეთ ⌘-C-ს.",
+    "Press Ctrl-C to copy." : "კოპირებისთვის დააჭირეთ Ctrl-C-ს.",
+    "System" : "სისტემა",
     "Monitoring" : "მონიტორინგი",
-    "CPU load" : "CPU-ს დატვირთვა",
-    "Memory usage" : "მეხსიერების მოხმარება",
+    "Size" : "ზომა",
+    "Files:" : "ფაილები",
+    "Hostname" : "ჰოსტი",
+    "Status" : "სტატუსი",
     "Active users" : "აქტიური მომხმარებლები",
     "Shares" : "გაზიარებები",
-    "Storage" : "საცავი",
-    "Users:" : "მომხმარებლები:",
-    "Files:" : "ფაილები",
-    "Version:" : "ვერსია:",
     "PHP" : "PHP",
+    "Version:" : "ვერსია:",
     "Memory Limit:" : "მეხსიერების ლიმიტი:",
     "Max Execution Time:" : "მაქს. გაშვების დრო:",
     "Upload max size:" : "ატვირთვის მაქს. ზომა:",
