@@ -68,6 +68,7 @@ OC.L10N.register(
     "installing and updating apps via the app store or Federated Cloud Sharing" : "Das Installieren und Aktualisieren von Apps durch den App-Store oder durch Federated Cloud Sharing",
     "Federated Cloud Sharing" : "Federated-Cloud-Sharing",
     "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL verwendet eine veraltete %1$s Version (%2$s). Bitte aktualisieren Sie ihr Betriebssystem, da ansonsten Funktionen, wie z.B. %3$s, nicht zuverlässig funktionieren.",
+    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the nextcloud log file for more details." : "Es konnte nicht festgestellt werden, ob die TLS-Version von cURL veraltet ist oder nicht, da während der HTTPS-Anforderung an https://nextcloud.com ein Fehler aufgetreten ist. Bitte überprüfen Sie die Nextcloud-Protokolldatei für weitere Einzelheiten.",
     "Invalid SMTP password." : "Ungültiges SMTP-Passwort.",
     "Email setting test" : "Test der E-Mail-Einstellungen",
     "Well done, %s!" : "Gut gemacht, %s!",
@@ -79,6 +80,8 @@ OC.L10N.register(
     "Settings saved" : "Einstellungen gespeichert",
     "Unable to change full name" : "Der vollständige Name konnte nicht geändert werden",
     "Unable to change email address" : "E-Mail-Adresse konnte nicht geändert werden",
+    "Unable to set invalid phone number" : "Ungültige Rufnummer kann nicht eingestellt werden",
+    "Some account data was invalid" : "Einige Kontodaten waren ungültig",
     "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Um Ihr Twitter-Konto zu überprüfen, veröffentlichen Sie bitte den folgenden Tweet auf Twitter (Bitte stellen Sie sicher, dass der Tweet keinen Zeilenumbruch enthält):",
     "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Um Ihre Webseite zu überprüfen, speichern Sie bitte den folgenden Inhalt im Web-Wurzelverzeichnist in der Datei '.well-known/CloudIdVerificationCode.txt' (bitte stellen Sie sicher, das sich der gesamte Text in einer Zeile befindet):",
     "%1$s changed your password on %2$s." : "%1$s hat Ihr Passwort auf %2$s geändert.",
@@ -150,8 +153,8 @@ OC.L10N.register(
     "Developer documentation" : "Dokumentation für Entwickler",
     "This app is supported via your current Nextcloud subscription." : "Diese App wird von Ihrem aktuellen Nextcloud-Abonnement unterstützt.",
     "Supported" : "Unterstützt",
-    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Offizielle Apps werden von und innerhalb der Nextcloud-Community entwickelt. Sie stellen zentrale Funktionen bereit und sind für den produktiven Einsatz geeignet.",
-    "Featured" : "Offiziell",
+    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Vorgestellte Apps werden von und innerhalb der Nextcloud-Community entwickelt. Sie stellen zentrale Funktionen bereit und sind für den produktiven Einsatz geeignet.",
+    "Featured" : "Vorgestellt",
     "Update to {update}" : "Aktualisieren auf {update}",
     "Update all" : "Alle aktualisieren",
     "Results from other categories" : "Ergebnisse aus anderen Kategorien",
@@ -261,7 +264,7 @@ OC.L10N.register(
     "Disabled apps" : "Deaktivierte Apps",
     "Updates" : "Aktualisierungen",
     "App bundles" : "App-Pakete",
-    "Featured apps" : "Ausgewählte Apps",
+    "Featured apps" : "Vorgestellte Apps",
     "{license}-licensed" : "{license}-Lizenziert",
     "Details" : "Details",
     "Changelog" : "Liste der Änderungen",
