@@ -222,7 +222,7 @@ OC.L10N.register(
     "Welcome mail sent!" : "Απεστάλη το μήνυμα καλωσορίσματος!",
     "Edit User" : "Επεξεργασία Χρήστη",
     "Toggle user actions menu" : "Εναλλαγή μενού ρυθμίσεων χρήστη",
-    "{size} used" : "{μέγεθος} που χρησιμοποιείται",
+    "{size} used" : "{size} που χρησιμοποιείται",
     "Will be autogenerated" : "Θα δημιουργηθεί αυτόματα",
     "Display name" : "Εμφανιζόμενο όνομα",
     "Email" : "Ηλ.Ταχυδρομείο",
