@@ -68,6 +68,7 @@ OC.L10N.register(
     "installing and updating apps via the app store or Federated Cloud Sharing" : "instalando y actualizando aplicaciones a través de la tienda de aplicaciones o de la nube compartida federada",
     "Federated Cloud Sharing" : "Compartido en Nube Federada",
     "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL está usando una versión desactualizada %1$s (%2$s). Por favor, actualiza tu sistema operativo o funciones como %3$s no funcionarán de forma fiable.",
+    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the nextcloud log file for more details." : "No se puede determinar si la vdersión TLS de cURL está anticuada o no debido a que ocurrió un error durante la consulta HTTPS contra https://nextcloud.com. Por favor compruebe el archivo de registro de nexcloud para más detalles.",
     "Invalid SMTP password." : "Contraseña SMTP inválida",
     "Email setting test" : "Prueba de configuración de correo",
     "Well done, %s!" : "¡Bien hecho, %s!",
@@ -79,6 +80,8 @@ OC.L10N.register(
     "Settings saved" : "Ajustes guardados",
     "Unable to change full name" : "No se puede cambiar el nombre completo",
     "Unable to change email address" : "No se pudo cambiar la dirección de correo",
+    "Unable to set invalid phone number" : "No se pudo registrar un número de teléfono incorrecto",
+    "Some account data was invalid" : "Algunos datos de la cuenta no son correctos",
     "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Para verificar tu cuenta de Twitter, escribe el siguiente tuit en Twitter (por favor, asegúrate de escribirlo sin saltos de línea):",
     "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Para verificar tu sitio web, guarda el siguiente contenido en la raíz de la web en '.well-known/CloudIdVerificationCode.txt' (por favor, asegúrate de que el texto completo está en una línea):",
     "%1$s changed your password on %2$s." : "%1$s cambió su contraseña en %2$s.",
@@ -119,6 +122,8 @@ OC.L10N.register(
     "Reshare" : "Volver a compartir",
     "Unlimited" : "Ilimitado",
     "Verifying" : "Verificar",
+    "A background job is pending that checks for user imported SSL certificates. Please check back later." : "Está pendiente una tarea en segundo plano que comprueba por el usuario los certificados SSL importados. Por favor, revisalo más tarde.",
+    "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Hay algunos certificados SSL importados por el usuario que ya no se utilizan con Nextcloud 21. Pueden ser importados con la línea de comandos a través del comando \"occ security:certificates:import\". Sus rutas dentro del directorio de datos se muestran a continuación.",
     "The old server-side-encryption format is enabled. We recommend disabling this." : "El antiguo formato de cifrado en el lado del servidor está activado. Recomendamos deshabilitar esto.",
     "Nextcloud settings" : "Ajustes de Nextcloud",
     "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "La verificación en dos pasos se puede aplicar para todos los usuarios y grupos específicos. Si no tienen configurado un proveedor de dos pasos, no podrán iniciar sesión en el sistema.",
