@@ -79,6 +79,8 @@ OC.L10N.register(
     "Settings saved" : "Paramètres sauvegardés",
     "Unable to change full name" : "Impossible de modifier le nom complet",
     "Unable to change email address" : "Impossible de modifier l'adresse e-mail",
+    "Unable to set invalid phone number" : "Impossible d'enregistrer un n° de téléphone incorrect",
+    "Some account data was invalid" : "Certaines données du compte ne sont pas valides",
     "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Pour vérifier votre compte Twitter, postez le tweet suivant sur Twitter (veuillez vérifier de le poster sans saut de ligne) :",
     "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Pour vérifier votre site web, placez le contenu suivant à la racine de votre site à '.well-known/CloudIdVerificationCode.txt' (veuillez vérifier que le texte complet est en une seule ligne) :",
     "%1$s changed your password on %2$s." : "%1$s a modifié votre mot de passe sur %2$s.",
@@ -119,6 +121,8 @@ OC.L10N.register(
     "Reshare" : "Repartager",
     "Unlimited" : "Illimité",
     "Verifying" : "Vérification en cours",
+    "A background job is pending that checks for user imported SSL certificates. Please check back later." : "Une tâche en arrière-plan qui vérifie les certificats SSL importés par l’utilisateur est en attente. Veuillez vérifier plus tard.",
+    "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Certains certificats SSL importés par les utilisateurs sont présents et ne sont plus utilisés avec Nextcloud 21. Ils peuvent être importés par l'interface en ligne de commande via la commande \"occ security:certificates:import\". Leurs chemins dans le dossier data sont affichés ci-dessous.",
     "The old server-side-encryption format is enabled. We recommend disabling this." : "L'ancien format de chiffrement côté serveur est activé. Nous recommandons de le désactiver.",
     "Nextcloud settings" : "Paramètres Nextcloud",
     "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "L'authentification à deux facteurs peut être forcée pour tous les utilisateurs et des groupes spécifiques. S'ils n'ont pas un fournisseur à deux facteurs configuré, ils ne seront pas capable de s'identifier au système.",
@@ -413,6 +417,7 @@ OC.L10N.register(
     "New password" : "Nouveau mot de passe",
     "Change password" : "Changer de mot de passe",
     "Use a second factor besides your password to increase security for your account." : "Utiliser un second facteur d'authentification en plus de votre mot de passe pour augmenter la sécurité de votre compte.",
+    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Si vous utilisez des applications tierces pour vous connecter à Nextcloud, assurez-vous de créer et de configurer un mot de passe d'application pour chacune avant d'activer l'authentification à deux facteurs.",
     "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Une erreur est survenue. Veuillez fournir un certificat PEM encodé au format ASCII.",
     "Valid until {date}" : "Valide jusqu'au {date}",
     "Local" : "Local",
