@@ -68,6 +68,7 @@ OC.L10N.register(
     "installing and updating apps via the app store or Federated Cloud Sharing" : "instalando e actualizando aplicacións mediante a tenda de aplicacións ou da nube federada compartida",
     "Federated Cloud Sharing" : "Nube federada compartida",
     "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL está utilizando unha versión obsoleta %1$s (%2$s). Actualice o seu sistema operativo, caso contrario características como %3$s non funcionarán de xeito fiábel.",
+    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the nextcloud log file for more details." : "Non foi posíbel determinar se a versión TLS de cURL está desactualizada ou non porque se produciu un erro durante a solicitude HTTPS contra https://nextcloud.com. Consulte o ficheiro de rexistro de Nextcloud para obter máis detalles.",
     "Invalid SMTP password." : "Contrasinal SMTP incorrecta.",
     "Email setting test" : "Proba do axuste do correo",
     "Well done, %s!" : "Ben feito, %s!",
@@ -79,6 +80,8 @@ OC.L10N.register(
     "Settings saved" : "Axustes gardados",
     "Unable to change full name" : "Non é posíbel cambiar o nome completo",
     "Unable to change email address" : "Non é posíbel cambiar o enderezo de correo.",
+    "Unable to set invalid phone number" : "Non é posíbel estabelecer un número de teléfono non válido",
+    "Some account data was invalid" : "Algúns datos da conta non eran válidos",
     "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Para poder verificar a súa conta de Twitter, publique o seguinte chío en Twitter (asegúrese de publicar sen ningún salto de liña):",
     "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Para poder verificar o seu sitio Web, engada o seguinte contido ao seu web-root en «.well-known/CloudIdVerificationCode.txt» (asegúrese de que o texto completo estea só nunha liña):",
     "%1$s changed your password on %2$s." : "%1$s cambiou o seu contrasinal en %2$s.",
