@@ -68,6 +68,7 @@ OC.L10N.register(
     "installing and updating apps via the app store or Federated Cloud Sharing" : "installazione e aggiornamento delle applicazioni tramite il negozio delle applicazioni o condivisione cloud federata",
     "Federated Cloud Sharing" : "Condivisione cloud federata",
     "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL sta utilizzando una versione di %1$s datata (%2$s). Aggiorna il tuo sistema operativo o funzionalità come %3$s non funzioneranno correttamente.",
+    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the nextcloud log file for more details." : "Impossibile determinare se la versione TLS di cURL è obsoleta o meno perché si è verificato un errore durante la richiesta HTTPS su https://nextcloud.com. Controlla il file di registro di nextcloud per maggiori dettagli.",
     "Invalid SMTP password." : "Password SMTP non valida.",
     "Email setting test" : "Prova impostazioni email",
     "Well done, %s!" : "Ben fatto, %s!",
@@ -79,6 +80,8 @@ OC.L10N.register(
     "Settings saved" : "Impostazioni salvate",
     "Unable to change full name" : "Impossibile cambiare il nome completo",
     "Unable to change email address" : "Impossibile cambiare l'indirizzo di posta",
+    "Unable to set invalid phone number" : "Impossibile impostare un numero di telefono non valido",
+    "Some account data was invalid" : "Alcuni dati dell'account non sono validi",
     "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Per verificare il tuo account Twitter, pubblica il seguente tweet su Twitter (assicurati di pubblicarlo senza interruzioni di riga):",
     "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Per verificare il tuo sito web, memorizza il seguente contenuto nella radice del tuo sito in '.well-known/CloudIdVerificationCode.txt' (assicurati che l'intero testo sia in una riga):",
     "%1$s changed your password on %2$s." : "%1$s ha cambiato la tua password su %2$s.",
