@@ -68,6 +68,7 @@ OC.L10N.register(
     "installing and updating apps via the app store or Federated Cloud Sharing" : "instalowanie i aktualizowanie aplikacji za pośrednictwem sklepu z aplikacjami lub Udostępnionej Chmury Federacyjnej",
     "Federated Cloud Sharing" : "Udostępnianie Chmury Federacyjnej",
     "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL używa nieaktualnej %1$s wersji (%2$s). Zaktualizuj system operacyjny lub funkcje takie jak %3$s nie będą działać prawidłowo.",
+    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the nextcloud log file for more details." : "Nie można określić, czy wersja TLS cURL jest aktualna, ponieważ wystąpił błąd podczas żądania HTTPS skierowanego do https://nextcloud.com. Aby uzyskać więcej informacji, sprawdź plik dziennika nextcloud.",
     "Invalid SMTP password." : "Nieprawidłowe hasło SMTP.",
     "Email setting test" : "Test ustawień e-mail",
     "Well done, %s!" : "Dobra robota, %s!",
@@ -79,6 +80,8 @@ OC.L10N.register(
     "Settings saved" : "Zapisano ustawienia",
     "Unable to change full name" : "Nie można zmienić pełnej nazwy",
     "Unable to change email address" : "Nie można zmienić adresu e-mail",
+    "Unable to set invalid phone number" : "Nie można ustawić nieprawidłowego numeru telefonu",
+    "Some account data was invalid" : "Niektóre dane konta są nieprawidłowe",
     "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Aby zweryfikować swoje konto Twittera, wyślij poniższego tweeta (upewnij się, że cały tekst zawiera się w jednej linii):",
     "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Aby zweryfikować swoją stronę umieść poniższą zawartość w katalogu głównym serwera pod adresem '.well-known/CloudIdVerificationCode.txt' (upewnij się, że cały tekst zawiera się w jednej linii):",
     "%1$s changed your password on %2$s." : "%1$s zmienił Twoje hasło w %2$s.",
