@@ -24,13 +24,6 @@ OC.L10N.register(
     "Groups" : "Grupuri",
     "Group list is empty" : "Lista de grupuri este goală",
     "Unable to retrieve the group list" : "Nu s-a putut obține lista de grupuri",
-    "Add link" : "Adaugă link",
-    "Unsaved changes" : "Modificări nesalvate",
-    "Use current version" : "Folosește versiunea curentă",
-    "Use the saved version" : "Folosește versiuna salvată",
-    "Retry" : "Reîncearcă",
-    "Show image" : "Arată imaginea",
-    "Show file" : "Arată fișierul",
     "{actor} added you to group {group}" : "{actor} te-a adăugat în grupul {group}",
     "You added {user} to group {group}" : "Ai adăugat {user} în grupul {group}",
     "{actor} added {user} to group {group}" : "{actor} a adăugat pe {user} în grupul {group}",
@@ -92,6 +85,10 @@ OC.L10N.register(
     "Your username is: %s" : "Utilizatorul tău este: %s",
     "Set your password" : "Setează parola",
     "Install Client" : "Instalează client",
+    "Apps" : "Aplicații",
+    "Settings" : "Setări",
+    "Personal" : "Personal",
+    "Administration" : "Administrare",
     "Additional settings" : "Setări adiționale",
     "Basic settings" : "Setări de bază",
     "Sharing" : "Partajare",
@@ -104,20 +101,17 @@ OC.L10N.register(
     "Limit to groups" : "Limitează pentru grupuri",
     "Enforcement of two-factor authentication can be set for certain groups only." : "Forțarea autentificării cu doi factori poate fi setată doar pentru anumite grupuri.",
     "Save changes" : "Salvează modificările",
-    "by" : "de",
+    "All" : "Toate ",
+    "No results" : "Niciun rezultat",
     "Update to {version}" : "Actualizare la {version}",
     "Remove" : "Șterge",
     "Disable" : "Dezactivați",
-    "All" : "Toate ",
-    "No results" : "Niciun rezultat",
     "Visit website" : "Viziteaza pagina web",
     "Report a bug" : "Raportează un defect",
     "User documentation" : "Documentație utilizator",
     "Admin documentation" : "Documentație pentru administrare",
     "Developer documentation" : "Documentație pentru dezvoltatori",
     "No apps found for your version" : "Nu au fost găsite aplicații pentru versiunea ta",
-    "Enable" : "Activare",
-    "The app will be downloaded from the app store" : "Aplicația va fi descărcată din magazin",
     "Device settings" : "Setările dispozitivului",
     "Allow filesystem access" : "Permite accesul la fișierele de sistem",
     "Rename" : "Redenumește",
@@ -160,11 +154,14 @@ OC.L10N.register(
     "Your apps" : "Aplicațiile tale",
     "Disabled apps" : "Aplicații inactive",
     "Updates" : "Actualizări",
+    "Details" : "Detalii",
     "Add group" : "Adaugă grup",
     "Everyone" : "Toți",
     "Admins" : "Administratori",
     "Show user backend" : "Arată administrare utilizator",
     "Send email to new user" : "Trimite email către noul utilizator",
+    "Enable" : "Activare",
+    "The app will be downloaded from the app store" : "Aplicația va fi descărcată din magazin",
     "Never" : "Niciodată",
     "App update" : "Actualizare aplicație",
     "Administrator documentation" : "Documentație pentru administrare",
@@ -202,7 +199,6 @@ OC.L10N.register(
     "Enable encryption" : "Activează criptarea",
     "Select default encryption module:" : "Selectează modulul implicit de criptare:",
     "Start migration" : "Pornește migrarea",
-    "Execute one task with each page loaded" : "Execută o sarcină la fiecare pagină încărcată",
     "Allow apps to use the Share API" : "Permite aplicațiilor să folosească API-ul de partajare",
     "Expire after " : "Expiră după",
     "days" : "zile",
@@ -213,15 +209,12 @@ OC.L10N.register(
     "Allow resharing" : "Permite repartajarea",
     "Allow sharing with groups" : "Permite partajarea cu grupuri",
     "Exclude groups from sharing" : "Exclude grupuri de la partajare",
-    "Personal" : "Personal",
-    "Administration" : "Administrare",
     "Profile picture" : "Imagine de profil",
     "Upload new" : "Încarcă una nouă",
     "Select from Files" : "Selectează din fișiere",
     "Remove image" : "Înlătură imagine",
     "png or jpg, max. 20 MB" : "png sau jpg, max. 20 MB",
     "Choose as profile picture" : "Alege ca imagine de profil",
-    "Details" : "Detalii",
     "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "Utilizezi <strong>%1$s</strong> din <strong>%2$s</strong> (<strong>%3$s %%</strong>)",
     "Full name" : "Nume complet",
     "Your email address" : "Adresa ta de email",
@@ -238,7 +231,6 @@ OC.L10N.register(
     "Current password" : "Parola curentă",
     "New password" : "Noua parolă",
     "Change password" : "Schimbă parola",
-    "Share" : "Partajează",
     "An error occurred. Please upload an ASCII-encoded PEM certificate." : "A apărut o eroare. Te rugăm să uploadezi un certificat PEM în format ASCII.",
     "Valid until {date}" : "Valabil până la {date}",
     "Local" : "Local",
@@ -247,162 +239,13 @@ OC.L10N.register(
     "Contacts" : "Contacte",
     "Visible to local users and to trusted servers" : "Vizibil userilor locali si serverelor de încredere",
     "Will be synced to a global and public address book" : "Va fi sincronizat cu o agendă de adrese publice și globale",
-    "Afrikaans (Namibia)" : "Afrikaans (Namibia)",
-    "Afrikaans (South Africa)" : "Afrikaans (South Africa)",
-    "Afrikaans" : "Afrikaans",
-    "Akan (Ghana)" : "Akan (Ghana)",
-    "Akan" : "Akan",
-    "Albanian (Albania)" : "Albanian (Albania)",
-    "Albanian" : "Albanian",
-    "Amharic (Ethiopia)" : "Amharic (Ethiopia)",
-    "Amharic" : "Amharic",
-    "Arabic (Algeria)" : "Arabic (Algeria)",
-    "Arabic (Bahrain)" : "Arabic (Bahrain)",
-    "Arabic (Egypt)" : "Arabic (Egypt)",
-    "Arabic (Iraq)" : "Arabic (Iraq)",
-    "Arabic (Jordan)" : "Arabic (Jordan)",
-    "Arabic (Kuwait)" : "Arabic (Kuwait)",
-    "Arabic (Lebanon)" : "Arabic (Lebanon)",
-    "Arabic (Libya)" : "Arabic (Libya)",
-    "Arabic (Morocco)" : "Arabic (Morocco)",
-    "Arabic (Oman)" : "Arabic (Oman)",
-    "Arabic (Qatar)" : "Arabic (Qatar)",
-    "Arabic (Saudi Arabia)" : "Arabic (Saudi Arabia)",
-    "Arabic (Sudan)" : "Arabic (Sudan)",
-    "Arabic (Syria)" : "Arabic (Syria)",
-    "Arabic (Tunisia)" : "Arabic (Tunisia)",
-    "Arabic (United Arab Emirates)" : "Arabic (United Arab Emirates)",
-    "Arabic (Yemen)" : "Arabic (Yemen)",
-    "Arabic" : "Arabic",
-    "Armenian (Armenia)" : "Armenian (Armenia)",
-    "Armenian" : "Armenian",
-    "Assamese (India)" : "Assamese (India)",
-    "Assamese" : "Assamese",
-    "Asu (Tanzania)" : "Asu (Tanzania)",
-    "Asu" : "Asu",
-    "Azerbaijani (Cyrillic)" : "Azerbaijani (Cyrillic)",
-    "Azerbaijani (Cyrillic, Azerbaijan)" : "Azerbaijani (Cyrillic, Azerbaijan)",
-    "Azerbaijani (Latin)" : "Azerbaijani (Latin)",
-    "Azerbaijani (Latin, Azerbaijan)" : "Azerbaijani (Latin, Azerbaijan)",
-    "Azerbaijani" : "Azerbaijani",
-    "Bambara (Mali)" : "Bambara (Mali)",
-    "Bambara" : "Bambara",
-    "Basque (Spain)" : "Basque (Spain)",
-    "Basque" : "Basque",
-    "Belarusian (Belarus)" : "Belarusian (Belarus)",
-    "Belarusian" : "Belarusian",
-    "Bemba (Zambia)" : "Bemba (Zambia)",
-    "Bemba" : "Bemba",
-    "Bena (Tanzania)" : "Bena (Tanzania)",
-    "Bena" : "Bena",
-    "Bengali (Bangladesh)" : "Bengali (Bangladesh)",
-    "Bengali (India)" : "Bengali (India)",
-    "Bengali" : "Bengali",
-    "Bosnian (Bosnia and Herzegovina)" : "Bosnian (Bosnia and Herzegovina)",
-    "Bosnian" : "Bosnian",
-    "Bulgarian (Bulgaria)" : "Bulgarian (Bulgaria)",
-    "Bulgarian" : "Bulgarian",
-    "Burmese (Myanmar [Burma])" : "Burmese (Myanmar [Burma])",
-    "Burmese" : "Burmese",
-    "Catalan (Spain)" : "Catalan (Spain)",
-    "Catalan" : "Catalan",
-    "Central Morocco Tamazight (Latin)" : "Central Morocco Tamazight (Latin)",
-    "Central Morocco Tamazight (Latin, Morocco)" : "Central Morocco Tamazight (Latin, Morocco)",
-    "Central Morocco Tamazight" : "Central Morocco Tamazight",
-    "Cherokee (United States)" : "Cherokee (United States)",
-    "Cherokee" : "Cherokee",
-    "Chiga (Uganda)" : "Chiga (Uganda)",
-    "Chiga" : "Chiga",
-    "Chinese (Simplified Han)" : "Chineză (Simplified Han)",
-    "Chinese (Simplified Han, China)" : "Chineză (Simplified Han, China)",
-    "Chinese (Simplified Han, Hong Kong SAR China)" : "Chineză (Han Simplificată, Hong Kong SAR China)",
-    "Chinese (Simplified Han, Macau SAR China)" : "Chineză (Han Simplificată, Macau SAR China)",
-    "Chinese (Simplified Han, Singapore)" : "Chineză (Han Simplificată, Singapore)",
-    "Chinese (Traditional Han)" : "Chineză (Han Traditională)",
-    "Chinese (Traditional Han, Hong Kong SAR China)" : "Chineză (Han Traditională, Hong Kong SAR China)",
-    "Chinese (Traditional Han, Macau SAR China)" : "Chineză (Han Traditională, Macau SAR China)",
-    "Chinese (Traditional Han, Taiwan)" : "Chineză (Han Traditională, Taiwan)",
-    "Chinese" : "Chineză",
-    "Cornish (United Kingdom)" : "Cornish (United Kingdom)",
-    "Cornish" : "Cornish",
-    "Croatian (Croatia)" : "Croatian (Croatia)",
-    "Croatian" : "Croatian",
-    "Czech (Czech Republic)" : "Chehă (Republica Chehă)",
-    "Czech" : "Chehă",
-    "Danish" : "Danish",
-    "English" : "English",
-    "Esperanto" : "Esperanto",
-    "Estonian" : "Estonian",
-    "Ewe" : "Ewe",
-    "Faroese" : "Faroese",
-    "Finnish" : "Finnish",
-    "French" : "French",
-    "Fulah" : "Fulah",
-    "Galician" : "Galician",
-    "Ganda" : "Ganda",
-    "Georgian" : "Georgian",
-    "German" : "German",
-    "Gujarati" : "Gujarati",
-    "Hausa" : "Hausa",
-    "Hebrew" : "Hebrew",
-    "Hindi" : "Hindi",
-    "Hungarian" : "Hungarian",
-    "Icelandic" : "Icelandic",
-    "Igbo" : "Igbo",
-    "Indonesian" : "Indonesian",
-    "Irish" : "Irish",
-    "Italian" : "Italian",
-    "Japanese" : "Japanese",
-    "Kannada" : "Kannada",
-    "Kazakh" : "Kazakh",
-    "Kinyarwanda" : "Kinyarwanda",
-    "Korean" : "Korean",
-    "Latvian" : "Latvian",
-    "Lithuanian" : "Lithuanian",
-    "Macedonian" : "Macedonian",
-    "Malagasy" : "Malagasy",
-    "Malay" : "Malay",
-    "Malayalam" : "Malayalam",
-    "Maltese" : "Maltese",
-    "Manx" : "Manx",
-    "Marathi" : "Marathi",
-    "Nepali" : "Nepali",
-    "Oriya" : "Oriya",
-    "Oromo" : "Oromo",
-    "Persian" : "Persian",
-    "Polish" : "Polish",
-    "Portuguese" : "Portuguese",
-    "Romansh" : "Romansh",
-    "Russian" : "Russian",
-    "Sango" : "Sango",
-    "Serbian" : "Serbian",
-    "Shona" : "Shona",
-    "Slovak" : "Slovak",
-    "Slovenian" : "Slovenian",
-    "Somali" : "Somali",
-    "Swahili" : "Swahili",
-    "Swedish" : "Swedish",
-    "Tamil" : "Tamil",
-    "Telugu" : "Telugu",
-    "Thai" : "Thai",
-    "Tibetan" : "Tibetan",
-    "Tigrinya" : "Tigrinya",
-    "Tonga" : "Tonga",
-    "Turkish" : "Turkish",
-    "Ukrainian" : "Ukrainian",
-    "Urdu" : "Urdu",
-    "Uzbek" : "Uzbek",
-    "Vietnamese" : "Vietnamese",
-    "Welsh" : "Welsh",
-    "Yoruba" : "Yoruba",
-    "Zulu" : "Zulu",
-    "Official" : "Oficial",
+    "by" : "de",
     "SSL Root Certificates" : "Certificate SSL rădăcină",
     "Common Name" : "Nume comun",
     "Valid until" : "Valabil până la",
     "Issued By" : "Emis de",
     "Valid until %s" : "Valabil până la %s",
     "Import root certificate" : "Importă certificat rădăcină",
-    "Set default expiration date" : "Setează data implicită de expirare"
+    "Execute one task with each page loaded" : "Execută o sarcină la fiecare pagină încărcată"
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
