@@ -38,7 +38,7 @@ OC.L10N.register(
     "{actor} removed {user} from group {group}" : "{actor} odstrani uporabnika {user} iz skupine {group}",
     "An administrator removed you from group {group}" : "Skrbnik vas odstrani iz skupine {group}",
     "An administrator removed {user} from group {group}" : "Skrbnik odstrani uporabnika {user} iz skupine {group}",
-    "Your <strong>group memberships</strong> were modified" : "Vaše <strong>članstvo v skupinah</strong> je spremenjeno",
+    "Your <strong>group memberships</strong> were modified" : "Spremenjeno je vaše <strong>članstvo v skupinah</strong> ",
     "{actor} changed your password" : "{actor} spremeni moje geslo",
     "You changed your password" : "Spremenite geslo",
     "Your password was reset by an administrator" : "Skrbnik sistema ponastavi moje geslo",
@@ -51,7 +51,7 @@ OC.L10N.register(
     "You renamed app password \"{token}\" to \"{newToken}\"" : "Preimenujete žeton gesla programa »{token}« to »{newToken}«",
     "You granted filesystem access to app password \"{token}\"" : "Odobrite sistemski dostop do žetona gesla programa »{token}«",
     "You revoked filesystem access from app password \"{token}\"" : "Odobrite sistemski datotečni dostop gesla programa »{token}«",
-    "Security" : "Varnost",
+    "Security" : "Varnostna opozorila",
     "You successfully logged in using two-factor authentication (%1$s)" : "Uspešno zabeležite uporabo dvo-stopenjske overitve (%1$s)",
     "A login attempt using two-factor authentication failed (%1$s)" : "Poskus prijave z dvostopenjsko overitvijo je spodletel (%1$s)",
     "Remote wipe was started on %1$s" : "Oddaljeno varnostno brisanje je bilo začeto na %1$s.",
@@ -79,6 +79,8 @@ OC.L10N.register(
     "Settings saved" : "Nastavitve so shranjene.",
     "Unable to change full name" : "Ni mogoče spremeniti polnega imena",
     "Unable to change email address" : "Ni mogoče spremeniti elektronskega naslova",
+    "Unable to set invalid phone number" : "Ni mogoče nastaviti neveljavne telefonske številke",
+    "Some account data was invalid" : "Nekateri podatki računa niso veljavni",
     "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Za overitev računa Twitter, objavite sporočilo (prepričajte se, da ni nobenega preloma vrstice):",
     "%1$s changed your password on %2$s." : "%1$s spremeni vaše geslo %2$s.",
     "Your password on %s was changed." : "Vaše geslo %s je bilo spremenjeno.",
@@ -154,7 +156,7 @@ OC.L10N.register(
     "No apps found for your version" : "Za navedeni iskalni niz ni programov",
     "Disable all" : "Onemogoči vse",
     "Enable all" : "Omogoči vse",
-    "_%n app has an update available_::_%n apps have an update available_" : ["Za %n program je na voljo posodobitev.","Za %n programa so na voljo posodobitve.","Za %n programe so na voljo posodobitve.","Za %n programov so na voljo posodobitve."],
+    "_%n app has an update available_::_%n apps have an update available_" : ["Na voljo je posodobitev za %n program.","Na voljo sta posodobitvi za %n programa.","Na voljo so posodobitve za %n programe.","Na voljo so posodobitve za %n programov."],
     "Marked for remote wipe" : "Označeno za oddaljeno varnostno brisanje",
     "Device settings" : "Nastavitve naprave",
     "Allow filesystem access" : "Dovoli dostop do datotečnega sistema",
@@ -199,11 +201,11 @@ OC.L10N.register(
     "Copy" : "Kopiraj",
     "Could not copy app password. Please copy it manually." : "Gesla programa ni mogoče kopirati. Storite to ročno.",
     "You do not have permissions to see the details of this user" : "Ni ustreznih dovoljenj za pregled podatkov uporabnika",
-    "Add new password" : "Dodaj novo geslo",
-    "Add new email address" : "Dodaj nov elektronski naslov",
+    "Add new password" : "Vpis gesla",
+    "Add new email address" : "Vpis elektronskega naslova",
     "Add user in group" : "Dodaj uporabnika v skupino",
     "Set user as admin for" : "Nastavi uporabnika kot skrbnika za",
-    "Select user quota" : "Izbor količinske omejitve uporabnika",
+    "Select user quota" : "Količinska omejitev prostora",
     "No language set" : "Jezik ni nastavljen",
     "Delete user" : "Izbriši uporabnika",
     "Wipe all devices" : "Varnostno izbriši vse naprave",
@@ -316,7 +318,7 @@ OC.L10N.register(
     "Test email settings" : "Preizkus nastavitev elektronske pošte",
     "Send email" : "Pošlji elektronsko sporočilo",
     "Security & setup warnings" : "Varnost in namestitvena opozorila",
-    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Zaradi varnosti in optimizacije delovanja je pomembno, da je sistem pravilno nastavljen. Za pomoč pri preverjanju se samodejno izvajajo nekateri preizkusi. Več podrobnosti o tem je zabeleženih v dokumentaciji. ",
+    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Zaradi varnosti in optimizacije delovanja je pomembno, da je sistem pravilno nastavljen. Za preverjanj se nekateri preizkusi izvajajo samodejno. Več podrobnosti je zabeleženih v dokumentaciji. ",
     "All checks passed." : "Vsa preverjanja so uspešno zaključena.",
     "There are some errors regarding your setup." : "Med preverjanjem je bilo zaznanih je nekaj napak namestitve.",
     "There are some warnings regarding your setup." : "Med preverjanjem je bilo zbranih nekaj opozoril.",
@@ -356,7 +358,7 @@ OC.L10N.register(
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Skrbnik lahko prilagodi možnosti souporabe. Več podrobnosti je zapisanih v dokumentaciji.",
     "Allow apps to use the Share API" : "Dovoli programom uporabo vmesnika API souporabe",
     "Set default expiration date for shares" : "Nastavi privzeti datuma poteka za mesta souporabe",
-    "Expire after " : "Povezava naj poteče po",
+    "Expire after " : "Povezava naj preteče po",
     "days" : "dneh.",
     "Enforce expiration date" : "Vsili datum preteka",
     "Allow users to share via link" : "Uporabnikom dovoli omogočanje souporabe s povezavami",
