@@ -68,6 +68,7 @@ OC.L10N.register(
     "installing and updating apps via the app store or Federated Cloud Sharing" : "通过应用程序商店或联合云共享安装和更新应用程序",
     "Federated Cloud Sharing" : "联合云共享",
     "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL正使用一个过时的%1$s 版本 (%2$s)。请升级您的操作系统，否则像 %3$s 这样的特性将无法可靠地工作。",
+    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the nextcloud log file for more details." : "不能确定 cURL 的 TLS 版本是否已过时，因为在HTTPS请求 https://nextcloud.com 时发生了错误。请检查 nextcloud 日志文件以了解详情。",
     "Invalid SMTP password." : "无效的 SMTP 密码",
     "Email setting test" : "电子邮件设置测试",
     "Well done, %s!" : "已完成，%s！",
@@ -79,6 +80,8 @@ OC.L10N.register(
     "Settings saved" : "设置已保存",
     "Unable to change full name" : "无法修改全名",
     "Unable to change email address" : "无法修改电子邮箱地址",
+    "Unable to set invalid phone number" : "无法设置有效的电话号码",
+    "Some account data was invalid" : "一些账号数据无效",
     "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "为了验证您的 Twitter 账号，请在 Twitter 上发布以下推文（请确保发布内容中没有任何换行符）：",
     "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "为了验证您的网站，请将以下内容存储在“.well-known / CloudIdVerificationCode.txt”的网络根目录中（请确保完整的文本在一行中）：",
     "%1$s changed your password on %2$s." : "%1$s 更改了您在 %2$s 上的密码。",
