@@ -1,7 +1,6 @@
 OC.L10N.register(
     "systemtags",
     {
-    "Tags" : "ტეგები",
     "Update" : "განახლება",
     "Create" : "შექმნა",
     "Select tag…" : "ტეგის არჩევა…",
@@ -36,6 +35,7 @@ OC.L10N.register(
     "%s (restricted)" : "%s (აკრძალული)",
     "%s (invisible)" : "%s (უჩინარი)",
     "<strong>System tags</strong> for a file have been modified" : "<strong>სისტემური ტეგები</strong> ფაილისთვის შეიცვალა",
+    "Tags" : "ტეგები",
     "Collaborative tags" : "თანამშრომლობის ტეგები",
     "Tagged files" : "დატაგული ფაილები",
     "Select tags to filter by" : "ფილტრაციისთვის აირჩიეთ ტეგები",
@@ -43,6 +43,7 @@ OC.L10N.register(
     "Please select tags to filter by" : "ფილტრაციისთვის გთხოვთ აირჩიოთ ტეგები",
     "No files found for the selected tags" : "არჩეული ტეგების მიხედვით ფაილების პოვნა ვერ მოხერხდა",
     "Select tag …" : "ტეგის არჩევა …",
+    "Create a new tag" : "ახალი ტეგის შექმნა",
     "Name" : "სახელი",
     "Public" : "ღია",
     "Restricted" : "აკრძალული",
@@ -52,7 +53,6 @@ OC.L10N.register(
     "No files in here" : "აქ ფაილები არაა",
     "No entries found in this folder" : "ამ დირექტორიაში შენატანების მოძებნა ვერ მოხერხდა",
     "Size" : "ზომა",
-    "Modified" : "შეცვლილია",
-    "Create and edit collaborative tags. These tags affect all users." : "შეგიძლიათ შექმნათ და შეცვალოთ თანამშრომლობის ტეგები. ეს ტეგები ეხება ყველა მომხმარებელს."
+    "Modified" : "შეცვლილია"
 },
 "nplurals=2; plural=(n!=1);");
