@@ -1,27 +1,25 @@
 OC.L10N.register(
     "twofactor_backupcodes",
     {
-    "_" : "_",
-    "An error occurred while generating your backup codes" : "Ett fel uppstod vid skapandet av nya återställningsnycklar",
-    "{name} backup codes" : "{name} återställningsnycklar",
-    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Detta är dina återställningsnycklar. Vänligen spara och/eller skriv ut dem eftersom du inte kommer kunna se dessa nycklar igen.",
-    "Save backup codes" : "Spara återställningsnycklar",
-    "Print backup codes" : "Skriv ut återställningsnycklar",
-    "Backup codes have been generated. {used} of {total} codes have been used." : "Återställningsnycklar har skapats. {used} av {total} nycklar har använts.",
-    "Regenerate backup codes" : "Skapa nya återställningsnycklar",
-    "_icon-loading-small_::_generate-backup-codes_" : ["icon-loading-small","Generera återställningsnycklar"],
-    "If you regenerate backup codes, you automatically invalidate old codes." : "Om du skapar nya återställningsnycklar så kommer de gamla automatiskt att sluta fungera.",
-    "Generate backup codes" : "Generera återställningsnycklar",
     "You created two-factor backup codes for your account" : "Du skapade återställningsnycklar till tvåfaktorsautentiseringen på ditt användarkonto.",
     "Second-factor backup codes" : "Tvåfaktorsautentisering",
-    "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor." : "Du har aktiverat tvåfaktorsautentisering men har ännu inte skapat återställningsnycklar. Detta är nödvändigt om du förlorar tillgång till din andra faktor.",
+    "Generate backup codes" : "Generera återställningsnycklar",
+    "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor." : "Du har aktiverat tvåfaktorsautentisering men har ännu inte skapat återställningsnycklar. Detta är nödvändigt om du förlorar åtkomst till din andra faktor.",
     "Backup code" : "Återställningsnyckel",
     "Use backup code" : "Använd återställningsnyckel",
     "Two factor backup codes" : "Återställningsnycklar tvåfaktor",
     "A two-factor auth backup codes provider" : "Återställningsnycklar för tvåfaktorautentisering",
+    "Backup codes have been generated. {used} of {total} codes have been used." : "Återställningsnycklar har skapats. {used} av {total} nycklar har använts.",
+    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Detta är dina återställningsnycklar. Vänligen spara och/eller skriv ut dem eftersom du inte kommer kunna se dessa nycklar igen.",
+    "Save backup codes" : "Spara återställningsnycklar",
+    "Print backup codes" : "Skriv ut återställningsnycklar",
+    "Regenerate backup codes" : "Skapa nya återställningsnycklar",
+    "If you regenerate backup codes, you automatically invalidate old codes." : "Om du skapar nya återställningsnycklar så kommer de gamla automatiskt att sluta fungera.",
+    "An error occurred while generating your backup codes" : "Ett fel uppstod vid skapandet av nya återställningsnycklar",
+    "{name} backup codes" : "{name} återställningsnycklar",
     "Use one of the backup codes you saved when setting up two-factor authentication." : "Använd en av återställningsnycklarna du sparade när du konfigurerar tvåfaktorsautentisering.",
     "Submit" : "Skicka",
-    "You have enabled two-factor authentication but have not yet generated backup codes. Be sure to do this in case you lose access to your second factor." : "Du har aktiverat tvåfaktorsautentisering men har ännu inte skapat återställningsnycklar. Detta är nödvändigt om du förlorar tillgång till din andra faktor.",
-    "function" : "funktion"
+    "_" : "_",
+    "_icon-loading-small_::_generate-backup-codes_" : ["icon-loading-small","Generera återställningsnycklar"]
 },
 "nplurals=2; plural=(n != 1);");
