@@ -36,10 +36,12 @@ OC.L10N.register(
     "Operation %s does not exist" : "Operace %s neexistuje",
     "Operation %s is invalid" : "Operace %s není platná",
     "At least one check needs to be provided" : "Je třeba poskytnou alespoň jednu kontrolu",
+    "The provided operation data is too long" : "Data zadané operace jsou příliš objemná",
     "Invalid check provided" : "Zadána neplatná kontrola",
     "Check %s does not exist" : "Kontrola %s neexistuje",
     "Check %s is invalid" : "Kontrola %s je neplatná",
     "Check %s is not allowed with this entity" : "Zaškrtnutí %s není u této entity povoleno",
+    "The provided check value is too long" : "Zadaná hodnota kontroly je příliš dlouhá",
     "Check #%s does not exist" : "Kontrola č. %s neexistuje",
     "Check %s is invalid or does not exist" : "Kontrola %s není platná, nebo neexistuje",
     "Flow" : "Tok",
