@@ -36,10 +36,12 @@ OC.L10N.register(
     "Operation %s does not exist" : "Operation %s existiert nicht",
     "Operation %s is invalid" : "Operation %s ist ungültig",
     "At least one check needs to be provided" : "Mindestens ein Test muss bereitgestellt werden",
+    "The provided operation data is too long" : "Die bereitgestellten Betriebsdaten sind zu lang",
     "Invalid check provided" : "Ungültiger Test bereitgestellt",
     "Check %s does not exist" : "Die Prüfung %s existiert nicht",
     "Check %s is invalid" : "Die Prüfung %s ist ungültig",
     "Check %s is not allowed with this entity" : "Die Prüfung %s ist mit dieser Entität unzulässig",
+    "The provided check value is too long" : "Der bereitgestellte Prüfwert ist zu lang",
     "Check #%s does not exist" : "Die Prüfung #%s existiert nicht",
     "Check %s is invalid or does not exist" : "Die Prüfung %s ist ungültig ist oder nicht existiert",
     "Flow" : "Ablauf",
