@@ -37,6 +37,7 @@ OC.L10N.register(
     "Select a comparator" : "Elekti komparilon",
     "Select a file type" : "Elekti dosierformon",
     "e.g. httpd/unix-directory" : "ekz. httpd/unix-directory",
+    "Folder" : "Dosierujo",
     "Images" : "Bildoj",
     "Office documents" : "Oficejaj dokumentoj",
     "PDF documents" : "PDF-dokumentoj",
@@ -92,26 +93,6 @@ OC.L10N.register(
     "Request user agent" : "Retumil-identigilo („user-agent“)",
     "User group membership" : "Grupano",
     "is member of" : "estas membro de",
-    "is not member of" : "ne estas membro de",
-    "Short rule description" : "Mallong priskribo de regulo",
-    "Add rule" : "Aldoni regulon",
-    "Reset" : "Restarigi",
-    "Saving…" : "Konservado...",
-    "Group list is empty" : "Gruplisto malplenas",
-    "Unable to retrieve the group list" : "Ne eblas ricevi grupliston",
-    "Saved" : "Konservita",
-    "Saving failed:" : "Konservado malsukcesis:",
-    "Add rule group" : "Aldoni regulgrupon",
-    "Example: {placeholder}" : "Ekzemplo: {placeholder}",
-    "Select tag…" : "Elekti etikedon...",
-    "Start" : "Komenco",
-    "End" : "Fino",
-    "Select timezone…" : "Elekti horzonon...",
-    "Sync clients" : "Sinkronigaj klientoj",
-    "Workflow" : "Laborfluo",
-    "Files workflow engine" : "Modulo de dosiera laborfluo",
-    "Open documentation" : "Malfermi dokumentaron",
-    "Loading…" : "Ŝargado...",
-    "Tag management" : "Etikeda administrado"
+    "is not member of" : "ne estas membro de"
 },
 "nplurals=2; plural=(n != 1);");
