@@ -36,10 +36,12 @@ OC.L10N.register(
     "Operation %s does not exist" : "Operação %s não existe",
     "Operation %s is invalid" : "Operação %s é inválida",
     "At least one check needs to be provided" : "É necessário fornecer ao menos uma verificação",
+    "The provided operation data is too long" : "Os dados de operação fornecidos são muito longos",
     "Invalid check provided" : "Verificação fornecida inválida",
     "Check %s does not exist" : "Verifique se %s não existe",
     "Check %s is invalid" : "Verifique se %s é inválido",
     "Check %s is not allowed with this entity" : "Verificação de %s não é permitida nesta entidade",
+    "The provided check value is too long" : "O valor de verificação fornecido é muito longo",
     "Check #%s does not exist" : "Verifique se %s não existe",
     "Check %s is invalid or does not exist" : "Verifique se %s é valido ou existe",
     "Flow" : "Fluxo",
