@@ -2,6 +2,7 @@
 /**
  * @copyright Copyright (c) 2016, ownCloud, Inc.
  *
+ * @author Christoph Wurst <christoph@winzerhof-wurst.at>
  * @author Joas Schilling <coding@schilljs.com>
  * @author Morris Jobke <hey@morrisjobke.de>
  * @author Robin McCorkell <robin@mccorkell.me.uk>
@@ -34,7 +35,6 @@ use OC\App\CodeChecker\InfoChecker;
 use OC\App\CodeChecker\LanguageParseChecker;
 use OC\App\CodeChecker\PrivateCheck;
 use OC\App\CodeChecker\StrongComparisonCheck;
-use OC\App\InfoParser;
 use Stecman\Component\Symfony\Console\BashCompletion\Completion\CompletionAwareInterface;
 use Stecman\Component\Symfony\Console\BashCompletion\CompletionContext;
 use Symfony\Component\Console\Command\Command;
@@ -43,8 +43,7 @@ use Symfony\Component\Console\Input\InputInterface;
 use Symfony\Component\Console\Input\InputOption;
 use Symfony\Component\Console\Output\OutputInterface;
 
-class CheckCode extends Command implements CompletionAwareInterface  {
-
+class CheckCode extends Command implements CompletionAwareInterface {
 	protected $checkers = [
 		'private' => PrivateCheck::class,
 		'deprecation' => DeprecationCheck::class,
@@ -81,7 +80,7 @@ class CheckCode extends Command implements CompletionAwareInterface  {
 			);
 	}
 
-	protected function execute(InputInterface $input, OutputInterface $output) {
+	protected function execute(InputInterface $input, OutputInterface $output): int {
 		$appId = $input->getArgument('app-id');
 
 		$checkList = new EmptyCheck();
@@ -95,40 +94,40 @@ class CheckCode extends Command implements CompletionAwareInterface  {
 
 		$codeChecker = new CodeChecker($checkList, !$input->getOption('skip-validate-info'));
 
-		$codeChecker->listen('CodeChecker', 'analyseFileBegin', function($params) use ($output) {
-			if(OutputInterface::VERBOSITY_VERBOSE <= $output->getVerbosity()) {
+		$codeChecker->listen('CodeChecker', 'analyseFileBegin', function ($params) use ($output) {
+			if (OutputInterface::VERBOSITY_VERBOSE <= $output->getVerbosity()) {
 				$output->writeln("<info>Analysing {$params}</info>");
 			}
 		});
-		$codeChecker->listen('CodeChecker', 'analyseFileFinished', function($filename, $errors) use ($output) {
+		$codeChecker->listen('CodeChecker', 'analyseFileFinished', function ($filename, $errors) use ($output) {
 			$count = count($errors);
 
 			// show filename if the verbosity is low, but there are errors in a file
-			if($count > 0 && OutputInterface::VERBOSITY_VERBOSE > $output->getVerbosity()) {
+			if ($count > 0 && OutputInterface::VERBOSITY_VERBOSE > $output->getVerbosity()) {
 				$output->writeln("<info>Analysing {$filename}</info>");
 			}
 
 			// show error count if there are errors present or the verbosity is high
-			if($count > 0 || OutputInterface::VERBOSITY_VERBOSE <= $output->getVerbosity()) {
+			if ($count > 0 || OutputInterface::VERBOSITY_VERBOSE <= $output->getVerbosity()) {
 				$output->writeln(" {$count} errors");
 			}
-			usort($errors, function($a, $b) {
+			usort($errors, function ($a, $b) {
 				return $a['line'] >$b['line'];
 			});
 
-			foreach($errors as $p) {
+			foreach ($errors as $p) {
 				$line = sprintf("%' 4d", $p['line']);
 				$output->writeln("    <error>line $line: {$p['disallowedToken']} - {$p['reason']}</error>");
 			}
 		});
 		$errors = [];
-		if(!$input->getOption('skip-checkers')) {
+		if (!$input->getOption('skip-checkers')) {
 			$errors = $codeChecker->analyse($appId);
 		}
 
-		if(!$input->getOption('skip-validate-info')) {
+		if (!$input->getOption('skip-validate-info')) {
 			$infoChecker = new InfoChecker();
-			$infoChecker->listen('InfoChecker', 'parseError', function($error) use ($output) {
+			$infoChecker->listen('InfoChecker', 'parseError', function ($error) use ($output) {
 				$output->writeln("<error>Invalid appinfo.xml file found: $error</error>");
 			});
 
