@@ -86,6 +86,7 @@ OC.L10N.register(
     "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Vámi využívaná verze PHP nepodporuje FreeType, což bude mít za následky vizuální nedostatky u obrázků profilů a v rozhraní pro nastavování.",
     "Missing index \"{indexName}\" in table \"{tableName}\"." : "Chybí index „{indexName}“ v tabulce „{tableName}“.",
     "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "V databázi chybí některé indexy. Protože přidávání indexů na velkých tabulkách může zabrat nějaký čas, nebyly přidány automaticky. Spuštěním „occ db:add-missing-indices“ je možné tyto chybějící indexy ručně za provozu instance. Po přidání indexů dotazy do těchto tabulek jsou obvykle mnohem rychlejší.",
+    "Missing primary key on table \"{tableName}\"." : "Chybí primární klíč v tabulce \"{tableName}\".",
     "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "Chybí volitelný sloupec „{columnName}“ v tabulce „{tableName}“.",
     "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "V databázi chybí některé volitelné sloupce. Protože přidání sloupců do rozsáhlých tabulek může trvat dlouho, nebyly přidány automaticky (jsou volitelné). Spuštěním příkazu \"occ db:add-missing-columns\" je možné tyto chybějící sloupce přidat ručně a to za provozu instance. Po přidání se může zlepšit doba reakce a použitelnost některých funkcí.",
     "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "V této instanci chybí některé doporučené moduly PHP. Pro lepší výkon a kompatibilitu, je důrazně doporučeno je nainstalovat.",
@@ -259,6 +260,7 @@ OC.L10N.register(
     "Too many requests" : "Příliš mnoho požadavků",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Z vaší sítě bylo příliš mnoho požadavků. Zkuste to později nebo (pokud je toto chyba) se obraťte na svého správce.",
     "Error" : "Chyba",
+    "Previous" : "Předchozí",
     "Internal Server Error" : "Vnitřní chyba serveru",
     "The server was unable to complete your request." : "Server nemohl dokončit váš požadavek.",
     "If this happens again, please send the technical details below to the server administrator." : "Pokud se toto stane znovu, pošlete níže uvedené technické podrobnosti správci serveru.",
