@@ -45,7 +45,6 @@ OC.L10N.register(
     "Starting code integrity check" : "Comenzando verificación de integridad del código",
     "Finished code integrity check" : "Terminó la verificación de integridad del código ",
     "%s (incompatible)" : "%s (incompatible)",
-    "Following apps have been disabled: %s" : "Las siguientes aplicaciones han sido deshabilitadas: %s",
     "Already up to date" : "Ya está actualizado",
     "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Tu servidor web aún no esta correctamente configurado para permitir la sincronización de archivos porque la interfaz WebDAV parece estar rota. ",
     "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "Tu servidor web no está correctamente configurado para resolver \"{url}\". Puedes encontrar más información al respecto en la <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentación</a>.",
@@ -66,13 +65,6 @@ OC.L10N.register(
     "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Probablemente tu directorio de datos y archivos sean accesibles desde Internet. El archivo .htaccess no está funcionando. Se recomienda ampliamente que configures tu servidor web para que el directorio de datos no sea accesible, o bien, que muevas el directorio de datos fuera del directorio raíz del servidor web.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "El encabezado HTTP \"{header}\" está establecido a \"{expected}\". Esto representa un riesgo potencial de seguridad o privacidad, y que se recomienda ajustar esta configuración. ",
     "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "El encabezado HTTP \"{header}\" no está establecido a \"{expected}\". Puede que lgunas características no funcionen correctamente, y se recomienda ajustar esta confirguración. ",
-    "Non-existing tag #{tag}" : "Etiqueta #{tag} no-existente",
-    "restricted" : "restringido",
-    "invisible" : "invisible",
-    "Delete" : "Borrar",
-    "Rename" : "Renombrar",
-    "Collaborative tags" : "Etiquetas colaborativas",
-    "No tags found" : "No se encontraron etiquetas",
     "unknown text" : "texto desconocido",
     "Hello world!" : "¡Hola mundo!",
     "sunny" : "soleado",
@@ -89,9 +81,6 @@ OC.L10N.register(
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "La actualización no fue exitosa. Por favor reporta este tema a la <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Comunidad Nextcloud</a>.",
     "Continue to Nextcloud" : "Continuar a Nextcloud",
     "_The update was successful. Redirecting you to Nextcloud in %n second._::_The update was successful. Redirecting you to Nextcloud in %n seconds._" : ["La actualización fue exitosa. Lo estamos redireccionando a Nextcloud en %n segundo. ","La actualización fue exitosa. Te redireccionaremos a Nextcloud en %n segundos."],
-    "Searching other places" : "Buscando en otras ubicaciones",
-    "No search results in other folders for {tag}{filter}{endtag}" : "No hay resultados para la búsqueda {tag}{filter}{endtag} en otras carpetas",
-    "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} resultado de la búsqueda en otra carpeta","{count} resultados de la búsqueda en otras carpetas"],
     "Log in" : "Ingresar",
     "Logging in …" : "Iniciando sesión ...",
     "Server side authentication failed!" : "¡Falló la autenticación del lado del servidor!",
@@ -110,6 +99,7 @@ OC.L10N.register(
     "Cancel" : "Cancelar",
     "Forgot password?" : "¿Olvidaste tu contraseña?",
     "Back" : "Atrás",
+    "Reset search" : "Reestablecer búsqueda",
     "Settings" : "Configuraciones ",
     "Search contacts …" : "Buscar contactos ...",
     "No contacts found" : "No se encontraron contactos",
@@ -162,6 +152,13 @@ OC.L10N.register(
     "Strong password" : "Contraseña fuerte",
     "No action available" : "No hay acciones disponibles",
     "Error fetching contact actions" : "Se presentó un error al traer las acciónes de contatos",
+    "Non-existing tag #{tag}" : "Etiqueta #{tag} no-existente",
+    "restricted" : "restringido",
+    "invisible" : "invisible",
+    "Delete" : "Borrar",
+    "Rename" : "Renombrar",
+    "Collaborative tags" : "Etiquetas colaborativas",
+    "No tags found" : "No se encontraron etiquetas",
     "Personal" : "Personal",
     "Users" : "Usuarios",
     "Apps" : "Aplicaciones",
@@ -208,8 +205,6 @@ OC.L10N.register(
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Esta aplicación requiere de JavaScript para su correcta operación. Por favor {linkstart}habilita JavaScript{linkend} y vuelve a cargar la página. ",
     "More apps" : "Más aplicaciones",
     "More" : "Más",
-    "Search" : "Buscar",
-    "Reset search" : "Reestablecer búsqueda",
     "Contacts" : "Contactos",
     "Confirm your password" : "Confirma tu contraseña",
     "App token" : "Ficha de la aplicación",
@@ -225,7 +220,6 @@ OC.L10N.register(
     "Access through untrusted domain" : "Accesa a través de un dominio no de confianza",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Por favor contacta a tu adminsitrador. Si tu eres un administrador, edita la propiedad \"trusted_domains\" en el archivo config/config.php como en el ejemplo config.sample.php.",
     "App update required" : "Se requiere una actualización de la aplicación",
-    "These apps will be updated:" : "Las siguientes apllicaciones se actualizarán:",
     "These incompatible apps will be disabled:" : "Las siguientes aplicaciones incompatibles serán deshabilitadas:",
     "The theme %s has been disabled." : "El tema %s ha sido deshabilitado. ",
     "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Por favor asegurarte de que la base de datos, la carpeta de configuración y las carpetas de datos hayan sido respaldadas antes de continuar. ",
@@ -239,71 +233,14 @@ OC.L10N.register(
     "Upgrade via web on my own risk" : "Actualizar vía Web bajo mi propio riesgo",
     "This %s instance is currently in maintenance mode, which may take a while." : "Esta instancia %s se encuentra actualmente en modo mantenimiento, que podría tomar algo de tiempo. ",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Contacta a tu administrador del sistema si este mensaje persiste o se presentó de manera inesperada.",
-    "Could not send reset email because there is no email address for this username. Please contact your administrator." : "No fue posible enviar el correo electrónico para restablecer porque no hay una dirección de correo electrónico para este usuario. Por favor contacta a tu adminsitrador. ",
-    "Couldn't send reset email. Please make sure your username is correct." : "No fue posible restablecer el correo electrónico. Por favor asegurarte de que tu nombre de usuario sea correcto. ",
-    "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Tus archivos están encriptados. No habrá manera de recuperar tus datos una vez que restablezca tu contraseña. <br />Si no estás seguro de qué hacer, por favor contacta a tu administrador antes de continuar. <br />¿Realmente deseas continuar?",
-    "Sending email …" : "Enviando correo electrónico ...",
+    "Following apps have been disabled: %s" : "Las siguientes aplicaciones han sido deshabilitadas: %s",
     "You are currently running PHP 5.6. The current major version of Nextcloud is the last that is supported on PHP 5.6. It is recommended to upgrade the PHP version to 7.0+ to be able to upgrade to Nextcloud 14." : "Actualmente estás corriendo PHP 5.6. La versión principal actual de Nextcloud es la última que será soportada en PHPH 5.6. Te recomendamos actualizar la versión de PHP a la 7.0+ para que puedas actualizar a Nextcloud 14.",
-    "Shared" : "Compartido",
-    "Shared with" : "Compartido con",
-    "Shared by" : "Compartido por",
-    "Choose a password for the public link" : "Seleccione una contraseña para la liga pública",
-    "Choose a password for the public link or press the \"Enter\" key" : "Elige una contraseña para la liga pública o presiona la tecla \"Intro\"",
-    "Copied!" : "¡Copiado!",
-    "Copy link" : "Copiar liga",
-    "Not supported!" : "¡No está soportado!",
-    "Press ⌘-C to copy." : "Presiona ⌘-C para copiar.",
-    "Press Ctrl-C to copy." : "Presiona Ctrl-C para copiar.",
-    "Resharing is not allowed" : "No se permite volver a compartir",
-    "Link" : "Liga",
-    "Password protect" : "Proteger con contraseña",
-    "Allow editing" : "Permitir editar",
-    "Email link to person" : "Enviar la liga por correo electrónico a una persona",
-    "Send" : "Enviar",
-    "Allow upload and editing" : "Permitir carga y edición",
-    "Read only" : "Sólo lectura",
-    "File drop (upload only)" : "Permitir carga",
-    "Set expiration date" : "Selecciona la vigencia de tu archivo",
-    "Expiration" : "Expiración",
-    "Expiration date" : "Fecha de expiración",
-    "Unshare" : "Dejar de compartir",
-    "Share to {name}" : "Compartir con {name}",
-    "Share link" : "Compartir liga",
-    "Could not unshare" : "No fue posible dejar de compartir",
-    "Shared with you and the group {group} by {owner}" : "Compartido contigo y el grupo {group} por {owner}",
-    "Shared with you by {owner}" : "Compartido contigo por {owner}",
-    "Choose a password for the mail share" : "Elige una contraseña para el elemento compartido por correo",
-    "group" : "grupo",
-    "remote" : "remoto",
-    "email" : "correo electrónico",
-    "shared by {sharer}" : "compartido por {sharer}",
-    "Can reshare" : "Puede volver a compartir",
-    "Can edit" : "Puede editar",
-    "Can create" : "Puede crear",
-    "Can change" : "Puede cambiar",
-    "Can delete" : "Puede borrar",
-    "Access control" : "Control de acceso",
-    "Error while sharing" : "Se presentó un error al compartir",
-    "Share details could not be loaded for this item." : "Los detalles del recurso compartido no se pudieron cargar para este elemento. ",
-    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["Se requiere de la menos {count} caracter para el auto completar","Se requieren de la menos {count} caracteres para el auto completar"],
-    "This list is maybe truncated - please refine your search term to see more results." : "Esta lista puede estar truncada - por favor refina tus términos de búsqueda para poder ver más resultados. ",
-    "No users or groups found for {search}" : "No se encontraron usuarios o gurpos para {search}",
-    "No users found for {search}" : "No se encontraron usuarios para {search}",
-    "An error occurred. Please try again" : "Se presentó un error. Por favor vuelve a intentarlo",
-    "Home" : "Inicio",
-    "Work" : "Trabajo",
-    "Other" : "Otro",
-    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
-    "Share" : "Compartir",
-    "Name or email address..." : "Nombre o dirección de correo electrónico",
-    "Name or federated cloud ID..." : "Nombre...",
-    "Name, federated cloud ID or email address..." : "Nombre o dirección de correo electrónico...",
-    "Name..." : "Nombre...",
-    "Error removing share" : "Se presentó un error al dejar de compartir",
     "({scope})" : "({scope})",
+    "Searching other places" : "Buscando en otras ubicaciones",
+    "No search results in other folders for {tag}{filter}{endtag}" : "No hay resultados para la búsqueda {tag}{filter}{endtag} en otras carpetas",
+    "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} resultado de la búsqueda en otra carpeta","{count} resultados de la búsqueda en otras carpetas"],
     "Saving..." : "Guardando...",
-    "Dismiss" : "Descartar",
-    "New Password" : "Nueva Contraseña",
-    "Cancel log in" : "Cancelar inicio de sesión"
+    "Search" : "Buscar",
+    "These apps will be updated:" : "Las siguientes apllicaciones se actualizarán:"
 },
 "nplurals=2; plural=(n != 1);");
