@@ -67,9 +67,6 @@ OC.L10N.register(
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "به روزرسانی ناموفق بود. لطفا این مسئله را در <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">جامعه Nextcloud</a> گزارش دهید",
     "Continue to Nextcloud" : "ادامه به Nextcloud",
     "_The update was successful. Redirecting you to Nextcloud in %n second._::_The update was successful. Redirecting you to Nextcloud in %n seconds._" : ["به روز رسانی موفقیت آمیز بود هدایت شما به Nextcloud در %nثانیه ","به روز رسانی موفقیت آمیز بود هدایت شما به Nextcloud در %nثانیه "],
-    "Searching other places" : "جستجو در مکان‌های دیگر",
-    "No search results in other folders for {tag}{filter}{endtag}" : "جستجو در پوشه های دیگر برای {tag}{filter}{endtag} یافت نشد",
-    "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} نتایج جستجو در پوشه های دیگر","{count} نتایج جستجو در پوشه های دیگر"],
     "Log in" : "ورود",
     "Logging in …" : "ورود به سیستم ...",
     "Server side authentication failed!" : "تأیید هویت از سوی سرور انجام نشد!",
@@ -197,7 +194,6 @@ OC.L10N.register(
     "See the documentation" : "مشاهده‌ی مستندات",
     "More apps" : "برنامه های بیشتر",
     "More" : "بیش‌تر",
-    "Search" : "جست‌و‌جو",
     "Contacts" : "مخاطبین",
     "Contacts menu" : "منوی دفتر تلفن",
     "Confirm your password" : "گذرواژه خود را تأیید کنید",
@@ -213,77 +209,12 @@ OC.L10N.register(
     "Detailed logs" : "Detailed logs",
     "Update needed" : "نیاز به روز رسانی دارد",
     "Following apps have been disabled: %s" : "برنامه های زیر غیر فعال شده اند %s",
-    "Shared" : "اشتراک گذاشته شده",
-    "Shared with" : "مشترک با",
-    "Shared by" : "اشتراک گذاشته شده به وسیله",
-    "Choose a password for the public link" : "انتخاب رمز برای لینک عمومی",
-    "Choose a password for the public link or press the \"Enter\" key" : "یک رمز عبور برای لینک عمومی انتخاب کنید یا کلید \"Enter\" را فشار دهید",
-    "Copied!" : "کپی انجام شد!",
-    "Copy link" : "کپی کردن لینک",
-    "Not supported!" : "پشتیبانی وجود ندارد!",
-    "Press ⌘-C to copy." : "برای کپی کردن از دکمه های C+⌘ استفاده نمایید",
-    "Press Ctrl-C to copy." : "برای کپی کردن از دکمه ctrl+c استفاده نمایید",
-    "Resharing is not allowed" : "اشتراک گذاری مجدد مجاز نمی باشد",
-    "Link" : "لینک",
-    "Hide download" : "پنهان کردن بارگیری",
-    "Password protect" : "نگهداری کردن رمز عبور",
-    "Allow editing" : "اجازه‌ی ویرایش",
-    "Email link to person" : "پیوند ایمیل برای شخص.",
-    "Send" : "ارسال",
-    "Allow upload and editing" : "اجازه آپلود و ویرایش",
-    "Read only" : "فقط خواندنی",
-    "File drop (upload only)" : "انداختن فایل (فقط آپلود)",
-    "Expiration date enforced" : "تاریخ انقضا اجرا شده است",
-    "Set expiration date" : "تنظیم تاریخ انقضا",
-    "Expiration" : "تاریخ انقضا",
-    "Expiration date" : "تاریخ انقضا",
-    "Note to recipient" : "توجه داشته باشید به گیرنده",
-    "Unshare" : "لغو اشتراک",
-    "Delete share link" : "پیوند اشتراک را حذف کنید",
-    "Add another link" : "پیوند دیگری اضافه کنید",
-    "Share to {name}" : "به اشتراک گذاشتن برای {name}",
-    "Share link" : "اشتراک گذاشتن لینک",
-    "Could not unshare" : "اشتراک گذاری بازگردانده نشد",
-    "Shared with you and the group {group} by {owner}" : "به اشتراک گذاشته شده با شما و گروه {گروه} توسط {دارنده}",
-    "Shared with you and {circle} by {owner}" : "با شما و {حلقه} توسط {مالک }به اشتراک گذاشته شده است",
-    "Shared with you and the conversation {conversation} by {owner}" : "با شما و گفتگو {مکالمه} توسط {صاحب }به اشتراک گذاشته شده است",
-    "Shared with you in a conversation by {owner}" : "در گفتگو توسط {صاحب} با شما به اشتراک گذاشته شده است",
-    "Shared with you by {owner}" : "به اشتراک گذاشته شده با شما توسط { دارنده}",
-    "Choose a password for the mail share" : "یک رمز عبور برای اشتراک ایمیل انتخاب کنید",
-    "group" : "گروه",
-    "remote" : "از راه دور",
-    "remote group" : "گروه از راه دور",
-    "email" : "ایمیل",
-    "conversation" : "گفتگو",
-    "shared by {sharer}" : "اشتراک گذاشته شده توسط  {sharer}",
-    "Can reshare" : "می توان مجددا به اشتراک گذاشت",
-    "Can edit" : "می توان ویرایش کرد",
-    "Can create" : "میتوان ایجاد کرد",
-    "Can change" : "می توان تغییر داد",
-    "Can delete" : "می توان حذف کرد",
-    "Access control" : "کنترل دسترسی",
-    "Error while sharing" : "خطا درحال به اشتراک گذاشتن",
-    "Share details could not be loaded for this item." : "جزئیات اشتراک گذاری برای این مورد قابل بارگذاری نیست.",
-    "Search globally" : "در سطح جهان جستجو کنید",
-    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["برای تکمیل خودکار لازم است حداقل {count} کاراکتر وجود داشته باشد","برای تکمیل خودکار لازم است حداقل {count} کاراکتر وجود داشته باشد"],
-    "This list is maybe truncated - please refine your search term to see more results." : "این فهرست ممکن است کامل نباشد - لطفا نتایج جستجوی خود را ریفرش کنید تا نتایج بیشتری ببینید.",
-    "No users or groups found for {search}" : "هیچ کاربری یا گروهی یافت نشد {search}",
-    "No users found for {search}" : "هیچ کاربری با جستجوی {search} یافت نشد",
-    "An error occurred (\"{message}\"). Please try again" : "خطایی روی داد (\"{پیام}\"). لطفا دوباره تلاش کنید",
-    "An error occurred. Please try again" : "یک خطا رخ داده است، لطفا مجددا تلاش کنید",
-    "Home" : "خانه ",
-    "Work" : "کار",
-    "Other" : "دیگر",
-    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
-    "Share" : "اشتراک‌گذاری",
-    "Name or email address..." : "نام یا آدرس ایمیل ...",
-    "Name or federated cloud ID..." : "نام یا شناسه Federated Cloud ...",
-    "Name, federated cloud ID or email address..." : "نام, آدرس ایمیل یا شناسه Federated Cloud ...",
-    "Name..." : "نام...",
-    "Error removing share" : "خطا در حذف اشتراک گذاری",
     "({scope})" : "({scope})",
+    "Searching other places" : "جستجو در مکان‌های دیگر",
+    "No search results in other folders for {tag}{filter}{endtag}" : "جستجو در پوشه های دیگر برای {tag}{filter}{endtag} یافت نشد",
+    "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} نتایج جستجو در پوشه های دیگر","{count} نتایج جستجو در پوشه های دیگر"],
     "Saving..." : "در حال ذخیره سازی...",
-    "Cancel log in" : "لغو ورود",
+    "Search" : "جست‌و‌جو",
     "These apps will be updated:" : "این برنامه‌ها بروزرسانی شده‌اند:"
 },
 "nplurals=2; plural=(n > 1);");
