@@ -29,6 +29,8 @@ OC.L10N.register(
     "Nextcloud Server" : "שרת Nextcloud",
     "Some of your link shares have been removed" : "חלק מקישורי השיתופים שלך הוסרו",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "עקב תקלת אבטחה נאלצנו להסיר חלק מקישורי השיתופים שלך. נא להיכנס לקישור לקבלת פרטים נוספים.",
+    "The user limit of this instance is reached." : "מגבלת המשתמשים של מופע זה הושגה.",
+    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "הזן את מפתח המנוי שלך כדי להגדיל את מגבלת המשתמשים. למידע נוסף על Nextcloud Enterprise, עיין באתר שלנו.",
     "Preparing update" : "מכין עדכון",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "שלב בתיקון:",
@@ -60,6 +62,8 @@ OC.L10N.register(
     "Already up to date" : "כבר עדכני",
     "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "שרת האינטרנט לא מוגדר עדיין כראוי כדי לאפשר סנכרון קבצים, כיוון שמנשק ה־WebDAV כנראה אינו מתפקד.",
     "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "שרת האינטרנט שלך אינו מוגדר כראוי כדי לפתור את „{url}”. ניתן למצוא מידע נוסף ב<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">תיעוד</a>.",
+    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation page</a>. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "שרת האינטרנט שלך אינו מוגדר כראוי לפתור את ה-\"{url}\". קרוב לוודאי שזה קשור לתצורה של שרת אינטרנט שלא עודכנה כדי לספק תיקיה זו ישירות. אנא השווה את התצורה שלך עם כללי השכתוב שנשלחו ב- \"htaccess.\" עבור Apache או זה שמופיע בתיעוד עבור Nginx בדף התיעוד שלו. ב- Nginx, אלה בדרך כלל השורות המתחילות ב- \"location ~\" שצריכים עדכון.",
+    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "שרת האינטרנט שלך אינו מוגדר כראוי למסירת קבצי woff2.. זו בדרך כלל בעיה בתצורת ה-Nginx. עבור Nextcloud 15 הוא זקוק להתאמה כדי לספק גם קבצי woff2.. השווה את תצורת ה-Nginx שלך לתצורה המומלצת <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">בתיעוד</a> שלנו.",
     "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "מסתבר כי PHP לא מוגדר כראוי כדי לתשאל משתני סביבה. הבדיקה עם getenv(\"PATH\") מחזירה תשובה ריקה בלבד.",
     "Please check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">installation documentation ↗</a> for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "נא לעיין ב<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">תיעוד למתקינים ↖️</a> להערות בנוגע להגדרות PHP והגדרות ה־PHP לשרת שלך, במיוחד אם נעשה שימוש ב־php-fpm.",
     "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "הופעלה תצורה לקריאה בלבד. מצב זה מונע את הגדרת חלק מההגדרות דרך מנשק דפדפן. יתרה מכך, יש להפוך את הקובץ למורשה לכתיבה ידנית בכל עדכון מחדש.",
@@ -67,29 +71,48 @@ OC.L10N.register(
     "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "מודול ה־PHP בשם „fileinfo” חסר. מומלץ בחום להפעיל את המודול הזה כדי לקבל את התוצאות הטובות ביותר בזיהוי סוג MIME.",
     "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation ↗</a> for more information." : "נעילת קבצים מושבתת בזמן פעילות, מצב כזה יכול לגרום לתקלות במקרים של תחרות על משאב. יש להפעיל את „filelocking.enabled” ב־config.php כדי להתעלם מתקלות שכאלה. יש לעיין ב<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">תיעוד ↖️</a> לקבלת מידע נוסף.",
     "If your installation is not installed at the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (suggestion: \"{suggestedOverwriteCliURL}\")" : "אם המערכת שלך אינה מותקנת בשורש שם המתחם ומשתמשת ב־cron של המערכת, עשויות לצוץ תקלות עם יצירת כתובות. כדי להימנע מהתקלות האלו, נא להגדיר את האפשרות „overwrite.cli.url” בקובץ ה־config.php של נתיב שורש ההתקנה שלך (הצעה: „{suggestedOverwriteCliURL}”)",
+    "Your installation has no default phone region set. This is required to be able to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective ISO 3166-1 code of the wished region." : "לא הגדרת אזור הטלפון כברירת מחדל להתקנה שלך. זה נדרש כדי לאפשר לאמת מספרי טלפון בהגדרות הפרופיל ללא קוד מדינה. כדי לאפשר מספרים ללא קוד מדינה, הוסף \"default_phone_region\" עם קוד ISO 3166-1 המתאים לאזור הרצוי.",
     "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "לא ניתן היה להפעיל את משימות ה־cron דרך שורת פקודה. השגיאות הטכניות הבאות התרחשו:",
     "Last background job execution ran {relativeTime}. Something seems wrong." : "משימת הרקע האחרונה פעלה במשך {relativeTime}. כנראה שמדובר בתקלה כלשהי.",
     "Check the background job settings" : "בדיקת הגדרות משימות רקע",
     "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "לשרת זה אין חיבור לאינטרנט: מגוון נקודות קצה אינן נגישות. משמעות הדבר היא שחלק מהתכונות כגון עיגון אחסון חיצוני, הודעות על עדכונים או התקנות של יישומי צד שלישי לא יעבדו. גישה לקבצים מרחוק ושליחת הודעות בדוא״ל לא יעבדו גם כן. אנו ממליצים להפעיל את החיבור של השרת הזה לאינטרנט כדי שתהיה אפשרות ליהנות מכל התכונות.",
     "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "לא הוגדר מטמון זיכרון. כדי לשפר את הביצועים, נא להגדיר מטמון זיכרון (memcache), אם ניתן. ניתן למצוא מידע נוסף ב<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">תיעוד</a>.",
+    "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "אין מקור מתאים לאקראיות שנמצא על ידי PHP, שמאוד לא מומלץ מטעמי אבטחה. מידע נוסף ניתן למצוא <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">בתיעוד</a>.",
     "You are currently running PHP {version}. Upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it." : "גרסת ה־PHP שמותקנת אצלך היא {version}. נא לשדרג את גרסת ה־PHP שלך כדי לנצל את <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{phpLink}\">עדכוני הביצועים והאבטחה שמסופקים על ידי קבוצת PHP</a> ברגע שההפצה שלך משחררת אותן.",
+    "Nextcloud 20 is the last release supporting PHP 7.2. Nextcloud 21 requires at least PHP 7.3." : "Nextcloud 20 הוא המהדורה האחרונה התומכת ב- PHP 7.2. \nNextcloud 21 דורש לפחות PHP 7.3.",
     "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "תצורת הכותרת של המתווך ההפוך שגויה או שהגישה שלך אל Nextcloud מתבצעת ממתווך מהימן. אם לא כך המצב, מדובר בפרצת אבטחה שיכולה לאפשר לתוקף לזייף כתובת IP כפי שהיא מיוצגת מול ה־Nextcloud. ניתן למצוא מידע נוסף ב<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">תיעוד</a>.",
     "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached מוגדר כמטמון מופץ, אבל מודול ה־PHP השגוי המותקן הוא „memcache”.‏ ‎\\OC\\Memcache\\Memcached תומך רק ב־„memcached” ולא ב־ „memcache”. ניתן לצפות ב<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{wikiLink}\">וויקי של memcached לגבי שני המודולים</a>.",
     "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "חלק מהקבצים לא עברו את בדיקת השלמות. ניתן למצוא מידע נוסף על אופן הפתרון של תקלה זו ב<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">תיעוד</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">רשימת קבצים שגויים…</a> / <a href=\"{rescanEndpoint}\">סריקה מחדש…</a>)",
+    "The PHP OPcache module is not loaded. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">For better performance it is recommended</a> to load it into your PHP installation." : "מודול ה- PHP OPcache לא נטען. \nלקבלת ביצועים טובים יותר, מומלץ לטעון אותו להתקנת ה- PHP שלך.",
     "The PHP OPcache is not properly configured. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">For better performance it is recommended</a> to use the following settings in the <code>php.ini</code>:" : "ה־OPcache של PHP אינו מוגדר כראוי. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">לשיפור הביצועים אנו ממליצים</a> להשתמש בהגדרות הבאות בקובץ <code>php.ini</code>:",
     "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "פונקציית ה־PHP‏ „set_time_limit” אינה זמינה. מצב זה עשוי לגרום לעצירת סקריפטים באמצע הפעולה ולפגיעה בהתקנה שלך. אנו ממליצים בחום להפעיל את הפונקציה הזאת.",
     "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "ל־PHP שלך אין תמיכה ב־FreeType. מצב כזה יגרום לתמונות פרופיל משובשות לצד מנשק הגדרות משובש.",
     "Missing index \"{indexName}\" in table \"{tableName}\"." : "חסר אינדקס „{indexName}” בטבלה „{tableName}”.",
     "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "למסד הנתונים חסרים אינדקסים. כיוון שהוספת אינדקסים על טבלאות גדולות היא פעולה שגוזלת זמן רב הם לא נוספים אוטומטית. על ידי הרצת הפקודה „occ db:add-missing-indices” האינדקסים החסרים נוספים ידנית ללא עצירת פעולת העותק. לאחר הוספת האינדקסים השאילתות על הטבלאות האלה מהירות בהרבה.",
+    "Missing primary key on table \"{tableName}\"." : "חסר מפתח ראשי בטבלה \"{tableName}\".",
+    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "במסד הנתונים חסרים כמה מפתחות ראשיים. בשל העובדה שהוספת מפתחות ראשיים לטבלאות גדולות עשויה להימשך זמן מה, הם לא נוספו אוטומטית. על ידי הפעלת \"occ db: add-missing-primary-keys\", ניתן להוסיף מפתחות הראשיים החסרים האלה באופן ידני, בזמן שהמופע ממשיך לפעול.",
+    "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "חסרה עמודה האופציונלית \"{columnName}\" בטבלה \"{tableName}\".",
+    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "במסד הנתונים חסרים כמה עמודות אופציונליות. בשל העובדה שהוספת עמודות בטבלאות גדולות עשויה להימשך זמן מה, הן לא נוספו אוטומטית כאשר הן יכולות להיות אופציונליות. על ידי הפעלת \"occ db: add-missing-column\", ניתן להוסיף את העמודות החסרות האלה באופן ידני בזמן שהמופע ממשיך לפעול. לאחר הוספת העמודות, חלק מהתכונות עשויות לשפר את ההיענות או את השימושיות.",
+    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "במופע זה חסרים כמה מודולי PHP מומלצים. לשיפור ביצועים ותאימות טובה יותר, מומלץ להתקין אותם.",
+    "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "למודול php-imagick במקרה הזה אין תמיכה ב- SVG. לקבלת תאימות טובה יותר, מומלץ להתקין אותו.",
+    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running 'occ db:convert-filecache-bigint' those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">the documentation page about this</a>." : "בחלק מהעמודות במסד הנתונים חסרה המרה ל- big int. בשל העובדה ששינוי סוגי העמודות בטבלאות גדולות עלול לארוך זמן מה, לא שינו אותן באופן אוטומטי. על ידי הפעלת 'occ db: convert-filecache-bigint', ניתן היה להחיל את השינויים הממתינים באופן ידני. יש לבצע פעולה זו בזמן שהמופע לא מקוון. לפרטים נוספים, קראו את<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\"> עמוד התיעוד בנושא זה</a>.",
     "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "SQLite הוא מנגנון מסד הנתונים נכון לעכשיו. במערכות גדולות מוטב להחליף למנגנון מסד נתונים אחר.",
     "This is particularly recommended when using the desktop client for file synchronisation." : "מצב זה מומלץ במיוחד כאשר מריצים את לקוח שולחן העבודה לסנכרון קבצים.",
     "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation ↗</a>." : "כדי להגר למסד נתונים אחר יש להשתמש בכלי שורת הפקודה: ‚occ db:convert-type’, או לעיין ב<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">תיעוד ↖️</a>.",
     "The PHP memory limit is below the recommended value of 512MB." : "מגבלת הזיכרון של ה־PHP היא מתחת לערך המומלץ על סך 512 מ״ב.",
+    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "ספריות אפליקציות מסוימות הן בבעלות משתמש אחר מזה של שרת האינטרנט. זה יכול להיות במקרה שאפליקציות הותקנו באופן ידני. בדוק את ההרשאות של ספריות האפליקציות הבאות:",
+    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL. For further details read <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">the documentation page about this</a>." : "MySQL משמש כמסד נתונים, אך אינו תומך בתווים של 4 בתים. כדי להיות מסוגל לטפל בתווים של 4 בתים (כמו אימוג'יים) ללא בעיות בשמות קבצים או הערות למשל, מומלץ לאפשר את תמיכה ב-4 בתים ב- MySQL. לפרטים נוספים, קראו את <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">עמוד התיעוד בנושא זה</a>.",
+    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "מופע זה משתמש באיחסון אובייקטים מבוססת S3 כאחסון ראשי. הקבצים שהועלו מאוחסנים באופן זמני בשרת, ולכן מומלץ שיהיה שטח פנוי של 50 GB בספריית ה- temp של PHP. בדוק ביומנים לקבלת יותר פרטים על הנתיב והשטח הזמין. כדי לשפר זאת, אנא שנה את הספריה הזמנית ב- php.ini, או תפנה יותר מקום בנתיב זה.",
+    "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">the documentation page about this</a>." : "אתה ניגש למופע שלך באמצעות חיבור מאובטח, אולם המופע שלך מייצר כתובות אתרים לא מאובטחות. ככל הנראה פירוש הדבר שאתה עומד מאחורי שרת reverse proxy, ומשתני ה-overwrite config אינם מוגדרים בצורה נכונה. אנא קרא<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\"> את דף התיעוד בנושא זה</a>.",
     "Error occurred while checking server setup" : "שגיאה אירעה בזמן בדיקת התקנת השרת",
+    "For more details see the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "לפרטים נוספים, עיין<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\"> בתיעוד</a>.",
     "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "תיקיית הנתונים והקבצים שלך כנראה נגישים דרך האינטרנט. קובץ ה־‎.htaccess אינו עובד. מומלץ בחום להגדיר את השרת שלך כך שתיקיית הנתונים אינה נגישה עוד או לחלופין להעביר את תיקיית הנתונים אל מחוץ לתיקיית השורש של שירות אירוח האתרים.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "כותרת ה־HTTP‏ „{header}” אינה מוגדרת לערך „{expected}”. מדובר בפרצת אבטחה או פרטיות, מומלץ להתאים את ההגדרה הזאת בהתאם.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "כותרת ה־HTTP‏ „{header}” אינה מוגדרת לערך „{expected}”. יתכן שחלק מהתכונות לא תעבודנה כראוי, מומלץ להתאים את ההגדרה הזאת בהתאם.",
+    "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "כותרת ה-HTTP, הנקרא \"{header}\", אינה מכילה \"{expected}\". זהו סיכון אפשרי של אבטחה או פרטיות, שכן מומלץ להתאים הגדרה זו בהתאם.",
+    "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{link}\">W3C Recommendation ↗</a>." : "כותרת ה-HTTP הנקרא \"{header}\", אינה מוגדרת כ-\n\"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" או \"{val5}\".\nזה יכול לדלוף מידע על הפניות. ראה המלצת W3C ↗.",
     "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the <a href=\"{docUrl}\" rel=\"noreferrer noopener\">security tips ↗</a>." : "כותרת ה־HTTP בשם „Strict-Transport-Security” אינה מוגדרת עד לפחות „{seconds}” שניות. לטובת אבטחה מוגברת אנו ממליצים להפעיל HSTS כפי שמתואר ב<a href=\"{docUrl}\" rel=\"noreferrer noopener\">עצות האבטחה ↖️</a> שלנו.",
+    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the <a href=\"{docUrl}\">security tips ↗</a>." : "גישה לאתר בצורה לא מאובטחת באמצעות HTTP. מומלץ מאוד להגדיר את השרת שלך לחייב HTTPS במקום HTTP, כמתואר בעצות אבטחה ↗.",
     "unknown text" : "מלל לא מוכר",
     "Hello world!" : "שלום עולם!",
     "sunny" : "שמשי",
@@ -102,7 +125,7 @@ OC.L10N.register(
     "Update to {version}" : "עדכון ל־{version}",
     "An error occurred." : "אירעה שגיאה.",
     "Please reload the page." : "יש להעלות מחדש דף זה.",
-    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "העדכון בוצע בהצלחה. למידע נוסף <a href=\"{url}\">ניתן לבדוק בהודעת הפורום שלנו</a> המכסה נושא זו.",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "העדכון לא בוצע בהצלחה. למידע נוסף <a href=\"{url}\">ניתן לבדוק בהודעת הפורום שלנו</a> המכסה נושא זו.",
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "העדכון לא הצליח. נא לדווח על התקלה הזאת ל<a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">קהילת Nextcloud</a>.",
     "Continue to Nextcloud" : "להמשיך ל־Nextcloud",
     "_The update was successful. Redirecting you to Nextcloud in %n second._::_The update was successful. Redirecting you to Nextcloud in %n seconds._" : ["העדכון הצליח. תתבצע העברה ל־Nextcloud בעוד שנייה.","העדכון הצליח. תתבצע העברה ל־Nextcloud בעוד %n שניות.","העדכון הצליח. תתבצע העברה ל־Nextcloud בעוד %n שניות.","העדכון הצליח. תתבצע העברה ל־Nextcloud בעוד %n שניות."],
@@ -119,11 +142,15 @@ OC.L10N.register(
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "זיהינו מספר ניסיונות כניסה שגויים מכתובת ה־IP שלך. לכן, ניסיון הכניסה הבא יתאפשר עבורך רק בעוד 30 שניות.",
     "Your account is not setup for passwordless login." : "החשבון שלך לא מוגדר לכניסה בלי ססמה.",
     "Passwordless authentication is not supported in your browser." : "אימות ללא ססמה אינו נתמך על ידי הדפדפן שלך.",
+    "Passwordless authentication is only available over a secure connection." : "אימות ללא סיסמה הוא זמין רק דרך חיבור מאובטח.",
     "Reset password" : "איפוס ססמה",
+    "A password reset message has been sent to the e-mail address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "הודעת איפוס סיסמה נשלחה לכתובת הדואר האלקטרוני של חשבון זה. אם אינך מקבל אותו, בדוק את תיקיות דואר הספאם/זבל שלך, או בקש עזרה ממנהל המקומי שלך.",
+    "If it is not there ask your local administrator." : "אם זה לא נמצא, שאל את המנהל המקומי שלך.",
     "Couldn't send reset email. Please contact your administrator." : "לא ניתן היה לשלוח דואר אלקטרוני לאיפוס. יש לפנות למנהל שלך.",
     "Password can not be changed. Please contact your administrator." : "לא ניתן לשנות את הססמה. יש לפנות למנהל שלך.",
     "Back to login" : "חזרה לכניסה",
     "New password" : "ססמה חדשה",
+    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "הקבצים שלך מוצפנים. לא תהיה שום דרך להחזיר את הנתונים לאחר איפוס הסיסמה. אם אינך בטוח מה לעשות, פנה למנהל המערכת לפני שתמשיך. האם אתה באמת רוצה להמשיך?",
     "I know what I'm doing" : "אני יודע/ת מה אני עושה",
     "Resetting password" : "איפוס ססמה",
     "Recommended apps" : "יישומונים מומלצים",
@@ -137,16 +164,21 @@ OC.L10N.register(
     "Schedule work & meetings, synced with all your devices." : "תזמון עבודה ופגישות בסנכרון עם כל המכשירים שלך.",
     "Keep your colleagues and friends in one place without leaking their private info." : "עמיתים לעבודה וחברים מרוכזים במקום אחד מבלי זליגה של הפרטים האישיים שלהם.",
     "Simple email app nicely integrated with Files, Contacts and Calendar." : "יישומון דוא״ל פשוט שמשתלב בצורה נחמדה עם הקבצים, אנשי הקשר והיומן.",
+    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "צ'אטים, שיחות וידאו, שיתוף מסך, פגישות מקוונות ועידת אינטרנט - בדפדפן ובאפליקציות סלולריות.",
     "Collaboratively edit office documents." : "עריכה שיתופית של מסמכי Office.",
+    "Local document editing back-end used by the Collabora Online app." : "עריכת מסמך מקומי באופן back-end המשמשת את אפליקציית Collabora Online.",
     "Forgot password?" : "שכחת ססמה?",
     "Log in with a device" : "כניסה עם מכשיר",
     "Back" : "חזרה",
     "Reset search" : "איפוס החיפוש",
+    "Search for {name} only" : "חפש ל-{name} בלבד",
     "No results for {query}" : "אין תוצאות עבור {query}",
     "Start typing to search" : "להתחלת החיפוש יש להקליד",
     "Loading more results …" : "נטענות תוצאות נוספות…",
     "Load more results" : "לטעון עוד תוצאות",
+    "An error occurred while searching for {type}" : "אירעה שגיאה בחיפוש אחר {type}",
     "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["נא להקליד לפחות תו אחד כדי לחפש","נא להקליד לפחות {minSearchLength} תווים כדי לחפש","נא להקליד לפחות {minSearchLength} תווים כדי לחפש","נא להקליד לפחות {minSearchLength} תווים כדי לחפש"],
+    "Search {types} …" : "חפש {types} ...",
     "Settings" : "הגדרות",
     "Could not load your contacts" : "לא ניתן לטעון את אנשי הקשר שלך",
     "Search contacts …" : "חיפוש אנשי קשר…",
@@ -230,7 +262,10 @@ OC.L10N.register(
     "File not found" : "קובץ לא נמצא",
     "The document could not be found on the server. Maybe the share was deleted or has expired?" : "לא ניתן למצוא את המסמך בשרת. יכול להיות שהשיתוף נמחק או פג?",
     "Back to %s" : "חזרה אל %s",
+    "Too many requests" : "יותר מדי בקשות",
+    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "היו יותר מדי בקשות מהרשת שלך. נסה שוב מאוחר יותר, או צור קשר עם מנהל המערכת שלך אם זו שגיאה.",
     "Error" : "שגיאה",
+    "Previous" : "הקודם",
     "Internal Server Error" : "שגיאה פנימית בשרת",
     "The server was unable to complete your request." : "השרת לא הצליח להשלים את הבקשה שלך.",
     "If this happens again, please send the technical details below to the server administrator." : "אם דבר כזה קורה שוב, נא לשלוח את הפרטים הטכניים שלהלן למנהל השרת.",
@@ -267,10 +302,12 @@ OC.L10N.register(
     "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "יש להשתמש ב־SQLite לסביבות מזעריות או למטרות פיתוח. בסביבת פעילות שגרתית אנו ממליצים על מנגנון מסד נתונים אחר.",
     "If you use clients for file syncing, the use of SQLite is highly discouraged." : "אם יש לך לקוח שמשמש אותך לסנכרון קבצים, השימוש ב־SQLite לא מומלץ עבורך.",
     "Install recommended apps" : "התקנת יישומונים מומלצים",
+    "Calendar, Contacts, Talk, Mail & Collaborative editing" : "לוח שנה, אנשי קשר, שיחה, דואר, ועריכה משותפת",
     "Finish setup" : "סיום התקנה",
     "Finishing …" : "מסיים...",
     "Need help?" : "עזרה נזקקת?",
     "See the documentation" : "יש לצפות במסמכי התיעוד",
+    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "נראה שאתה מנסה להתקין מחדש את ה-Nextcloud שלך.אבל הקובץ CAN_INSTALL חסר בספריית ה-config שלך. אנא צור את הקובץ CAN_INSTALL בתיקיית ה-config שלך כדי להמשיך.",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "לא ניתן להסיר את CAN_INSTALL מתיקיית ההגדרות. נא להסיר את הקובץ הזה ידנית.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "יישום זה דורש JavaScript לפעולה נכונה. יש {linkstart}לאפשר JavaScript{linkend} ולטעון את העמוד מחדש.",
     "Get your own free account" : "קבלת חשבון משלך בחינם",
@@ -285,6 +322,7 @@ OC.L10N.register(
     "Confirm your password" : "אימות הססמה שלך",
     "Connect to your account" : "התחברות לחשבון שלך",
     "Please log in before granting %1$s access to your %2$s account." : "נא להיכנס בטרם הענקת גישה לחשבון שלך ב־%2$s לטובת %1$s.",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "אם אינך מנסה להגדיר מכשיר חדש או אפליקציה חדשה, מישהו מנסה לרמות אותך להעניק לו גישה לנתונים שלך. במקרה הזה, אל תמשיך, ובמקום זאת פנה למנהל המערכת שלך.",
     "App token" : "אסימון יישום",
     "Grant access" : "הענקת גישה",
     "Alternative log in using app token" : "כניסה חלופית באמצעות אסימון יישומון",
@@ -299,6 +337,7 @@ OC.L10N.register(
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "על החשבון שלך מופעלת אבטחה מוגברת. נא לבחור גורם אימות נוסף:",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "לא ניתן לטעון לפחות את אחד משיטות האימות הדו־שלבי שהפעלת. נא ליצור קשר עם מנהל המערכת.",
     "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "אימות דו־שלבי נאכף אך הוא אינו מוגדר על החשבון שלך. נא ליצור קשר עם המנהל שלך לקבלת עזרה.",
+    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "אימות דו-גורמי נאכף, אך לא הוגדר בחשבון שלך. אנא תמשיך להגדיר אימות דו-גורמי.",
     "Set up two-factor authentication" : "הגדרת אימות דו־שלבי",
     "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "אימות דו־שלבי נאכף אך הוא אינו מוגדר על החשבון שלך. נא להשתמש באחד מהקודים לצורכי גיבוי כדי להיכנס או ליצור קשר עם המנהל שלך לקבלת עזרה.",
     "Use backup code" : "שימוש בקוד גיבוי",
