@@ -29,6 +29,8 @@ OC.L10N.register(
     "Nextcloud Server" : "Strežnik Nextcloud",
     "Some of your link shares have been removed" : "Nekatere povezave za souporabo so bile odstranjene.",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Zaradi varnostnih razlogov so bile nekatere povezave odstranjene. Več podrobnosti je na voljo v uradno izdanem opozorilu.",
+    "The user limit of this instance is reached." : "Dosežena je količinska omejitev za uporabnika.",
+    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "Vpišite ključ naročnine in povečajte omejitev za uporabnika. Za več podrobnosti si oglejte Poslovni paket Nextcloud na spletni strani.",
     "Preparing update" : "Poteka pripravljanje posodobitve",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "Korak popravila:",
@@ -69,6 +71,7 @@ OC.L10N.register(
     "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "Manjka modul PHP »fileinfo«. Priporočljivo je omogočiti ta modul za popolno zaznavanje vrst MIME.",
     "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation ↗</a> for more information." : "Zaklepanje datotek je onemogočeno, kar lahko privede do različnih težav. Priporočljivo je omogočiti možnost \"filelocking.enabled\" v datoteki config.php, da se izognete zapletom. Za več informacij si glejte <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentacijo ↗</a>.",
     "If your installation is not installed at the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (suggestion: \"{suggestedOverwriteCliURL}\")" : "Če namestitev ni nameščena v korenski mapi domene, a uporablja sistemska opravila cron, se lahko pojavijo težave z ustvarjanjem naslovov URL. Težavam se je mogoče izogniti z nastavitvijo možnosti »overwrite.cli.url« v datoteki confih.php za pot do spletnega korena (predlog: »{suggestedOverwriteCliURL}«).",
+    "Your installation has no default phone region set. This is required to be able to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective ISO 3166-1 code of the wished region." : "Namestitev med nastavitvami nima določenega privzetega telefonskega področja. To je pomembno za overjanje telefonskih številk brez uporabe kode države. Za vpis brez kode je treba dodatki možnost »default_phone_region« z ustrezno kodo regije po določilih ISO 3166-1.",
     "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Ni mogoče izvesti opravila cron prek vmesnika ukazne vrstice. Pojavile so se tehnične napake:",
     "Last background job execution ran {relativeTime}. Something seems wrong." : " Zadnje ozadnje izvajanje opravila je potekalo {relativeTime}. Kaže, da je nekaj narobe.",
     "Check the background job settings" : "Preverite nastavitve ozadnjih opravil",
@@ -79,19 +82,29 @@ OC.L10N.register(
     "Nextcloud 20 is the last release supporting PHP 7.2. Nextcloud 21 requires at least PHP 7.3." : "Okolje Nextcloud 20 je zadnja različica, ki omogoča podporo PHP 7.2. Nextcloud 21 zahteva vsaj različico PHP 7.3.",
     "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Predpomnilnik memcached je nastavljen kot porazdeljen predpomnilnik, vendar pa je nameščen napačen modul PHP »memcache«. Modul \\OC\\Memcache\\Memcached podpirao le »memcached«, ne pa tudi »memcache«. Več podrobnosti za oba modula je zapisanih <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{wikiLink}\">na wiki straneh</a>.",
     "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Nekatere datoteke ne opravijo preizkusa celovitosti. Več podrobnosti o težavi je opisanih v <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentaciji</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">Seznam neveljavnih datotek … </a>/ <a href=\"{rescanEndpoint}\">Ponovni preizkus …</a>)",
+    "The PHP OPcache module is not loaded. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">For better performance it is recommended</a> to load it into your PHP installation." : "Modul PHP OPcache ni naložen. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Za najboljše delovanje je priporočljivo</a> modul dodati k uporabljeni namestitvi PHP.",
+    "The PHP OPcache is not properly configured. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">For better performance it is recommended</a> to use the following settings in the <code>php.ini</code>:" : "Modul PHP OPcache ni pravilno nastavljen. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Za najboljše delovanje je priporočljivo</a> uporabiti posebne nastavitve v datoteki <code>php.ini</code>:",
+    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "Funkcija PHP »set_time_limit« ni na voljo. To lahko povzroči nepričakovano zaustavitev skriptnih ukazov med izvajanjem, kar lahko povzroči sesutje namestitve. To možnost je priporočeno omogočiti.",
     "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Namestitev PHP je brez ustrezne podpore za FreeType, kar pogosto vpliva na težave s slikami profila in nastavitvami vmesnika.",
     "Missing index \"{indexName}\" in table \"{tableName}\"." : "Manjka kazalo » {indexName} « v razpredelnici »{tableName}«.",
+    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "V podatkovni zbirki ni določenih nekaterih določil. Ker je dodajanje določil na velikih razpredelnicah časovno izredno zahtevno opravilo, ta niso dodana samodejno. Z ukazom »occ db: add-missing-indeks« je določila mogoče varno dodati ročno, medtem ko je sistem v delovanju. Po dodajanju bo izvajanje poizvedb teh razpredelnic neprimerno hitrejše.",
     "Missing primary key on table \"{tableName}\"." : "Manjka osnovni ključ v razpredelnici »{tableName}«.",
+    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "V podatkovni zbirki ni določenih nekaterih osnovnih ključev. Ker je dodajanje ključev na velikih razpredelnicah časovno izredno zahtevno opravilo, ti niso dodani samodejno. Z ukazom »occ db: add-missing-primary-keys« je ključe mogoče varno dodati ročno, medtem ko je sistem v delovanju.",
     "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "Manjka izbirni stolpec »{columnName}« v razpredelnici »{tableName}«.",
+    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "V podatkovni zbirki manjka nekaj izbirnih stolpcev. Ker je dodajanje stolpcev na velikih razpredelnicah časovno izredno zahtevno opravilo, ta niso dodana samodejno, ker so v osnovi izbirna. Z ukazom »occ db:add-missing-columns« je stolpce mogoče varno dodati ročno med delovanjem sistema. Po dodajanju bo odzivnost in uporabnost nekaterih zmožnosti občutna izboljšana.",
     "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "Namestitev PHP ne vključuje nekaterih priporočenih modulov. Za izboljšanje delovanja in boljšo skladnost jih je zelo priporočljivo omogočiti.",
     "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "Modul php-imagick ne vključuje podpore za SVG. Za izboljšanje delovanja in boljšo skladnost jih je zelo priporočljivo omogočiti.",
+    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running 'occ db:convert-filecache-bigint' those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">the documentation page about this</a>." : "Nekateri stolpci v podatkovni zbirki so brez pretvornika velikih števil. Ker je spreminjanje stolpcev na velikih razpredelnicah časovno izredno zahtevno opravilo, ta niso dodana samodejno. V osnovi so izbirna. Z ukazom »occ db:convert-filecache-bigint« je mogoče te spremembe dodati ročno. Opravilo je treba izvesti, ko okolje ni dejavno. Za več podrobnosti si oglejte <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentacijo</a>.",
     "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "Trenutno je uporabljena ozadnja podatkovna zbirka SQLite. Za obsežnejše sisteme je priporočljiv prehod na drugo vrsto zbirke.",
     "This is particularly recommended when using the desktop client for file synchronisation." : "Priporočilo ima še večjo težo, če se sistem krajevno usklajuje z namizjem prek odjemalca.",
     "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation ↗</a>." : "Za prehod sistema na drugo podatkovno zbirko, uporabite ukaz orodne vrstice: »occ db:convert-type«, več o tem pa je zapisano v <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentaciji ↗</a>.",
     "The PHP memory limit is below the recommended value of 512MB." : "Omejitev pomnilnika PHP je pod priporočljivo vrednostjo 512 MB.",
+    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "Nekatere mape programov imajo lastništvo določeno na uporabnika ni ni spletni strežniški uporabnik. To se lahko zgodi, če so programi nameščeni ročno. Preveriti je treba dovoljenja map:",
     "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL. For further details read <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">the documentation page about this</a>." : "Podatkovna zbirka MySQL je v uporabi, ni pa omogočena podpora za 4-bitne znake. Za uporabo teh znakov (kot so na primer grafične izrazne ikone) brez težav tudi v imenih datotek in opombah, je priporočljivo podporo omogočiti med nastavitvami MySQL. Več podrobnosti je zabeleženih na straneh <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentacije</a>.",
+    "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">the documentation page about this</a>." : "Dostop do okolja poteka prek varne povezave, a ta ustvarja ne-varne naslove URL. To najverjetneje pomeni, da je strežnik za povratnim strežnikom in da spremenljivke nastavitev niso pravilno nastavljene. Več o tem si lahko ogledate v <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentaciji</a>.",
     "Error occurred while checking server setup" : "Prišlo je do napake med preverjanjem nastavitev strežnika",
     "For more details see the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "Za več podrobnosti si oglejte <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentacijo</a>.",
+    "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Podatkovna mapa in datoteke so najverjetneje dostopni prek Interneta, ker datoteka .htaccess ni ustrezno nastavljena. Priporočljivo je nastaviti spletni strežnik tako, da dostop do mape prek zunanjega omrežja ni mogoč, ali pa tako, da podatkovno mapo prestavite izven korenske mape strežnika.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "Glava HTTP »{header}« ni nastavljena na pričakovano vrednost »{expected}«. To predstavlja potencialno varnostno ali zasebnostno tveganje, zato je priporočljivo prilagoditi nastavitve.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "Glava HTTP »{header}« ni nastavljena na pričakovano vrednost »{expected}«. Nekatere možnosti morda ne bodo delovale pravilno, zato je priporočljivo prilagoditi nastavitve.",
     "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "Glava \"{header}\" HTTP ne vsebuje »{expected}«. To je potencialno varnostna luknja, zato priporočamo prilagoditev nastavitev.",
@@ -291,6 +304,7 @@ OC.L10N.register(
     "Finishing …" : "Poteka zaključevanje opravila ...",
     "Need help?" : "Ali potrebujete pomoč?",
     "See the documentation" : "Preverite dokumentacijo",
+    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Kaže, da poskušate ponovno namestiti okolje Nextcloud, a datoteke CAN_INSTALL ni v mapi nastavitev. Ustvarite jo, potem lahko poskusite znova.",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Ni mogoče odstraniti datoteke CAN_INSTALL iz nastavitvene mape. Odstranite jo ročno.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Program zahteva podporo JavaScript za pravilno delovanje. Med nastavitvami omogočite {linkstart}JavaScript{linkend} in osvežite spletno stran.",
     "Get your own free account" : "Pridobite brezplačni račun",
@@ -305,6 +319,7 @@ OC.L10N.register(
     "Confirm your password" : "Potrdite geslo",
     "Connect to your account" : "Povežite z računom",
     "Please log in before granting %1$s access to your %2$s account." : "Pred %1$s odobritvijo dostopa %2$s do računa se je treba prijaviti.",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Če ne poskušate dodati naprave ali programa, vas poskuša nekdo pretentati v odobritev dostopa do vaših podatkov. Če se vam zdi, da je tako, ne nadaljujte s potrjevanjem, ampak stopite v stik s skrbnikom sistema.",
     "App token" : "Žeton programa",
     "Grant access" : "Odobri dostop",
     "Alternative log in using app token" : "Alternativni način prijave z uporabo programskega žetona",
