@@ -48,7 +48,7 @@ OC.L10N.register(
     "Checking for update of app \"%s\" in appstore" : "Проверавам ажурирања апликације „%s“ у продавници",
     "Update app \"%s\" from appstore" : "Ажурирај апликацију „%s“ из продавнице",
     "Checked for update of app \"%s\" in appstore" : "Проверено ажурирање апликације „%s“ у продавници",
-    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Провера да ли шема база за %s може бити ажурирана (ово може да потраје, у зависности колика је база)",
+    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Провера да ли шема базе података за %s може бити ажурирана (ово може да потраје, у зависности од величине базе)",
     "Checked database schema update for apps" : "Проверено ажурирање шеме базе података за апликације",
     "Updated \"%1$s\" to %2$s" : "„%1$s“ ажурирано на %2$s",
     "Set log level to debug" : "Постави ниво уписа у дневник на дебаговање",
@@ -76,6 +76,7 @@ OC.L10N.register(
     "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "Нисте подесили меморијски кеш. Да побољшате перформансе, подесите меморијски кеш, ако је доступан. Више информација има у <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">документацији</a>.",
     "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "PHP не може да чита погодан извор случајних бројева што се не препоручује из сигурносних разлога. Можете наћи више информација у <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">документацији</a>.",
     "You are currently running PHP {version}. Upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it." : "Тренутно користите {version} верзију PHP-а. Надоградите PHP верзију да искористите сва <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{phpLink}\">безбедоносна ажурирања и побољшања брзине које обезбеђује PHP група</a>, чим Ваша дистрибуција почне да је подржава.",
+    "Nextcloud 20 is the last release supporting PHP 7.2. Nextcloud 21 requires at least PHP 7.3." : "Некстклауд 20 је последње издање са подршком за PHP 7.2. Некстклауд 21 захтева бар PHP 7.3",
     "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "Или подешавање обрнутих прокси заглавља није исправно, или приступате Некстклауду преко проксија од поверења. Ако то не радите, ово је безбедоносни проблем и може омогућити нападачу да лажира да је његова IP адреса видљива Некстклауду. Више информација о овоме има у <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">документацији</a>.",
     "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached је подешен као дистрибуирани кеш, али је инсталиран погрешни PHP модуле „memcache“. \\OC\\Memcache\\Memcached подржава само \"memcached\" модул, а не и \"memcache\".  Погледајте <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{wikiLink}\">memcached вики о оба модула</a>.",
     "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Неки фајлови нису прошли проверу интегритета. Даљње информације о томе како да решите овај проблем се могу наћи у <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">документацији</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">Списак неисправних фајлова</a>/<a href=\"{rescanEndpoint}\">Скенирај поново…</a>)",
@@ -92,7 +93,6 @@ OC.L10N.register(
     "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "Тренутно се као база података користи SQLite. За веће инсталације, препоручујемо да промените базу података.",
     "This is particularly recommended when using the desktop client for file synchronisation." : "Ово се нарочито порепоручује ако се користи клијент програм у графичком окружењу за синхронизацију.",
     "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation ↗</a>." : "За пресељење на другу базу података, користите алат командне линије:  'occ db:convert-type', или погледајте <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">документацију ↗</a>.",
-    "Use of the the built in php mailer is no longer supported. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Please update your email server settings ↗<a/>." : "Коришћење уграђеног php mailer-а више није подржано. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Молимо ажурирајте и-мејл сервер поставке ↗<a/>.",
     "The PHP memory limit is below the recommended value of 512MB." : "Меморијско ограничење за ПХП је испод препоручене вредности од 512MB.",
     "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "Власник неких апликативних директоријума је корисник који није исти као и корисник по којим ради веб сервер. Ово је могуће ако су се апликације инсталирале ручно. Проверите привилегије над следећим апликативним директоријумима:",
     "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL. For further details read <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">the documentation page about this</a>." : "MySQL се користи као база података, али она не подржава карактере од 4 бајта. Да бисте могли да користите ове 4-бајтне карактере (као што су емоџији) без проблема у нпр. именима фајлова или коментарима, препоручује се да омогућите подршку за 4 бајта у MySQL-у. За више детаља, прочитајте <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">страну на документацији о овоме</a>.",
@@ -164,10 +164,13 @@ OC.L10N.register(
     "Forgot password?" : "Заборавили сте лозинку?",
     "Log in with a device" : "Пријава са уређајем",
     "Back" : "Назад",
+    "Reset search" : "Ресетуј претрагу",
+    "Search for {name} only" : "Тражи само за {name}",
     "No results for {query}" : "Нема резултата за упит {query}",
     "Start typing to search" : "Почните да куцате да бисте претраживали",
     "Loading more results …" : "Учитавам још резултата…",
     "Load more results" : "Учитај још резултата",
+    "An error occurred while searching for {type}" : "Десила се грешка приликом тражења за {type}",
     "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Унесите {minSearchLength} или више карактера да бисте претраживали","Унесите {minSearchLength} или више карактера да бисте претраживали","Унесите {minSearchLength} или више карактера да бисте претраживали"],
     "Search {types} …" : "Претражи {types}…",
     "Settings" : "Поставке",
@@ -339,7 +342,7 @@ OC.L10N.register(
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Контактирајте Вашег администратора. Ако сте Ви администратор, измените \"trusted_domains\" подешавање у config/config.php као у примеру config.sample.php.",
     "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Више информација о томе како ово подесити можете да нађете у %1$s документацији%2$s.",
     "App update required" : "Потребно ажурирање апликације",
-    "%1$s will be updated to version %2$s" : "%1$s ће бити ажурирана на верзију %2$s",
+    "%1$s will be updated to version %2$s" : "%1$s ће бити ажуриран на верзију %2$s",
     "The following apps will be updated:" : "Следеће апликације ће бити ажуриране:",
     "These incompatible apps will be disabled:" : "Следеће некомпатибилне апликације ће бити онемогућене:",
     "The theme %s has been disabled." : "Тема %s је онемогућена.",
@@ -358,95 +361,16 @@ OC.L10N.register(
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Контактирајте администратора ако се порука понавља или се неочекивано појавила.",
     "Following apps have been disabled: %s" : "Следеће апликације су искључене: %s",
     "You are currently running PHP 5.6. The current major version of Nextcloud is the last that is supported on PHP 5.6. It is recommended to upgrade the PHP version to 7.0+ to be able to upgrade to Nextcloud 14." : "Тренутно користите PHP верзију 5.6. Тренутна главна верзија Некстклауда је последња која подржава PHP 5.6. Препорука је да пређете на PHP верзију 7.0+ да бисте могли да ажурирате Некстклауд на верзију 14.",
-    "Shared" : "Дељено",
-    "Shared with" : "Дељено са",
-    "Shared by" : "Поделио",
-    "Choose a password for the public link" : "Унесите лозинку за јавну везу",
-    "Choose a password for the public link or press the \"Enter\" key" : "Унесите лозинку за јавну везу или притисните \"Ентер\"",
-    "Copied!" : "Копирано!",
-    "Copy link" : "Копирај везу",
-    "Not supported!" : "Није подржано!",
-    "Press ⌘-C to copy." : "Притисните ⌘-C за копирање.",
-    "Press Ctrl-C to copy." : "Притисните Ctrl-C за копирање.",
-    "Unable to create a link share" : "Не могу да направим везу дељења",
-    "Unable to toggle this option" : "Не могу да укључим/искључим ову опцију",
-    "Resharing is not allowed" : "Поновно дељење није дозвољено",
-    "Link" : "Веза",
-    "Hide download" : "Сакриј скидање",
-    "Password protection enforced" : "Захтевана заштита лозинком",
-    "Password protect" : "Заштићено лозинком",
-    "Allow editing" : "Дозволи уређивање",
-    "Email link to person" : "Пошаљи е-поштом",
-    "Send" : "Пошаљи",
-    "Allow upload and editing" : "Дозволи отпремање и уређивање",
-    "Read only" : "Само за читање",
-    "File drop (upload only)" : "Превлачење фајлова (само за отпремање)",
-    "Expiration date enforced" : "Захтевано постављање датума истека",
-    "Set expiration date" : "Постави датум истека",
-    "Expiration" : "Истиче",
-    "Expiration date" : "Датум истека",
-    "Note to recipient" : "Белешка примаоцу",
-    "Unshare" : "Укини дељење",
-    "Delete share link" : "Обриши везу дељења",
-    "Add another link" : "Додај још једну везу",
-    "Password protection for links is mandatory" : "За везе је обавезна заштита лозинком",
-    "Share to {name}" : "Подели са {name}",
-    "Share link" : "Веза дељења",
-    "New share link" : "Нова веза дељења",
-    "Created on {time}" : "Направљено {time}",
-    "Password protect by Talk" : "Заштити лозинком преко Talk-а",
-    "Could not unshare" : "Не могу да укинем дељење",
-    "Shared with you and the group {group} by {owner}" : "{owner} дели са вама и са групом {group}.",
-    "Shared with you and {circle} by {owner}" : "Дељено са Вама и кругом {circle} од стране корисника {owner}",
-    "Shared with you and the conversation {conversation} by {owner}" : "{owner} поделио са Вама и у разговору {conversation}",
-    "Shared with you in a conversation by {owner}" : "{owner} поделио са Вама у разговору",
-    "Shared with you by {owner}" : "{owner} дели са вама",
-    "Choose a password for the mail share" : "Унесите лозинку за дељење е-поштом",
-    "group" : "група",
-    "remote" : "удаљени",
-    "remote group" : "удаљена група",
-    "email" : "е-пошта",
-    "conversation" : "разговор",
-    "shared by {sharer}" : "дели {sharer}",
-    "Can reshare" : "Може да дели даље",
-    "Can edit" : "Може да уређује",
-    "Can create" : "Може да направи",
-    "Can change" : "Може да мења",
-    "Can delete" : "Може да обрише",
-    "Access control" : "Контрола приступа",
-    "{shareInitiatorDisplayName} shared via link" : "{shareInitiatorDisplayName} је поделио преко везе",
-    "Error while sharing" : "Грешка при дељењу",
-    "Share details could not be loaded for this item." : "Не могу да учитам детаље дељења за ову ставку.",
-    "Search globally" : "Претражите глобално",
-    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["Најмање {count} слово је потребно за аутокомплетирање","Најмање {count} слова је потребно за аутокомплетирање","Бар {count} слова је потребно за аутоматско довршавање"],
-    "This list is maybe truncated - please refine your search term to see more results." : "Ова листа је можда скраћена - претражите опет користећи мало специфичније изразе да бисте добили још резултата.",
-    "No users or groups found for {search}" : "Није нађен ниједан корисник ни група за претрагу {search}",
-    "No users found for {search}" : "Није нађен ниједан корисник за претрагу {search}",
-    "An error occurred (\"{message}\"). Please try again" : "Десила се грешка (\"{message}\"). Покушајте поново.",
-    "An error occurred. Please try again" : "Дошло је до грешке. Покушајте поново",
-    "Home" : "Почетна",
-    "Work" : "Посао",
-    "Other" : "Остало",
-    "{sharee} (remote group)" : "{sharee} (удаљена група)",
-    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
-    "Share" : "Дели",
-    "Name or email address..." : "Име или адреса е-поште...",
-    "Name or federated cloud ID..." : "Име или ID здруженог облака...",
-    "Name, federated cloud ID or email address..." : "Име, ID здруженог облака или адреса е-поште...",
-    "Name..." : "Име...",
-    "Error removing share" : "Грешка при уклањању дељења",
+    "Use of the the built in php mailer is no longer supported. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Please update your email server settings ↗<a/>." : "Коришћење уграђеног php mailer-а више није подржано. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Молимо ажурирајте и-мејл сервер поставке ↗<a/>.",
     "({scope})" : "({scope})",
     "Searching other places" : "Претражујем остала места",
     "No search results in other folders for {tag}{filter}{endtag}" : "Нема резултата претраге у осталим фасциклама за {tag}{filter}{endtag}",
     "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} резултат претраге у осталим фасциклама","{count} резултата претраге у осталим фасциклама","{count} резултата претраге у осталим фасциклама"],
-    "Saving..." : "Чувам...",
-    "Search" : "Претражи",
-    "Reset search" : "Ресетуј претрагу",
-    "Your client should now be connected! You can close this window." : "Ваш клијент сада треба да је повезан! Можете затворити овај прозор.",
-    "Cancel log in" : "Поништите пријаву",
-    "These apps will be updated:" : "Следеће апликације ће бити ажуриране:",
     "Nextcloud {app}" : "Некстклауд апликација {app}",
     "Local document editing back-end used by the OnlyOffice app." : "Позадински мотор за локално уређивање докумената који користи OnlyOffice апликацију",
-    "Calendar, Contacts, Talk, Mail & OnlyOffice" : "Календар, контакти, разговор, пошта & OnlyOffice"
+    "Saving..." : "Чувам...",
+    "Calendar, Contacts, Talk, Mail & OnlyOffice" : "Календар, контакти, разговор, пошта & OnlyOffice",
+    "Search" : "Претражи",
+    "These apps will be updated:" : "Следеће апликације ће бити ажуриране:"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
