@@ -29,6 +29,8 @@ OC.L10N.register(
     "Nextcloud Server" : "Nextcloud 服务器",
     "Some of your link shares have been removed" : "您的一些链接共享已被移除",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "由于一个安全缺陷，我们必须移除您的部分链接共享。更多信息请查看此链接。",
+    "The user limit of this instance is reached." : "已达到这个实例的最大用户数。",
+    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "输入订阅密钥以增加用户限制。欲了解更多关于Nextcloud企业版的信息，请访问我们的网站。",
     "Preparing update" : "正在准备更新",
     "[%d / %d]: %s" : "[%d / %d]：%s",
     "Repair step:" : "修复错误：",
@@ -69,6 +71,7 @@ OC.L10N.register(
     "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "未找到 PHP 的 \"fileinfo\" 模块。强烈推荐启用该模块，从而获得更好的 MIME 类型探测结果。",
     "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation ↗</a> for more information." : "已禁用事务性文件锁定，这可能在竞争条件下导致问题。在 config.php 中启用 \"filelocking.enabled\" 可以避免此问题。详情查阅 <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">文档 ↗</a>。",
     "If your installation is not installed at the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (suggestion: \"{suggestedOverwriteCliURL}\")" : "如果没有将 Nextcloud 安装到域名根目录并使用系统计划任务，生成超链接就会出现问题。为避免此问题，请在 config.php 配置文件中将 \"overwrite.cli.url\" 设置为您 Nextcloud 安装的路径。（建议：\"{suggestedOverwriteCliURL}\"）",
+    "Your installation has no default phone region set. This is required to be able to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective ISO 3166-1 code of the wished region." : "您的安装没有设置默认的电话区域。这是在没有国家代码的情况下验证配置文件设置中的电话号码所必需的。如果号码没有国家代码，请添加“默认电话区域”，并加上希望使用的区域对应的ISO 3166-1代码。",
     "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "无法通过 CLI 执行计划任务，请查看以下技术错误：",
     "Last background job execution ran {relativeTime}. Something seems wrong." : "最近一次执行后台任务运行时间为 {relativeTime}，似乎哪里出了问题。",
     "Check the background job settings" : "请检查后台任务设置",
@@ -136,7 +139,7 @@ OC.L10N.register(
     "Password" : "密码",
     "Wrong username or password." : "错误的用户名或密码。",
     "User disabled" : "用户不可用",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "我们检测到您的 IP 进行了多次无效登录尝试。因此，请 30 秒之后再尝试。",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "我们检测到您的 IP 进行了多次无效登录尝试。因此，你的下一次登录最长会延迟30秒。",
     "Your account is not setup for passwordless login." : "您的账号未设置无密码登录。",
     "Passwordless authentication is not supported in your browser." : "浏览器不支持无密码验证。",
     "Passwordless authentication is only available over a secure connection." : "无密码身份验证仅在安全连接上可用。",
