@@ -15,6 +15,7 @@ OC.L10N.register(
     "No valid crop data provided" : "未提供有效的剪裁設定",
     "Crop is not square" : "剪裁設定不是正方形",
     "State token does not match" : "狀態權杖不相符",
+    "Invalid app password" : "無效的 APP 密碼",
     "Could not complete login" : "嘗試登入時發生錯誤",
     "Your login token is invalid or has expired" : "您的登入權杖無效或已過期",
     "Password reset is disabled" : "密碼重設已停用",
@@ -28,6 +29,7 @@ OC.L10N.register(
     "Nextcloud Server" : "Nextcloud 伺服器",
     "Some of your link shares have been removed" : "部分分享連結己被移除",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "由於安全性問題，我們必須移除您一部分的連結分享。查看更多資訊請點選連結。",
+    "The user limit of this instance is reached." : "的達此實例的使用者上限。",
     "Preparing update" : "準備更新",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "修復步驟：",
@@ -94,6 +96,7 @@ OC.L10N.register(
     "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL. For further details read <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">the documentation page about this</a>." : "您的 MySQL 資料庫並不支援 4-byte 的字元。為了能處理檔案名稱中，或是註記中的 4-byte 的字元 (如表情符號等) 。建議您啟用 MySQL 中支援 4-byte 的字元的功能。詳情請見<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">此文件中關於此項目的說明</a>。",
     "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "此站台使用Amazon S3物件儲存為主要儲存區。上傳檔案會暫存在伺服器，因此建議PHP的暫存資料夾最少要有50GB可用容量。請在登錄檔中查閱關於資料夾路徑及可用容量的詳細資訊。要增進效能，請在php.ini中變更暫存資料夾位置，或將該資料夾容量增加。",
     "Error occurred while checking server setup" : "檢查伺服器設定時發生錯誤",
+    "For more details see the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "要取得進一步的資訊，請見 <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation\n</a>.",
     "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "您的資料目錄和檔案看來可以被公開存取，這表示 .htaccess 設定檔並未生效，我們強烈建議您設定網頁伺服器，拒絕公開存取資料目錄，或者將您的資料目錄移出網頁伺服器根目錄。",
     "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "目前 HTTP 的 {header} 標頭設定並不是 \"{expected}\" ，這是一個潛在的安全性和隱私風險，我們建議調整此項設定。",
     "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "目前 HTTP 的 {header} 標頭設定並不是 \"{expected}\" ，這將讓某些功能無法正常運作，我們建議修正此項設定。",
@@ -128,6 +131,7 @@ OC.L10N.register(
     "Wrong username or password." : "錯誤的使用者名稱 或 密碼",
     "User disabled" : "使用者已遭停用",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "您的 IP 多次嘗試登入無效，下一次登入將會被延時 30 秒。",
+    "Your account is not setup for passwordless login." : "你的帳號尚未設定免密碼登入。",
     "Reset password" : "重設密碼",
     "A password reset message has been sent to the e-mail address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "重設密碼資訊已寄至您的電子郵件。若您並未收到該信件，請確認您垃圾信箱，或請求管理員協助。",
     "If it is not there ask your local administrator." : "你找的東西不在，請聯絡管理員。",
@@ -150,8 +154,14 @@ OC.L10N.register(
     "Keep your colleagues and friends in one place without leaking their private info." : "將您的同事和朋友的聯繫整合在一處，且不洩漏他們的個人資訊",
     "Simple email app nicely integrated with Files, Contacts and Calendar." : "簡潔的電子郵件應用程式，與檔案瀏覽器、通訊錄、行事曆完美整合",
     "Forgot password?" : "忘記密碼？",
+    "Log in with a device" : "使用裝置登入",
     "Back" : "返回",
     "Reset search" : "重置搜尋",
+    "Search for {name} only" : "只搜尋 {name}",
+    "No results for {query}" : "{query} 查詢沒有結果",
+    "Load more results" : "載入更多結果",
+    "An error occurred while searching for {type}" : "搜尋 {type} 時發生錯誤",
+    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["請輸入 {minSearchLength} 個或以上字元搜尋"],
     "Search {types} …" : "搜尋 {types} 中 …",
     "Settings" : "設定",
     "Could not load your contacts" : "無法載入您的聯絡人",
@@ -236,6 +246,7 @@ OC.L10N.register(
     "File not found" : "找不到檔案",
     "The document could not be found on the server. Maybe the share was deleted or has expired?" : "伺服器上找不到該文件，或許這個分享已經被刪除或是過期了？",
     "Back to %s" : "回到 %s",
+    "Too many requests" : "太多要求",
     "Error" : "錯誤",
     "Internal Server Error" : "內部伺服器錯誤",
     "The server was unable to complete your request." : "伺服器無法完成你的請求。",
@@ -319,6 +330,7 @@ OC.L10N.register(
     "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "更多關於如何設定的訊息，請見%1$s文件%2$s。",
     "App update required" : "需要更新應用程式",
     "%1$s will be updated to version %2$s" : "%1$s 將會更新至版本 %2$s",
+    "The following apps will be updated:" : "將更新以下的 APP：",
     "These incompatible apps will be disabled:" : "將會停用這些不相容的應用程式",
     "The theme %s has been disabled." : "主題 %s 已經被停用",
     "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "在繼續之前，請備份資料庫、config 目錄及資料目錄",
