@@ -10,6 +10,7 @@ OC.L10N.register(
     "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "I file dell'applicazione %1$s non sono stati sostituiti correttamente. Assicurati che sia una versione compatibile con il server.",
     "Sample configuration detected" : "Configurazione di esempio rilevata",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "È stato rilevato che la configurazione di esempio è stata copiata. Ciò può compromettere la tua installazione e non è supportato. Leggi la documentazione prima di modificare il file config.php",
+    "Other activities" : "Altre attività",
     "%1$s and %2$s" : "%1$s e %2$s",
     "%1$s, %2$s and %3$s" : "%1$s, %2$s e %3$s",
     "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s e %4$s",
@@ -22,6 +23,7 @@ OC.L10N.register(
     "PHP %s or higher is required." : "Richiesto PHP %s o superiore",
     "PHP with a version lower than %s is required." : "Richiesta una versione di PHP minore di %s.",
     "%sbit or higher PHP required." : "Richiesto PHP %sbit o superiore.",
+    "The following architectures are supported: %s" : "Sono supportate le seguenti architetture: %s",
     "The following databases are supported: %s" : "I seguenti database sono supportati: %s",
     "The command line tool %s could not be found" : "Lo strumento da riga di comando %s non è stato trovato",
     "The library %s is not available." : "La libreria %s non è disponibile.",
@@ -101,7 +103,6 @@ OC.L10N.register(
     "Set an admin username." : "Imposta un nome utente di amministrazione.",
     "Set an admin password." : "Imposta una password di amministrazione.",
     "Can't create or write into the data directory %s" : "Impossibile creare o scrivere nella cartella dei dati %s",
-    "Invalid Federated Cloud ID" : "ID di cloud federata non valido",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Il motore di condivisione %s deve implementare l'interfaccia OCP\\Share_Backend",
     "Sharing backend %s not found" : "Motore di condivisione %s non trovato",
     "Sharing backend for %s not found" : "Motore di condivisione di %s non trovato",
@@ -166,6 +167,7 @@ OC.L10N.register(
     "Oct." : "Ott.",
     "Nov." : "Nov.",
     "Dec." : "Dic.",
+    "The user limit has been reached and the user was not created." : "È stato raggiunto il limite di utenti e l'utente non è stato creato.",
     "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Solo i seguenti caratteri sono consentiti in un nome utente: \"a-z\", \"A-Z\", \"0-9\", e \"_.@-'\"",
     "A valid username must be provided" : "Deve essere fornito un nome utente valido",
     "Username contains whitespace at the beginning or at the end" : "Il nome utente contiene spazi all'inizio o alla fine",
@@ -233,6 +235,7 @@ OC.L10N.register(
     "Groupware" : "Groupware",
     "Personal info" : "Informazioni personali",
     "Mobile & desktop" : "Mobile e desktop",
+    "Invalid Federated Cloud ID" : "ID di cloud federata non valido",
     "This can usually be fixed by giving the webserver write access to the apps directory or disabling the appstore in the config file. See %s" : "Ciò può essere normalmente corretto fornendo al server web accesso in scrittura alla cartella delle applicazioni o disabilitando il negozio di applicazioni nel file di configurazione. Vedi %s"
 },
 "nplurals=2; plural=(n != 1);");
