@@ -13,10 +13,8 @@ OC.L10N.register(
     "PHP %s or higher is required." : "Ir nepieciešams PHP %s vai jaunāks.",
     "PHP with a version lower than %s is required." : "Ir nepieciešams PHP vecāks kā %s.",
     "%sbit or higher PHP required." : "Nepieciešams %sbit vai jaunāks PHP.",
-    "Following databases are supported: %s" : "Tiek atbalstītas šādas datu bāzes: %s",
     "The command line tool %s could not be found" : "Komandrindas rīku %s nevarēja atrast",
     "The library %s is not available." : "Bibliotēka %s nav pieejama.",
-    "Following platforms are supported: %s" : "Tiek atbalstītas šādas platformas: %s",
     "Server version %s or higher is required." : "Ir vajadzīga servera versija %s vai jaunāka.",
     "Server version %s or lower is required." : "Ir vajadzīga servera versija %s vai vecāka.",
     "Authentication" : "Autentifikācija",
@@ -42,9 +40,7 @@ OC.L10N.register(
     "Log out" : "Izrakstīties",
     "Users" : "Lietotāji",
     "Unknown user" : "Nezināms lietotājs",
-    "Sharing" : "Koplietošana",
     "Additional settings" : "Papildu iestatījumi",
-    "Personal info" : "Personiskā informācija",
     "%s enter the database username." : "%s ievadiet datubāzes lietotājvārdu.",
     "%s enter the database name." : "%s ievadiet datubāzes nosaukumu.",
     "%s you may not use dots in the database name" : "%s datubāžu nosaukumos nedrīkst izmantot punktus",
@@ -53,7 +49,6 @@ OC.L10N.register(
     "PostgreSQL username and/or password not valid" : "Nav derīga PostgreSQL parole un/vai lietotājvārds",
     "Set an admin username." : "Iestatiet administratora lietotājvārdu.",
     "Set an admin password." : "Iestatiet administratora paroli.",
-    "Invalid Federated Cloud ID" : "Nederīgs Federated Cloud ID",
     "Open »%s«" : "Atvērt »%s«",
     "Could not find category \"%s\"" : "Nevarēja atrast kategoriju “%s”",
     "Sunday" : "Svētdiena",
@@ -112,8 +107,8 @@ OC.L10N.register(
     "Application is not enabled" : "Lietotne nav iespējota",
     "Authentication error" : "Autentifikācijas kļūda",
     "Token expired. Please reload page." : "Pilnvarai ir beidzies termiņš. Lūdzu, pārlādējiet lapu.",
-    "Please ask your server administrator to install the module." : "Lūdzu, palūdziet savam servera administratoram, lai instalē moduli.",
     "PHP module %s not installed." : "PHP modulis %s nav instalēts.",
+    "Please ask your server administrator to install the module." : "Lūdzu, palūdziet savam servera administratoram, lai instalē moduli.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Tas ir iespējams, kešatmiņa / paātrinātājs, piemēram, Zend OPcache vai eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP modulis ir uzstādīts, taču tas joprojām ir uzskatāms kā trūkstošs, pazudis?",
     "Please ask your server administrator to restart the web server." : "Lūdzu, palūdziet savam servera administratoram, restartēt Web serveri.",
@@ -124,11 +119,10 @@ OC.L10N.register(
     "Storage connection error. %s" : "Datu savienojuma kļūda. %s",
     "Storage is temporarily not available" : "Glabātuve īslaicīgi nav pieejama",
     "Storage connection timeout. %s" : "Datu savienojuma taimauts. %s",
-    "Create" : "Izveidot",
-    "Change" : "Mainīt",
-    "Delete" : "Dzēst",
-    "Share" : "Koplietot",
-    "Unlimited" : "Neierobežota",
-    "Verify" : "Verificēt"
+    "Following databases are supported: %s" : "Tiek atbalstītas šādas datu bāzes: %s",
+    "Following platforms are supported: %s" : "Tiek atbalstītas šādas platformas: %s",
+    "Sharing" : "Koplietošana",
+    "Personal info" : "Personiskā informācija",
+    "Invalid Federated Cloud ID" : "Nederīgs Federated Cloud ID"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
