@@ -20,6 +20,7 @@ OC.L10N.register(
     "PHP %s or higher is required." : "Zahtevana je različica PHP %s ali višja.",
     "PHP with a version lower than %s is required." : "Zahtevana je različica PHP nižja od %s.",
     "%sbit or higher PHP required." : "Zahtevana je %s-bitna različica PHP višja.",
+    "The following architectures are supported: %s" : "Podprte so navedena okolja: %s",
     "The following databases are supported: %s" : "Podprte so navedene podatkovne zbirke: %s",
     "The command line tool %s could not be found" : "Orodja ukazne vrstice %s ni mogoče najti",
     "The library %s is not available." : "Knjižnica %s ni na voljo.",
@@ -32,8 +33,12 @@ OC.L10N.register(
     "Logged in user must be an admin" : "Prijavljen uporabnik mora biti tudi skrbnik",
     "Wiping of device %s has started" : "Začeto je brisanje podatkov na napravi %s.",
     "Wiping of device »%s« has started" : "Začeto je brisanje podatkov na napravi »%s«",
+    "»%s« started remote wipe" : "Program »%s« je začel izvajati oddaljeno varnostno brisanje",
+    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "Naprava ali program »%s« je začel izvajati oddaljeno varnostno brisanje. Ko bo opravilo končano boste prejeli še eno sporočilo.",
     "Wiping of device %s has finished" : "Brisanje podatkov na napravi %s je končano.",
     "Wiping of device »%s« has finished" : "Brisanje podatkov na napravi »%s« je končano.",
+    "»%s« finished remote wipe" : "Program »%s« je zaključil z izvajanjem oddaljenega varnostnega brisanja.",
+    "Device or application »%s« has finished the remote wipe process." : "Naprava ali program »%s« je zaključil oddaljeno varnostno brisanje.",
     "Remote wipe started" : "Začeto je oddaljeno varnostno brisanje",
     "A remote wipe was started on device %s" : "Začeto je bilo oddaljeno varnostno brisanje na napravi %s.",
     "Remote wipe finished" : "Oddaljeno varnostno brisanje je končano",
@@ -95,7 +100,6 @@ OC.L10N.register(
     "Set an admin username." : "Nastavi uporabniško ime skrbnika.",
     "Set an admin password." : "Nastavi skrbniško geslo.",
     "Can't create or write into the data directory %s" : "Ni mogoče zapisati podatkov v podatkovno mapo %s",
-    "Invalid Federated Cloud ID" : "Neveljaven ID zveznega oblaka",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Souporaba ozadnjega programa %s mora vsebovati tudi vmesnik OCP\\Share_Backend",
     "Sharing backend %s not found" : "Ozadnjega programa %s za souporabo ni mogoče najti",
     "Sharing backend for %s not found" : "Ozadnjega programa za souporabo za %s ni mogoče najti",
@@ -111,7 +115,7 @@ OC.L10N.register(
     "%1$s shared »%2$s« with you" : "%1$s vam omogoča souporabo »%2$s«",
     "%1$s shared »%2$s« with you." : "%1$s vam omogoča souporabo »%2$s«.",
     "Click the button below to open it." : "Kliknite na gumb za odpiranje.",
-    "The requested share does not exist anymore" : "Zahtevano mesto souporabe ne obstaja več",
+    "The requested share does not exist anymore" : "Podano mesto souporabe ne obstaja več",
     "Could not find category \"%s\"" : "Kategorije »%s« ni mogoče najti.",
     "Sunday" : "nedelja",
     "Monday" : "ponedeljek",
@@ -179,9 +183,10 @@ OC.L10N.register(
     "Cannot write into \"config\" directory" : "Mapa »config« nima nastavljenih ustreznih dovoljenj za pisanje!",
     "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Napako je mogoče odpraviti z dodelitvijo dovoljenja spletnemu strežniku za pisanje v nastavitveno mapo. Poglejte %s",
     "Cannot write into \"apps\" directory" : "V mapo »apps« ni mogoče zapisovati!",
-    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the appstore in the config file." : "Napako je mogoče odpraviti z dodelitvijo dovoljenja spletnemu strežniku za pisanje v mapo programov, ali pa z onemogočanjem zborle programov v nastavitveni datoteki.",
+    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the appstore in the config file." : "Napako je mogoče odpraviti z dodelitvijo dovoljenja spletnemu strežniku za pisanje v mapo programov, ali pa z onemogočanjem zbirke programov v nastavitveni datoteki.",
     "Cannot create \"data\" directory" : "Ni mogoče ustvariti »podatkovne« mape",
     "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "Napako je mogoče odpraviti z dodelitvijo dovoljenja spletnemu strežniku za pisanje v korensko mapo. Poglejte %s",
+    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "Omejitev je mogoče odpraviti z dodelitvijo dovoljenja spletnemu strežniku za pisanje v korensko mapo. Za več podrobnosti si oglejte %s.",
     "Setting locale to %s failed" : "Nastavljanje jezikovnih določil na %s je spodletelo.",
     "Please install one of these locales on your system and restart your webserver." : "Namestiti je treba podporo za vsaj eno od navedenih jezikovnih določil v sistemu in nato ponovno zagnati spletni strežnik.",
     "PHP module %s not installed." : "Modul PHP %s ni nameščen.",
@@ -198,6 +203,7 @@ OC.L10N.register(
     "Please ask your server administrator to restart the web server." : "Obvestite skrbnika strežnika, da je treba ponovno zagnati spletni strežnik.",
     "PostgreSQL >= 9 required" : "Zahtevana je različica PostgreSQL >= 9.",
     "Please upgrade your database version" : "Posodobite različico podatkovne zbirke.",
+    "Your data directory is readable by other users" : "Podatkovna mapa na strežniku ima določena dovoljenja za branje drugim uporabnikom",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Spremenite dovoljenja mape na 0770 in s tem onemogočite branje vsebine drugim uporabnikom.",
     "Your data directory must be an absolute path" : "Podatkovna mapa mora imeti navedeno celotno pot.",
     "Check the value of \"datadirectory\" in your configuration" : "Med nastavitvami je treba preveriti nastavitev »datadirectory«",
@@ -205,6 +211,9 @@ OC.L10N.register(
     "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Prepričajte se, da je datoteka ».ocdata« v korenu podatkovne mape.",
     "Action \"%s\" not supported or implemented." : "Dejanje »%s« ni podprto ali omogočeno.",
     "Authentication failed, wrong token or provider ID given" : "Overitev je spodletela, podan je napačen žeton oziroma določilo ID ponudnika",
+    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Manjkajo parametri za dokončanje zahteve: »%s«.",
+    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "Določilo ID »%1$s« je že v uporabi pri ponudniku zveznega oblaka »%2$s«.",
+    "Cloud Federation Provider with ID: \"%s\" does not exist." : "Ponudnik zveznega povezovanja z ID: »%s« ne obstaja.",
     "Could not obtain lock type %d on \"%s\"." : "Ni mogoče pridobiti zaklepa %d na \"%s\".",
     "Storage unauthorized. %s" : "Dostop do shrambe ni overjen. %s",
     "Storage incomplete configuration. %s" : "Nepopolna nastavitev shrambe. %s",
@@ -219,6 +228,8 @@ OC.L10N.register(
     "Security" : "Varnost",
     "Groupware" : "Skupinsko delo",
     "Personal info" : "Osebni podatki",
-    "Mobile & desktop" : "Mobilni in namizni dostop"
+    "Mobile & desktop" : "Mobilni in namizni dostop",
+    "Invalid Federated Cloud ID" : "Neveljaven ID zveznega oblaka",
+    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the appstore in the config file. See %s" : "Napako je mogoče odpraviti z dodelitvijo dovoljenja spletnemu strežniku za pisanje v mapo programov, ali pa z onemogočanjem zbirke programov v nastavitveni datoteki. Za več podrobnosti si oglejte %s."
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
