@@ -4,10 +4,12 @@
  *
  * @author Arthur Schiwon <blizzz@arthur-schiwon.de>
  * @author Christoph Wurst <christoph@winzerhof-wurst.at>
+ * @author Georg Ehrke <oc.list@georgehrke.com>
  * @author Joas Schilling <coding@schilljs.com>
  * @author Julius Härtl <jus@bitgrid.net>
  * @author Morris Jobke <hey@morrisjobke.de>
  * @author Robin Appelman <robin@icewind.nl>
+ * @author Roeland Jago Douma <roeland@famdouma.nl>
  * @author Thomas Citharel <nextcloud@tcit.fr>
  *
  * @license GNU AGPL version 3 or any later version
@@ -37,8 +39,8 @@ use OCP\IGroupManager;
 use OCP\IUser;
 use OCP\IUserManager;
 use OCP\IUserSession;
-use OCP\Share;
 use OCP\Share\IShare;
+use OCP\UserStatus\IManager as IUserStatusManager;
 
 class UserPlugin implements ISearchPlugin {
 	/* @var bool */
@@ -54,13 +56,29 @@ class UserPlugin implements ISearchPlugin {
 	private $userSession;
 	/** @var IUserManager */
 	private $userManager;
+	/** @var IUserStatusManager */
+	private $userStatusManager;
 
-	public function __construct(IConfig $config, IUserManager $userManager, IGroupManager $groupManager, IUserSession $userSession) {
+	/**
+	 * UserPlugin constructor.
+	 *
+	 * @param IConfig $config
+	 * @param IUserManager $userManager
+	 * @param IGroupManager $groupManager
+	 * @param IUserSession $userSession
+	 * @param IUserStatusManager $userStatusManager
+	 */
+	public function __construct(IConfig $config,
+								IUserManager $userManager,
+								IGroupManager $groupManager,
+								IUserSession $userSession,
+								IUserStatusManager $userStatusManager) {
 		$this->config = $config;
 
 		$this->groupManager = $groupManager;
 		$this->userSession = $userSession;
 		$this->userManager = $userManager;
+		$this->userStatusManager = $userStatusManager;
 
 		$this->shareWithGroupOnly = $this->config->getAppValue('core', 'shareapi_only_share_with_group_members', 'no') === 'yes';
 		$this->shareeEnumeration = $this->config->getAppValue('core', 'shareapi_allow_share_dialog_user_enumeration', 'yes') === 'yes';
@@ -79,7 +97,15 @@ class UserPlugin implements ISearchPlugin {
 				$usersInGroup = $this->groupManager->displayNamesInGroup($userGroupId, $search, $limit, $offset);
 				foreach ($usersInGroup as $userId => $displayName) {
 					$userId = (string) $userId;
-					$users[$userId] = $this->userManager->get($userId);
+					$user = $this->userManager->get($userId);
+					if (!$user->isEnabled()) {
+						// Ignore disabled users
+						continue;
+					}
+					$users[$userId] = $user;
+				}
+				if (count($usersInGroup) >= $limit) {
+					$hasMoreResults = true;
 				}
 			}
 		} else {
@@ -100,14 +126,30 @@ class UserPlugin implements ISearchPlugin {
 
 		$foundUserById = false;
 		$lowerSearch = strtolower($search);
+		$userStatuses = $this->userStatusManager->getUserStatuses(array_keys($users));
 		foreach ($users as $uid => $user) {
 			$userDisplayName = $user->getDisplayName();
 			$userEmail = $user->getEMailAddress();
 			$uid = (string) $uid;
+
+			$status = [];
+			if (array_key_exists($uid, $userStatuses)) {
+				$userStatus = $userStatuses[$uid];
+				$status = [
+					'status' => $userStatus->getStatus(),
+					'message' => $userStatus->getMessage(),
+					'icon' => $userStatus->getIcon(),
+					'clearAt' => $userStatus->getClearAt()
+						? (int)$userStatus->getClearAt()->format('U')
+						: null,
+				];
+			}
+
+
 			if (
-				strtolower($uid) === $lowerSearch ||
+				$lowerSearch !== '' && (strtolower($uid) === $lowerSearch ||
 				strtolower($userDisplayName) === $lowerSearch ||
-				strtolower($userEmail) === $lowerSearch
+				strtolower($userEmail) === $lowerSearch)
 			) {
 				if (strtolower($uid) === $lowerSearch) {
 					$foundUserById = true;
@@ -115,9 +157,10 @@ class UserPlugin implements ISearchPlugin {
 				$result['exact'][] = [
 					'label' => $userDisplayName,
 					'value' => [
-						'shareType' => Share::SHARE_TYPE_USER,
+						'shareType' => IShare::TYPE_USER,
 						'shareWith' => $uid,
 					],
+					'status' => $status,
 				];
 			} else {
 				$addToWideResults = false;
@@ -139,6 +182,7 @@ class UserPlugin implements ISearchPlugin {
 							'shareType' => IShare::TYPE_USER,
 							'shareWith' => $uid,
 						],
+						'status' => $status,
 					];
 				}
 			}
@@ -158,12 +202,26 @@ class UserPlugin implements ISearchPlugin {
 				}
 
 				if ($addUser) {
+					$status = [];
+					if (array_key_exists($user->getUID(), $userStatuses)) {
+						$userStatus = $userStatuses[$user->getUID()];
+						$status = [
+							'status' => $userStatus->getStatus(),
+							'message' => $userStatus->getMessage(),
+							'icon' => $userStatus->getIcon(),
+							'clearAt' => $userStatus->getClearAt()
+								? (int)$userStatus->getClearAt()->format('U')
+								: null,
+						];
+					}
+
 					$result['exact'][] = [
 						'label' => $user->getDisplayName(),
 						'value' => [
-							'shareType' => Share::SHARE_TYPE_USER,
+							'shareType' => IShare::TYPE_USER,
 							'shareWith' => $user->getUID(),
 						],
+						'status' => $status,
 					];
 				}
 			}
