@@ -2,6 +2,7 @@
 /**
  * @copyright Copyright (c) 2017 Joas Schilling <coding@schilljs.com>
  *
+ * @author Christoph Wurst <christoph@winzerhof-wurst.at>
  * @author Joas Schilling <coding@schilljs.com>
  *
  * @license GNU AGPL version 3 or any later version
@@ -35,8 +36,7 @@ use OCP\PreConditionNotMetException;
  * before the data structure is changed and the information is gone
  */
 class SaveAccountsTableData implements IRepairStep {
-
-	const BATCH_SIZE = 75;
+	public const BATCH_SIZE = 75;
 
 	/** @var IDBConnection */
 	protected $db;
@@ -78,6 +78,15 @@ class SaveAccountsTableData implements IRepairStep {
 			$numUsers = $this->runStep($offset);
 		}
 
+		// oc_persistent_locks will be removed later on anyways so we can just drop and ignore any foreign key constraints here
+		$tableName = $this->config->getSystemValue('dbtableprefix', 'oc_') . 'persistent_locks';
+		$schema = $this->db->createSchema();
+		$table = $schema->getTable($tableName);
+		foreach ($table->getForeignKeys() as $foreignKey) {
+			$table->removeForeignKey($foreignKey->getName());
+		}
+		$this->db->migrateToSchema($schema);
+
 		// Remove the table
 		if ($this->hasForeignKeyOnPersistentLocks) {
 			$this->db->dropTable('persistent_locks');
@@ -177,7 +186,7 @@ class SaveAccountsTableData implements IRepairStep {
 		}
 		if ($state === 1) {
 			$this->config->setUserValue($userdata['user_id'], 'core', 'enabled', 'true');
-		} else if ($state === 2) {
+		} elseif ($state === 2) {
 			$this->config->setUserValue($userdata['user_id'], 'core', 'enabled', 'false');
 		}
 
@@ -186,6 +195,5 @@ class SaveAccountsTableData implements IRepairStep {
 				->setParameter('userid', $userdata['user_id']);
 			$update->execute();
 		}
-
 	}
 }
