@@ -1242,7 +1242,7 @@ class Server extends ServerContainer implements IServerContainer {
 		});
 
 		$this->registerService(ICloudIdManager::class, function (Server $c) {
-			return new CloudIdManager();
+			return new CloudIdManager($c->get(\OCP\Contacts\IManager::class));
 		});
 
 		$this->registerAlias(\OCP\GlobalScale\IConfig::class, \OC\GlobalScale\Config::class);
